#!/bin/sh 
#
#Copyright (c) 2012, Novell, Inc.  All rights reserved.
#
# This script is used to reconfigure AFP proxy user used on local system.
# This script is written exclusively for service proxy migration
#

#Only root can execute this script
user_id=`id -u`
if test $user_id -ne 0
then
        echo "afp_reconfig_proxy.sh: Only root user can run this script"
        exit 1
fi

#Help of the script
Usage()
{
                echo ""
                echo "Usage: afp_reconfig_proxy.sh [options]"
                echo "          -h                      Prints this summary"
                echo "          -d                      LDAP Admin FDN"
                echo "          -w                      LDAP Admin Password"
                echo "          -i                      LDAP Server IP address"
                echo "          -p                      LDAP Port(Only Secure Port like 636)"
                echo "          -u                      Proxy DN in LDAP format"
                echo "          -D                      Proxy password"
#               echo "          -f                      Credentilas File"
		echo "          -e                      (Optional) yes or no. Credentials in file are encrypted or not. Default yes"
		echo ""
                exit 1;
}

if test $# -eq 0
then
        Usage
fi

while getopts d:w:i:p:u:D:e:h o
do
        case "$o" in
                     d)LDAP_ADM="$OPTARG";;
                     w)LDAP_PWD="$OPTARG";;
                     i)LDAP_IP="$OPTARG";;
                     p)LDAP_PORT="$OPTARG";;
		     u)PROXYUSER="$OPTARG";;
		     D)PROXYPWD="$OPTARG";;
#		     f)CREDILE="$OPTARG";;
		     e)ENCORNO="$OPTARG";;	
                     h)Usage;;
                   [?]) Usage;;
        esac
done


PROXY_LOG_FILE=/var/opt/novell/log/proxymgmt/pxymgmt.log
CRED_FILE=/var/opt/novell/log/proxymgmt/proxycred
CRED_TEMP_FILE=/var/opt/novell/log/proxymgmt/tempcred
CRED_TEMP_FILE_INPUT=/var/opt/novell/log/proxymgmt/tempcredin
ENCBINARY=/opt/novell/proxymgmt/bin/oes-enc-dec
RECONFBINARY=/opt/novell/afptcpd/bin/afp_proxy_rights_assign.sh
GETCREDBINARY=/opt/novell/afptcpd/bin/afp_retrieve_proxy_cred.sh
STCREDBINARY=/opt/novell/afptcpd/bin/afp_update_proxy_cred.sh
ENCRYPTCRED="yes"

#LDAP details are compulsory
if test "$LDAP_ADM" = "" || test "$LDAP_IP" = "" || test "$LDAP_PORT" = ""
then
        Usage
fi

if test "$ENCORNO" != ""
then
	ENCORNO=`echo $ENCORNO | tr '[:upper:]' '[:lower:]'`
	ENCRYPTCRED="$ENCORNO"
fi

#If creds are not passed through command line, go for the file
if test "$PROXYUSER" = "" || test "$PROXYPWD" = ""
then

	#Get Credentials from file, if exists
	if [ -f "$CRED_FILE" ];
	then
		#Find if DNS entry entry in the file
		PROXYCREDS=`grep "AFPPROXY=" $CRED_FILE`
		FOUNDCREDS=$?
		if [ $FOUNDCREDS -ne 0 ]
		then
			echo "AFP Proxy Credentials neither found in $CRED_FILE nor passed through command line" >> $PROXY_LOG_FILE
			echo "Nothing to do be done" >> $PROXY_LOG_FILE
			exit $FOUNDCREDS
		else
			#Get Credentials from file stored in the format AFPPROXY=PROXYDN:EncryptedPassword
			SERVICENAME="`echo $PROXYCREDS | cut -d'=' -f1`"
			PROXYUSERDN="`echo $PROXYCREDS | cut -d'=' -f2- | cut -d':' -f1`"
			PROXYPWD="`echo -n $PROXYCREDS | cut -d':' -f2`"	
			PROXYPASSWORD="$PROXYPWD"
			echo "SERVICENAME: $SERVICENAME, Proxy DN: $PROXYUSERDN and Stored Password: $PROXYPWD" >> $PROXY_LOG_FILE
			
			if test "$ENCRYPTCRED" = "yes"	#If Password is Encrypted
			then
				#Decrypt the password
				echo -n "$PROXYPWD" > $CRED_TEMP_FILE_INPUT
				$ENCBINARY 0 $CRED_TEMP_FILE_INPUT $CRED_TEMP_FILE
				DECRES=$?
				if [ $DECRES -ne 0 ]
				then
        				echo "Could not decrypt AFP proxy user password: $DECRES" >> $PROXY_LOG_FILE
        				exit $DECRES
				fi
			
				#Save the password into PROXYPWD variable
				read PROXYPWD < $CRED_TEMP_FILE
				rm $CRED_TEMP_FILE
				rm $CRED_TEMP_FILE_INPUT
				
				PROXYPASSWORD="$PROXYPWD"
			fi
		fi
	fi
	
else	#Proxy credentials are passed through command line. just save them

	PROXYUSERDN="$PROXYUSER"
	PROXYPASSWORD="$PROXYPWD"
fi

#Now start the service reconfiguration

#Retrieve current Service proxy user name
$GETCREDBINARY username $CRED_TEMP_FILE
READ_PROXY_NAME=$?
if [ $READ_PROXY_NAME -ne 0 ]
then
	echo "Could not retrieve current AFP proxy user name: $READ_PROXY_NAME " >> $PROXY_LOG_FILE
	exit $READ_PROXY_NAME
fi

#Save proxy user name in a variable
read CURRENTPROXYNAME < $CRED_TEMP_FILE
rm $CRED_TEMP_FILE

#Nothing needs to be done if service is already configured with same proxy as source
if test "$CURRENTPROXYNAME" = "$PROXYUSERDN"
then
	echo "AFP is already configured to use $PROXYUSERDN. Nothing needs to be done" >> $PROXY_LOG_FILE
	exit 0;
fi

#Export admin and proxy passwords through environment variables
#These variable names are hard coded
export OES_AFP_DATA="$PROXYPASSWORD"
export OES_ADMIN_DATA="$LDAP_PWD"

#Reconfigure the service to use new proxy
$RECONFBINARY  -u "$PROXYUSERDN" -d "$LDAP_ADM"  -i $LDAP_IP -p $LDAP_PORT -s 1 >> /dev/null 2>&1
CONFIG_PROXY=$?

if test $CONFIG_PROXY == 0
then
	echo "Proxy rights assignment for AFP is successful" >> $PROXY_LOG_FILE
	
	#Update AFP proxy credentials
	$STCREDBINARY "$PROXYUSERDN" >> /dev/null 2>&1
	STORE_IN_OCS=$?
	if test $STORE_IN_OCS == 0
	then
		echo "Successfully updated AFP proxy user credentials: $STORE_IN_OCS" >> $PROXY_LOG_FILE
		
		#Finally update YaST sysconfig file of the service with the proxy user DN.
		sed -i "s/CONFIG_AFP_PROXY_USER=\".*\"/CONFIG_AFP_PROXY_USER=\"$PROXYUSERDN\"/g" /etc/sysconfig/novell/afp*
		
		#Before proceeding further clear environment variables exporting passwords
		unset OES_AFP_DATA
		unset OES_ADMIN_DATA
		
	else
		#Before proceeding further clear environment variables exporting passwords
		unset OES_AFP_DATA
		unset OES_ADMIN_DATA

		echo "Failed to update AFP proxy user credentials: $STORE_IN_OCS" >> $PROXY_LOG_FILE
		exit $STORE_IN_OCS
	fi		
else
	#Before proceeding further clear environment variables exporting passwords
	unset OES_AFP_DATA
	unset OES_ADMIN_DATA

	echo "AFP proxy rights assignment has failed: $CONFIG_PROXY" >> $PROXY_LOG_FILE
	exit $CONFIG_PROXY
fi

exit 0

