#!/bin/sh
#
#Copyright (c) 2010, Novell, Inc.  All rights reserved.
#
#Attach a given user FDN to a password policy and add him as reader of passwords to that policy
#This assumes that password policy exists in PasswordPolicies.Security container. So the parameter
#passed is just the policy name. Bind Admin password will be read from env OES_DATA.

user_id=`id -u`
if test $user_id -ne 0
then 
	echo "attach_proxyuser_pwpolicy.sh : Only root user can run this script"
	exit 1
fi

if test $# != 4 
then
	echo "Usage :  attach_proxyuser_pwpolicy.sh <proxyuser_fdn> <base_fdn> <ldapserver_ip> <ldap_port>"
	exit 1
fi

# Sleep for few seconds we before we try to do proxyuser policy
# assignment.
sleep 5 
COUNT=0
TMP_ATTACH_USER_PWPOLICY_LDIFFILE=/tmp/attachuserpwpolicy.ldif
LDAP_MODIFY_BINARY=/usr/bin/ldapmodify
PROXY_LOG_FILE=/var/opt/novell/log/proxymgmt/pxymgmt.log
LDAP_SEC_CERT="env LDAPTLS_CACERT=/etc/opt/novell/certs/SSCert.pem"

mkdir -p /tmp
touch $TMP_ATTACH_USER_PWPOLICY_LDIFFILE

echo "dn: "$1 >> $TMP_ATTACH_USER_PWPOLICY_LDIFFILE
echo "changetype: modify" >> $TMP_ATTACH_USER_PWPOLICY_LDIFFILE
echo "add: nspmPasswordPolicyDN" >> $TMP_ATTACH_USER_PWPOLICY_LDIFFILE
echo "nspmPasswordPolicyDN: cn=Common_Proxy_policy,cn=Password Policies,cn=Security" >> $TMP_ATTACH_USER_PWPOLICY_LDIFFILE
echo "" >> $TMP_ATTACH_USER_PWPOLICY_LDIFFILE

echo "The ldap command to be executed from within attach_proxyuser_pwpolicy script is $LDAP_SEC_CERT $LDAP_MODIFY_BINARY -c -f $TMP_ATTACH_USER_PWPOLICY_LDIFFILE -D "$2" -w -H ldaps://$3:$4 " >> $PROXY_LOG_FILE
$LDAP_SEC_CERT $LDAP_MODIFY_BINARY -c -f $TMP_ATTACH_USER_PWPOLICY_LDIFFILE -D "$2" -w "$OES_DATA" -H ldaps://$3:$4 >> $PROXY_LOG_FILE 2>&1
LDAP_MODIFY_OUT=$?
echo "The return value of ldap command called from within attach_proxyuser_pwpolicy script is: $LDAP_MODIFY_OUT" >> $PROXY_LOG_FILE
if test $LDAP_MODIFY_OUT == 19 || test $LDAP_MODIFY_OUT == 32 
then
	while [[ ( $LDAP_MODIFY_OUT == 32 || $LDAP_MODIFY_OUT == 19 ) && $COUNT -lt 60 ]]
	do
		let COUNT+=5
		sleep 5
		echo "The ldap command from the error block (error 19 or 32) of attach_proxyuser_pwpolicy script is $LDAP_SEC_CERT $LDAP_MODIFY_BINARY -c -f $TMP_ATTACH_USER_PWPOLICY_LDIFFILE -D "$2" -w -H ldaps://$3:$4 " >> $PROXY_LOG_FILE
		$LDAP_SEC_CERT $LDAP_MODIFY_BINARY -c -f $TMP_ATTACH_USER_PWPOLICY_LDIFFILE -D "$2" -w "$OES_DATA" -H ldaps://$3:$4 >> $PROXY_LOG_FILE 2>&1
		LDAP_MODIFY_OUT=$?
		echo "The return value of ldap command called from within error block (error 19 or 32) of attach_proxyuser_pwpolicy script is: $LDAP_MODIFY_OUT" >> $PROXY_LOG_FILE
	done	
	if test $COUNT == 60
	then
		rm $TMP_ATTACH_USER_PWPOLICY_LDIFFILE
		echo "[Error] Proxy user policy attachment is failed with ladp error $LDAP_MODIFY_OUT." >> $PROXY_LOG_FILE
		echo "Please run /opt/novell/proxymgmt/bin/attach_proxyuser_pwpolicy.sh later manually by setting the admin password to OES_DATA" >> $PROXY_LOG_FILE
		echo "OR you can use iManager to assign proxy password policy to the proxy user" >> $PROXY_LOG_FILE
		exit 2
	fi
fi
if test $LDAP_MODIFY_OUT != 20 && test $LDAP_MODIFY_OUT != 0
then
	rm $TMP_ATTACH_USER_PWPOLICY_LDIFFILE
	exit 1
fi

COUNT=0
rm $TMP_ATTACH_USER_PWPOLICY_LDIFFILE
touch $TMP_ATTACH_USER_PWPOLICY_LDIFFILE

echo "dn: cn=Common_Proxy_policy,cn=Password Policies,cn=Security" >> $TMP_ATTACH_USER_PWPOLICY_LDIFFILE
echo "changetype: modify" >> $TMP_ATTACH_USER_PWPOLICY_LDIFFILE
echo "add: nsimAssignments" >> $TMP_ATTACH_USER_PWPOLICY_LDIFFILE
echo "nsimAssignments: "$1 >> $TMP_ATTACH_USER_PWPOLICY_LDIFFILE
echo "" >> $TMP_ATTACH_USER_PWPOLICY_LDIFFILE

echo "The ldap command (second block) to be executed from within attach_proxyuser_pwpolicy script is $LDAP_SEC_CERT $LDAP_MODIFY_BINARY -c -f $TMP_ATTACH_USER_PWPOLICY_LDIFFILE -D "$2" -w -H ldaps://$3:$4 " >>$PROXY_LOG_FILE
$LDAP_SEC_CERT $LDAP_MODIFY_BINARY -c -f $TMP_ATTACH_USER_PWPOLICY_LDIFFILE -D "$2" -w "$OES_DATA" -H ldaps://$3:$4 >> $PROXY_LOG_FILE 2>&1
LDAP_MODIFY_OUT=$?
echo "The return value of ldap command called from (second block) within attach_proxyuser_pwpolicy script is: $LDAP_MODIFY_OUT" >> $PROXY_LOG_FILE
if test $LDAP_MODIFY_OUT == 19  
then
	while [[ $LDAP_MODIFY_OUT == 19 && $COUNT -lt 60 ]]
	do
		let COUNT+=5
		sleep 5
		echo "The ldap command to be executed from the error block (error 19) within attach_proxyuser_pwpolicy script is $LDAP_SEC_CERT $LDAP_MODIFY_BINARY -c -f $TMP_ATTACH_USER_PWPOLICY_LDIFFILE -D "$2" -w -H ldaps://$3:$4 " >> $PROXY_LOG_FILE
		$LDAP_SEC_CERT $LDAP_MODIFY_BINARY -c -f $TMP_ATTACH_USER_PWPOLICY_LDIFFILE -D "$2" -w "$OES_DATA" -H ldaps://$3:$4 >> $PROXY_LOG_FILE 2>&1
		LDAP_MODIFY_OUT=$?
		echo "The return value of ldap command called from error block (error 19) within attach_proxyuser_pwpolicy script is: $LDAP_MODIFY_OUT" >> $PROXY_LOG_FILE
	done	
	if test $COUNT == 60
	then
		rm $TMP_ATTACH_USER_PWPOLICY_LDIFFILE
		echo "[Error] Proxy user policy attachment is failed with error $LDAP_MODIFY_OUT." >> $PROXY_LOG_FILE
		echo "Please run /opt/novell/proxymgmt/bin/attach_proxyuser_pwpolicy.sh later manually by setting the admin password to OES_DATA" >> $PROXY_LOG_FILE
		exit 2
	fi
fi
if test $LDAP_MODIFY_OUT != 20 && test $LDAP_MODIFY_OUT != 0
then
	rm $TMP_ATTACH_USER_PWPOLICY_LDIFFILE
	exit 1 
fi
rm $TMP_ATTACH_USER_PWPOLICY_LDIFFILE

exit 0
