#!/bin/sh 
# This script is used to automatically change the password for the 
# proxy users registered in file /etc/opt/novell/proxymgmt/proxy_users.conf

user_id=`id -u`
if test $user_id -ne 0
then 
        echo "change_proxy_pwd.sh : Only root user can run this script"
        exit 1
fi
		
PROXY_USER_FILE="/etc/opt/novell/proxymgmt/proxy_users.conf"
PROXY_INFO_FILE="/etc/opt/novell/proxymgmt/proxyuser.txt"
CP_UTIL="/opt/novell/proxymgmt/bin"
PROXY_LOGFILE="/var/opt/novell/log/proxymgmt/pxymgmt.log"
TMP_ADD_PROXYUSER_LDIFFILE="/tmp/change_pwd.ldif"
LDAP_SEARCH_BINARY="/usr/bin/ldapsearch"
EXECUTE_CMD_IN_FILE="/tmp/executeCommand.sh"
LDAP_SEC_CERT="env LDAPTLS_CACERT=/etc/opt/novell/certs/SSCert.pem"

getIp(){
	file=/var/opt/novell/eDirectory/data/ldap_listeners.txt
	ldaps_ip="127.0.0.1"

	if [ -f "$file" ]
	then
		ldaps_ip_port=`grep -Po -m 1 "(?<=n4u.ldap.interfaces.ldaps =).*" "$file"`
		ldaps_ip_port=$(echo $ldaps_ip_port | sed -e 's/[\r\n]//g')
		if [ ! -z ldaps_ip_port ]
		then
			IFS=':' read -r -a ip_array <<< "$ldaps_ip_port"
			if [ ${ip_array[0]} != "0.0.0.0" ]
			then
				ldaps_ip=${ip_array[0]}
				ldaps_port=${ip_array[1]}
			fi
		fi
	fi
	echo "$ldaps_ip"
	return 0
}

IP_ADDRESS=$(getIp)

export LDAPTLS_REQCERT=never
Usage() 
{
	echo ""
	echo "Usage: change_proxy_pwd.sh [options]"
	echo "		-h			Prints this summary"
	echo "		-A			(yes/no)Run this job in automatic mode"
	echo "		-p			Proxy user FDN"
	echo "		-w			New Proxy password"
	echo ""
	echo "		example1: To run the job in automatic mode(read users from proxy_users.conf and use random passwords): ./change_proxy_pwd.sh -A yes "
	echo "		example2: To manually pass the proxy details: ./change_proxy_pwd.sh -A no -p <Proxy user FDN> -w <password> "
	echo "		example3: To provide the proxy details in interactive way: ./change_proxy_pwd.sh -A no "
	echo ""
	exit 1;
}


# This function executes the given command to retrieve or update the proxy credentials. It also retries the execution of the same command for 3 times in case of failure. This method is added to #provide the fix for the bug #859412.
RetrieveOrUpdateProxyCredentials()
{
	
	COMMAND_TO_EXECUTE="$@"
	
	#Create a file to hold the command
	touch $EXECUTE_CMD_IN_FILE
	
	#Give execute permissions to the file
	chmod a+x $EXECUTE_CMD_IN_FILE

	#Put the command into the file
	cat << END > $EXECUTE_CMD_IN_FILE
#!/bin/bash
echo "Executing command: $COMMAND_TO_EXECUTE" >> $PROXY_LOGFILE
i=1
while [ \$i -le 3 ] 
do
	$COMMAND_TO_EXECUTE >> /dev/null 2>&1
	RETRIEVE_CRED_RETVALUE=\$?
	if [ \$RETRIEVE_CRED_RETVALUE -eq 0 ] || [ \$i == 3 ]
	then
		break
	fi
	sleep 5
	i=\`expr \$i + 1\`
	echo "Retry attempt \$i" >> $PROXY_LOGFILE
done
echo \$RETRIEVE_CRED_RETVALUE
END
	RETRIEVE_CRED_RETVALUE=$(/usr/bin/sh $EXECUTE_CMD_IN_FILE)
	rm $EXECUTE_CMD_IN_FILE
	return "$RETRIEVE_CRED_RETVALUE"
}

# This function performs an ldapsearch using common proxy FDN to verify whether the current common proxy password is in sync with eDirectory. If Yes, the password change task will be continued    #else the function exits.
# Added the below function to check if the eDirectory is in sync with CASA before attempting to change the password. This change is done to provide the fix for the bug #859412.
verifyNDSLogin()
{
	echo "Verifying ndslogin with the existing common proxy credentials." >> $PROXY_LOGFILE
	CP_FDN=$1
	CURR_PWD=$2
	if test "$CURR_PWD" = "" 
	then
		echo "ERROR: Current common proxy password is empty, exiting" >> $PROXY_LOGFILE
		logger -t `basename $0[$$]` "ERROR: Current common proxy password is empty"
		exit 1
	fi

	echo "Ldapsearch command to be executed to verify the common proxy credentials is $LDAP_SEC_CERT $LDAP_SEARCH_BINARY -b "" -s base -D "$CP_FDN" -w -H "ldaps://$IP_ADDRESS:636"" >> $PROXY_LOGFILE
	$LDAP_SEC_CERT $LDAP_SEARCH_BINARY -b "" -s base -D "$CP_FDN" -w "$CURR_PWD" -H "ldaps://$IP_ADDRESS:636" >> /dev/null 2>&1
	RET_VAL=$?
	echo "Ldapsearch command executed to verify the common proxy credentials returned: $RET_VAL" >> $PROXY_LOGFILE
	if [ $RET_VAL -ne 0 ]
	then
		echo "ERROR: Common Proxy credentials verification failed in change password task, exiting the password change task." >> $PROXY_LOGFILE
		echo "ERROR: Common Proxy credentials verification failed in change password task, exiting the password change task. Refer to $PROXY_LOGFILE for more details" 
		logger -t `basename $0[$$]` "ERROR: Common Proxy credentials verification failed in change password task, exiting the password change task. Refer to $PROXY_LOGFILE for more details"
		exit 1
	fi
}


if test $# -eq 0
then
	Usage
fi
while getopts A:p:w:h o
do		
	case "$o" in
		
		A)AUTO_MODE="$OPTARG";;
		p)PROXY_FDN="$OPTARG";;
		w)PROXY_NEW_PWD="$OPTARG";;
		h)Usage;;
		[?]) Usage;;
	esac
done

AUTO_MODE=`echo $AUTO_MODE | tr '[:upper:]' '[:lower:]'`
if [ "$AUTO_MODE" = "no" ]
then
	if test "$PROXY_FDN" = "" 
	then
		echo "Enter Proxy user FDN (eg:cn=OESCommonProxy_<hostname>,o=novell)"
		read PROXY_FDN 
	fi
	if test "$PROXY_NEW_PWD" = ""
	then
		echo "Enter Proxy user New Password"
		mode=`stty -g`
		stty -echo
		read PROXY_NEW_PWD 
		stty $mode
	fi
	rm -f /tmp/proxy_user.txt
	PROXY_USER_FILE="/tmp/proxy_user.txt"
	echo "$PROXY_FDN" >> $PROXY_USER_FILE
	NEW_PWD="$PROXY_NEW_PWD"
		
elif [ "$AUTO_MODE" =  "yes" ]
then
	echo "[Status] Running the password change job automatically" >> $PROXY_LOGFILE
else
	echo ""
	echo "Invalid option for Automatic mode. Please give either yes or no."
	Usage
	exit 1
fi

echo "Retrieving the current common proxy username from OCS" >> $PROXY_LOGFILE
CP_FDN=`$CP_UTIL/cp_retrieve_proxy_cred username`

cmd="$CP_UTIL/cp_retrieve_proxy_cred username"
RetrieveOrUpdateProxyCredentials $cmd
RET_VAL=$?
echo "Retrieving the current common proxy username from OCS returned: $RET_VAL" >> $PROXY_LOGFILE
if [ $RET_VAL -ne 0 ]
then
	echo "ERROR: Retrieving the current common proxy username from OCS failed, exiting" >> $PROXY_LOGFILE
	logger -t `basename $0[$$]` "ERROR: Retrieving the current common proxy username from OCS failed"
        exit 1
fi
        
echo "`date`: [Status] Starting Change Password Task" >> $PROXY_LOGFILE

#This loop reads the proxy user DNs list one by one from the file /etc/opt/novell/proxymgmt/proxy_users.conf, changes the password for the proxy user and syncs all the services using the proxy #user
while read curr_user_fdn 
do
	echo "[Status] ENTRY =========>>> $curr_user_fdn" >> $PROXY_LOGFILE
	
	if [ "$curr_user_fdn" == "" ]
	then
		continue
	fi

	if [ "$NEW_PWD" == "" ]
	then
		#Generate the random password here.
		NEW_PWD=`$CP_UTIL/randpwd.sh`

	fi

	MATCHED=0	
	PASSWORD_CHANGED=0

	#check if the user is same as common proxy.
	if [ "`echo $CP_FDN | tr '[:upper:]' '[:lower:]'`" = "`echo $curr_user_fdn | tr '[:upper:]' '[:lower:]'`" ]
	then
		MATCHED=1
		echo "[Status] Current user is common proxy user" >> $PROXY_LOGFILE
		CURR_PWD=`$CP_UTIL/cp_retrieve_proxy_cred password`>> /dev/null 2>&1
		
		cmd="$CP_UTIL/cp_retrieve_proxy_cred password"
		RetrieveOrUpdateProxyCredentials $cmd
		RET_VAL=$?
		echo "Retrieving the current common proxy password from OCS returned: $RET_VAL" >> $PROXY_LOGFILE
		if [ $RET_VAL -ne 0 ]
		then
			echo "ERROR: Retrieving the current common proxy password from OCS failed, exiting" >> $PROXY_LOGFILE
			logger -t `basename $0[$$]` "ERROR: Retrieving the current common proxy password from OCS failed"
			exit 1
		fi
		
		#echo "[Status] current Common proxy password : $CURR_PWD" >> $PROXY_LOGFILE
		CP_FDN=`echo $CP_FDN | tr . ,`
		export OLD_PROXY_DATA="$CURR_PWD"
		export NEW_PROXY_DATA="$NEW_PWD"

		verifyNDSLogin "$CP_FDN" $CURR_PWD
		echo "NDS login successful. Calling change_pwd script to change the password in eDirectory" >> $PROXY_LOGFILE
		
		#Delete the temporary ldif file if it exists before changing the password in eDirectory. This check is added to provide the fix for the bug #859412
		if [ -f $TMP_ADD_PROXYUSER_LDIFFILE ]
		then
			rm $TMP_ADD_PROXYUSER_LDIFFILE
		fi
		
		cmd="$CP_UTIL/change_pwd.sh \"$CP_FDN\" $IP_ADDRESS 636"
		RetrieveOrUpdateProxyCredentials "$cmd"
		EDIR_UPDATE=$?
                if [ $EDIR_UPDATE -ne 0 ]
		then
                	echo "ERROR: Changing password (not based on policies) in eDirectory is failed, exiting" >> $PROXY_LOGFILE
			logger -t `basename $0[$$]` "ERROR: Changing password (not based on policies) in eDirectory is failed"
			echo "ERROR: Changing password (not based on policies) in eDirectory is failed. Refer to $PROXY_LOGFILE for more details"
	                exit 1
                fi

	        echo "The change_pwd script to change the password in eDirectory returned: $EDIR_UPDATE" >> $PROXY_LOGFILE
		
		if [[ ( $EDIR_UPDATE = 19 || $EDIR_UPDATE = 80 ) && $AUTO_MODE != "no" ]]
		then
			echo "Trying policy based password change for common proxy" >> $PROXY_LOGFILE
			NEW_PWD=`$CP_UTIL/randpolicypwd $IP_ADDRESS 636 1 $CP_FDN "$CURR_PWD" $CP_FDN`
			RAND_PWD=$?
			echo "randompolicypwd script returned: $RAND_PWD" >> $PROXY_LOGFILE
			if test $RAND_PWD == 0
			then
				export NEW_PROXY_DATA="$NEW_PWD"

				cmd="$CP_UTIL/change_pwd.sh \"$CP_FDN\" $IP_ADDRESS 636"
				RetrieveOrUpdateProxyCredentials $cmd
				EDIR_UPDATE=$?
				if [ $EDIR_UPDATE -ne 0 ]
				then
					echo "ERROR: Changing the policy based password in eDirectory is failed, exiting" >> $PROXY_LOGFILE
					logger -t `basename $0[$$]` "ERROR: Changing the policy based password in eDirectory is failed"
					exit 1
				fi
				echo "Changing policy based password in eDirectory returned: $EDIR_UPDATE " >>$PROXY_LOGFILE
			fi	
		fi
			
		unset NEW_PROXY_DATA
		if test $EDIR_UPDATE != 0
		then 
			echo "ERROR: New Password for Common Proxy is not changed in eDirectory due to error $EDIR_UPDATE" >> $PROXY_LOGFILE
			echo "Refer to $PROXY_LOGFILE for more details"
			logger -t `basename $0[$$]` "ERROR: New Password for Common Proxy is not changed in eDirectory due to error $EDIR_UPDATE"
			exit 1
		else	
			PASSWORD_CHANGED=1
			export OES_PROXY_DATA="$NEW_PWD"
			echo "Going to update the OCS with the new common proxy password." >> $PROXY_LOGFILE
		
			cmd="$CP_UTIL/cp_update_proxy_cred.sh \"$curr_user_fdn\""
			RetrieveOrUpdateProxyCredentials $cmd
			STORE_IN_OCS=$?
			if [ $STORE_IN_OCS -ne 0 ]
			then
                		echo "ERROR: Updating the changed common proxy password in OCS failed" >> $PROXY_LOGFILE
				logger -t `basename $0[$$]` "ERROR: Updating the changed common proxy password in OCS failed"
				break
                        fi
 			
			if test $STORE_IN_OCS == 0
			then
				echo "[Status] New Common proxy credentials got stored in OCS  successfully" >> $PROXY_LOGFILE
				echo "Common Proxy password is changed and stored in OCS successfully"
			else
				echo "ERROR: Failed to update new Common proxy credentials in OCS"
				logger -t `basename $0[$$]` "ERROR: Failed to update new Common proxy credentials in OCS"
				echo "Reverting the common proxy password in eDirectory to the old one" >> $PROXY_LOGFILE

				export NEW_PROXY_DATA="$CURR_PWD"
				export OLD_PROXY_DATA="$NEW_PWD"

				$CP_UTIL/change_pwd.sh "$CP_FDN" $IP_ADDRESS 636 
				CHANGE_PWD_RET=$?
				echo "Reverting the common proxy password in eDirectory to the old one returned: $CHANGE_PWD_RET"
				if [ $CHANGE_PWD_RET -eq 0 ]
				then 
					echo "Reverted the common proxy password in eDirectory, exiting" >> $PROXY_LOGFILE
				else 
					echo "ERROR: Failed to revert the common proxy password in eDirectory, return value $CHANGE_PWD_RET, exiting" >> $PROXY_LOGFILE
					logger -t `basename $0[$$]` "ERROR: Failed to revert the common proxy password in eDirectory"
				fi
	                        unset OES_PROXY_DATA
	                        unset OLD_PROXY_DATA
        	                unset NEW_PROXY_DATA
				exit 1
			fi
			unset OES_PROXY_DATA
			unset OLD_PROXY_DATA
			unset NEW_PROXY_DATA
			
		fi
	fi

	# Go through each service whether they are using the same proxy or not.
	#novell-afp
	#`logger` command will log the message into syslogs (/var/log/messages). `basename` logs the name of the script. [$$] logs the pid of the process running this script. This is added to 	# provide the fix for the bug #859412
		if [ -f "/opt/novell/afptcpd/bin/afp_retrieve_proxy_cred.sh" ];
		then	
			echo "Retrieving AFP proxy username" >> $PROXY_LOGFILE
			cmd="/opt/novell/afptcpd/bin/afp_retrieve_proxy_cred.sh username $PROXY_INFO_FILE"
			RetrieveOrUpdateProxyCredentials $cmd
			RET_VAL=$?
			echo "Retrieving AFP proxy username returned: $RET_VAL" >> $PROXY_LOGFILE
			
			if [ $RET_VAL -eq 0 ]
			then
				if [ -f $PROXY_INFO_FILE ];
				then
					read SRVC_PRXY < $PROXY_INFO_FILE
					rm $PROXY_INFO_FILE
				fi
				
				SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`	
				echo "[Debug] AFP Proxy FDN    - $SRVC_PRXY" >> $PROXY_LOGFILE
				echo "[Debug] current Proxy FDN - $curr_user_fdn" >> $PROXY_LOGFILE
		
				if [ "$SRVC_PRXY" != "" ]
				then
					if [ "`echo $SRVC_PRXY | tr '[:upper:]' '[:lower:]'`" = "`echo $curr_user_fdn | tr '[:upper:]' '[:lower:]'`" ]
					then 
						MATCHED=1
						echo "[Debug] AFP Proxy user matched with current entry" >> $PROXY_LOGFILE
						echo "[Status][`date`] Attempting to change the password for AFP Proxy user" >> $PROXY_LOGFILE
						echo "*****novell-afp************"	
						if test $PASSWORD_CHANGED == 0
						then
							SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`
					
							echo "Retrieving the AFP proxy password" >> $PROXY_LOGFILE
							cmd="/opt/novell/afptcpd/bin/afp_retrieve_proxy_cred.sh password $PROXY_INFO_FILE"
							RetrieveOrUpdateProxyCredentials $cmd
							RET_VAL=$?
							echo "Retrieving the AFP proxy password returned: $RET_VAL" >> $PROXY_LOGFILE
							
							if [ $RET_VAL -eq 0 ]
							then
							
									if [ -f $PROXY_INFO_FILE ];
									then
										read CURR_PWD < $PROXY_INFO_FILE
										#echo "[Debug] Current AFP Proxy Password: $CURR_PWD" >> $PROXY_LOGFILE
										rm $PROXY_INFO_FILE
									fi
									# update the new password in eDirectory.
									export OLD_PROXY_DATA="$CURR_PWD"
									export NEW_PROXY_DATA="$NEW_PWD"

									$CP_UTIL/change_pwd.sh "$SRVC_PRXY" $IP_ADDRESS 636 >> /dev/null 2>&1
									EDIR_UPDATE=$?

									if [[ ( $EDIR_UPDATE = 19 || $EDIR_UPDATE = 80 ) && $AUTO_MODE != "no" ]]
									then
										echo "Trying policy based password change for AFP" >> $PROXY_LOGFILE
										NEW_PWD=`$CP_UTIL/randpolicypwd $IP_ADDRESS 636 1 "$SRVC_PRXY" "$CURR_PWD" "$SRVC_PRXY"`
										RAND_PWD=$?
										if test $RAND_PWD == 0
										then
											export NEW_PROXY_DATA="$NEW_PWD"
											$CP_UTIL/change_pwd.sh "$SRVC_PRXY" $IP_ADDRESS 636  >> /dev/null 2>&1
											EDIR_UPDATE=$?
										fi
									fi
									if test $EDIR_UPDATE != 0
									then 
										echo "ERROR: Password is not changed for AFP proxy in eDirectory due to error $EDIR_UPDATE" >> $PROXY_LOGFILE
										echo "AFP Proxy Password eDir update is Failed"
										logger -t `basename $0[$$]` "ERROR: Password is not changed for AFP proxy in eDirectory due to error $EDIR_UPDATE"
									else	
										echo "[Status] New password is updated for AFP Proxy in eDirectory successfully" >> $PROXY_LOGFILE
										PASSWORD_CHANGED=1
									fi
									unset OLD_PROXY_DATA
									unset NEW_PROXY_DATA
							fi
							
						else
							echo "[Status] New password for AFP Proxy is already updated in eDirectory" >> $PROXY_LOGFILE
						fi
						#Update proxy creds only incase of eDir updation is successful.
						if test $PASSWORD_CHANGED == 1 
						then
							# update the new proxy credentials into OCS store.
							export OES_AFP_DATA="$NEW_PWD"

							echo "Updating the OCS with the new proxy credentials for AFP service" >> $PROXY_LOGFILE
							cmd="/opt/novell/afptcpd/bin/afp_update_proxy_cred.sh \"$curr_user_fdn\""
							RetrieveOrUpdateProxyCredentials $cmd
							RET_VAL=$?
							echo "Updating the OCS with the new proxy credentials for AFP service returned: $RET_VAL" >> $PROXY_LOGFILE
							
							if test $RET_VAL == 0
							then 
								echo "[Status] AFP Proxy credential store update is successful" >> $PROXY_LOGFILE
								echo "AFP Proxy credential store  update is successful"
							else
								echo "ERROR: Proxy credential store updation failed for AFP" >> $PROXY_LOGFILE
								echo "AFP Proxy cred store update is Failed"
								logger -t `basename $0[$$]` "ERROR: Proxy credential store updation failed for AFP"
							fi	
							unset OES_AFP_DATA
						fi
					else
						echo "[Status] Current proxy entry did not match with AFP Proxy" >> $PROXY_LOGFILE
					fi
					unset SRVC_PRXY
				fi
			else
				echo "ERROR: Retrieving the proxy user credentials of AFP has failed." >> $PROXY_LOGFILE
				logger -t `basename $0[$$]` "ERROR: Retrieving the proxy user credentials of AFP has failed"
			fi
		else
			echo "[Status] novell-afp not installed on this machine" >> $PROXY_LOGFILE
		fi	
	
	#novell-cifs
		#`logger` command will log the message into syslogs (/var/log/messages). `basename` logs the name of the script. [$$] logs the pid of the process running this script. This is 			# added to provide the #fix for the bug #859412
		if [ -f "/opt/novell/cifs/bin/cifs_retrieve_proxy_cred.sh" ];
		then	
                        echo "Retrieving CIFS proxy username" >> $PROXY_LOGFILE
			cmd="/opt/novell/cifs/bin/cifs_retrieve_proxy_cred.sh username $PROXY_INFO_FILE"
			RetrieveOrUpdateProxyCredentials $cmd
			RET_VAL=$?
                        echo "Retrieving the CIFS proxy username returned: $RET_VAL" >> $PROXY_LOGFILE
			
			if [ $RET_VAL -eq 0 ]
                        then
				if [ -f $PROXY_INFO_FILE ];
				then
					read SRVC_PRXY < $PROXY_INFO_FILE
					rm $PROXY_INFO_FILE
				fi
				SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`	
				echo "[Debug] CIFS Proxy FDN    - $SRVC_PRXY" >> $PROXY_LOGFILE
				echo "[Debug] current Proxy FDN - $curr_user_fdn" >> $PROXY_LOGFILE
		
				if [ "$SRVC_PRXY" != "" ]
				then
					if [ "`echo $SRVC_PRXY | tr '[:upper:]' '[:lower:]'`" = "`echo $curr_user_fdn | tr '[:upper:]' '[:lower:]'`" ]
					then 
						MATCHED=1
						echo "[Debug] CIFS Proxy user matched with current entry" >> $PROXY_LOGFILE
						echo "[Status][`date`] Attempting to change the password for CIFS Proxy user" >> $PROXY_LOGFILE
						echo "*****novell-cifs************"
						if test $PASSWORD_CHANGED == 0
						then
							SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`

							echo "Retrieving the CIFS proxy password" >> $PROXY_LOGFILE
							cmd="/opt/novell/cifs/bin/cifs_retrieve_proxy_cred.sh password $PROXY_INFO_FILE"
							RetrieveOrUpdateProxyCredentials $cmd
							RET_VAL=$?
							echo "Retrieving the CIFS proxy password returned: $RET_VAL" >> $PROXY_LOGFILE
							if [ $RET_VAL -eq 0 ]
							then
								if [ -f $PROXY_INFO_FILE ];
								then
									read CURR_PWD < $PROXY_INFO_FILE
									#echo "[Debug] Current CIFS Proxy Password: $CURR_PWD" >> $PROXY_LOGFILE
									rm $PROXY_INFO_FILE
								fi
								# update the new password in eDirectory.
								export OLD_PROXY_DATA="$CURR_PWD"
								export NEW_PROXY_DATA="$NEW_PWD"
								$CP_UTIL/change_pwd.sh "$SRVC_PRXY" $IP_ADDRESS 636 >> /dev/null 2>&1
								EDIR_UPDATE=$?
								if [[ ( $EDIR_UPDATE = 19 || $EDIR_UPDATE = 80 ) && $AUTO_MODE != "no" ]]
								then
									echo "Trying policy based password change for CIFS" >> $PROXY_LOGFILE
									NEW_PWD=`$CP_UTIL/randpolicypwd $IP_ADDRESS 636 1 "$SRVC_PRXY" "$CURR_PWD" "$SRVC_PRXY"`
									RAND_PWD=$?
									if test $RAND_PWD == 0
									then
										export NEW_PROXY_DATA="$NEW_PWD"
										$CP_UTIL/change_pwd.sh "$SRVC_PRXY" $IP_ADDRESS 636  >> /dev/null 2>&1
										EDIR_UPDATE=$?
									fi
								fi
								if test $EDIR_UPDATE != 0
								then 
									echo "ERROR: Password is not changed for CIFS proxy in eDirectory due to error $EDIR_UPDATE" >> $PROXY_LOGFILE
									echo "CIFS Proxy Password eDir update is Failed"
									logger -t `basename $0[$$]` "ERROR: Password is not changed for CIFS proxy in eDirectory due to error $EDIR_UPDATE"
								else	
									echo "[Status] New password is updated for CIFS Proxy in eDirectory successfully" >> $PROXY_LOGFILE
									PASSWORD_CHANGED=1
								fi
								unset OLD_PROXY_DATA
								unset NEW_PROXY_DATA
							fi
						else
							echo "[Status] New password for CIFS Proxy is already updated in eDirectory" >> $PROXY_LOGFILE
						fi
						#Update proxy creds only incase of eDir updation is successful.
						if test $PASSWORD_CHANGED == 1 
						then
							# update the new proxy credentials into OCS store.
							export OES_CIFS_DATA="$NEW_PWD"

							echo "Updating the OCS with the new proxy credentials for CIFS service" >> $PROXY_LOGFILE
							cmd="/opt/novell/cifs/bin/cifs_update_proxy_cred.sh \"$curr_user_fdn\""
							RetrieveOrUpdateProxyCredentials $cmd
							RET_VAL=$?
							echo "Updating the OCS with the new proxy credentials for CIFS service returned: $RET_VAL" >> $PROXY_LOGFILE
							if test $RET_VAL == 0
                                                        then
                                                                echo "[Status] CIFS Proxy credential store update is successful" >> $PROXY_LOGFILE
                                                                echo "CIFS Proxy credential store  update is successful"
                                                        else
 
								echo "ERROR: Proxy credential store updation failed for CIFS" >> $PROXY_LOGFILE
								echo "CIFS Proxy cred store update is Failed"
								logger -t `basename $0[$$]` "ERROR: Proxy credential store updation failed for CIFS"
							fi	
							unset OES_CIFS_DATA
						fi
			
					else
                                                echo "[Status] Current proxy entry did not match with CIFS Proxy" >> $PROXY_LOGFILE
                                        fi
					unset SRVC_PRXY
				fi
			else
				echo "ERROR: Retrieving the proxy user credentials of CIFS has failed." >> $PROXY_LOGFILE
				logger -t `basename $0[$$]` "ERROR: Retrieving the proxy user credentials of CIFS has failed."
			fi
		else
			echo "[Status] novell-cifs not installed on this machine" >> $PROXY_LOGFILE
		fi

	#novell-dns
	#`logger` command will log the message into syslogs (/var/log/messages). `basename` logs the name of the script. [$$] logs the pid of the process running this script. This is added to 	# provide the fix for the bug #859412
				
		if [ -f "/opt/novell/named/bin/dns_retrieve_proxy_cred" ];
		then	
                        echo "Retrieving DNS proxy username" >> $PROXY_LOGFILE
			cmd="/opt/novell/named/bin/dns_retrieve_proxy_cred username $PROXY_INFO_FILE"
			RetrieveOrUpdateProxyCredentials $cmd
			RET_VAL=$?
                        echo "Retrieving the DNS proxy username returned: $RET_VAL" >> $PROXY_LOGFILE
                        
			if [ $RET_VAL -eq 0 ]
                        then
				if [ -f $PROXY_INFO_FILE ];
				then
					read SRVC_PRXY < $PROXY_INFO_FILE
					rm $PROXY_INFO_FILE
				fi
				SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`	
			
				echo "[Debug] DNS Proxy FDN     -$SRVC_PRXY" >> $PROXY_LOGFILE
				echo "[Debug] current Proxy FDN -$curr_user_fdn" >> $PROXY_LOGFILE
			
				if [ "$SRVC_PRXY" != "" ]
				then
					if [ "`echo $SRVC_PRXY | tr '[:upper:]' '[:lower:]'`" = "`echo $curr_user_fdn | tr '[:upper:]' '[:lower:]'`" ]
					then 
						MATCHED=1
						echo "[Status] Current Proxy entry matched with DNS Proxy" >> $PROXY_LOGFILE
						echo "[Status] Attempting to change password for DNS proxy user" >> $PROXY_LOGFILE
						echo "*****novell-named************"

						if test $PASSWORD_CHANGED == 0
						then
							SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`
							echo "Retrieving DNS proxy password" >> $PROXY_LOGFILE
							cmd="/opt/novell/named/bin/dns_retrieve_proxy_cred password $PROXY_INFO_FILE"
							RetrieveOrUpdateProxyCredentials $cmd
							RET_VAL=$?
							echo "Retrieving the DNS proxy password returned: $RET_VAL" >> $PROXY_LOGFILE
							
							if [ $RET_VAL -eq 0 ]
							then
								if [ -f $PROXY_INFO_FILE ];
								then
									read CURR_PWD < $PROXY_INFO_FILE
									#echo "[Debug] Current DNS proxy password: $CURR_PWD" >> $PROXY_LOGFILE
									rm $PROXY_INFO_FILE
								fi
								# update the new password in eDirectory.
								export OLD_PROXY_DATA="$CURR_PWD"
								export NEW_PROXY_DATA="$NEW_PWD"
								$CP_UTIL/change_pwd.sh "$SRVC_PRXY" $IP_ADDRESS 636 >> /dev/null 2>&1
								EDIR_UPDATE=$?

								if [[ ( $EDIR_UPDATE = 19 || $EDIR_UPDATE = 80 ) && $AUTO_MODE != "no" ]]
								then
									echo "Trying policy based password change for DNS" >> $PROXY_LOGFILE
									NEW_PWD=`$CP_UTIL/randpolicypwd $IP_ADDRESS 636 1 "$SRVC_PRXY" "$CURR_PWD" "$SRVC_PRXY"`
									RAND_PWD=$?
									if test $RAND_PWD == 0
									then
										export NEW_PROXY_DATA='$NEW_PWD'
										$CP_UTIL/change_pwd.sh "$SRVC_PRXY" $IP_ADDRESS 636  >> /dev/null 2>&1
										EDIR_UPDATE=$?
									fi
								fi

								if test $EDIR_UPDATE != 0
								then 
									echo "ERROR: Password is not changed for DNS Proxy in eDirectory due to error $EDIR_UPDATE" >> $PROXY_LOGFILE
									echo "DNS Proxy password eDir Update is Failed."
									logger -t `basename $0[$$]` "ERROR: Password is not changed for DNS Proxy in eDirectory due to error $EDIR_UPDATE"
								else
									echo "[Status] New password is updated for DSN Proxy in eDirectory successfully" >> $PROXY_LOGFILE
									PASSWORD_CHANGED=1
								fi
								unset OLD_PROXY_DATA
								unset NEW_PROXY_DATA
							fi
						else
							echo "[Status] New password is already updated for DNS Proxy in eDirectory" >> $PROXY_LOGFILE
						fi

						# Update the proxy cred store only in
						# case of eDir update is successful.
						if test $PASSWORD_CHANGED == 1
						then
							# update the new proxy credentials into OCS store.
							export OES_DNS_DATA="$NEW_PWD"
							#$CP_UTIL/casafor_dns.sh $curr_user_fdn
							
							echo "Updating the OCS with the new proxy credentials for DNS service" >> $PROXY_LOGFILE
							cmd="/opt/novell/named/bin/dns_update_proxy_cred \"$curr_user_fdn\""
							RetrieveOrUpdateProxyCredentials $cmd
							RET_VAL=$?
							echo "Updating the OCS with the new proxy credentials for DNS service returned: $RET_VAL" >> $PROXY_LOGFILE
							
							if test $RET_VAL == 0
							then 
								echo "[Status] New proxy credentials got stored for DNS successfully" >> $PROXY_LOGFILE
								echo "DNS Proxy Password update is Successful."
							else
								echo "ERROR: Proxy credentials updation failed for DNS" >> $PROXY_LOGFILE
								echo "DNS Proxy cred store Update in cred store is Failed."
								logger -t `basename $0[$$]` "ERROR: Proxy credentials updation failed for DNS"
							fi
							unset OES_DNS_DATA
						fi
					else
                                                echo "[Status] Current proxy entry did not match with DNS Proxy" >> $PROXY_LOGFILE
                                        fi
					unset SRVC_PRXY
				fi
			else
				echo "ERROR: Retrieving the proxy user credentials of DNS has failed." >> $PROXY_LOGFILE
				logger -t `basename $0[$$]` "ERROR: Retrieving the proxy user credentials of DNS has failed."
			fi
		else
			echo "[Status] novell-named not installed on this machine" >> $PROXY_LOGFILE
		fi
	
	#novell-dhcp
	#`logger` command will log the message into syslogs (/var/log/messages). `basename` logs the name of the script. [$$] logs the pid of the process running this script. This is added to 	# provide the fix for the bug #859412
	
		if [ -f "/opt/novell/dhcp/bin/dhcp_retrieve_proxy_cred" ];
		then	
			echo "Retrieving DHCP proxy username" >> $PROXY_LOGFILE    
			cmd="/opt/novell/dhcp/bin/dhcp_retrieve_proxy_cred username $PROXY_INFO_FILE"
			RetrieveOrUpdateProxyCredentials $cmd
			RET_VAL=$?                    
                        echo "Retrieving the DHCP proxy username returned: $RET_VAL" >> $PROXY_LOGFILE
                        
			if [ $RET_VAL -eq 0 ]
                        then
				if [ -f $PROXY_INFO_FILE ];
				then
					read SRVC_PRXY < $PROXY_INFO_FILE
					rm $PROXY_INFO_FILE
				fi
				SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`	
				echo "[Debug] DHCP Proxy FDN    -$SRVC_PRXY" >> $PROXY_LOGFILE
				echo "[Debug] current Proxy FDN -$curr_user_fdn" >> $PROXY_LOGFILE
			
				if [ "$SRVC_PRXY" != "" ]
				then
					if [ "`echo $SRVC_PRXY | tr '[:upper:]' '[:lower:]'`" = "`echo $curr_user_fdn | tr '[:upper:]' '[:lower:]'`" ]
					then 
						MATCHED=1
						echo "[Debug] current proxy entry is matched with DHCP Proxy" >> $PROXY_LOGFILE
						echo "[Status][`date`] Attempting to change the password for DHCP Proxy user" >> $PROXY_LOGFILE
						echo "*****Novell DHCP************"

						if test $PASSWORD_CHANGED == 0
						then
							SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`
							#CURR_PWD=`$CP_UTIL/retrieve_proxy_creds_dns password`

							echo "Retrieving DHCP proxy password" >> $PROXY_LOGFILE
							cmd="/opt/novell/dhcp/bin/dhcp_retrieve_proxy_cred password $PROXY_INFO_FILE"
							RetrieveOrUpdateProxyCredentials $cmd
							RET_VAL=$?
							echo "Retrieving the DHCP proxy password returned: $RET_VAL" >> $PROXY_LOGFILE
							
							if [ $RET_VAL -eq 0 ]
							then
								if [ -f $PROXY_INFO_FILE ];
								then
									read CURR_PWD < $PROXY_INFO_FILE
									#echo "[Debug] Current DHCP Proxy Password: $CURR_PWD" >> $PROXY_LOGFILE
									rm $PROXY_INFO_FILE
								fi
								# update the new password in eDirectory.
								export OLD_PROXY_DATA="$CURR_PWD"
								export NEW_PROXY_DATA="$NEW_PWD"
								$CP_UTIL/change_pwd.sh "$SRVC_PRXY" $IP_ADDRESS 636 >> /dev/null 2>&1
								EDIR_UPDATE=$?
								if [[ ( $EDIR_UPDATE = 19 || $EDIR_UPDATE = 80 ) && $AUTO_MODE != "no" ]]
								then
									echo "Trying policy based password change for DHCP" >> $PROXY_LOGFILE
									NEW_PWD=`$CP_UTIL/randpolicypwd $IP_ADDRESS 636 1 "$SRVC_PRXY" "$CURR_PWD" "$SRVC_PRXY"`
									RAND_PWD=$?
									if test $RAND_PWD == 0
									then
										export NEW_PROXY_DATA="$NEW_PWD"
										$CP_UTIL/change_pwd.sh "$SRVC_PRXY" $IP_ADDRESS 636  >> /dev/null 2>&1
										EDIR_UPDATE=$?
									fi
								fi
								if test $EDIR_UPDATE != 0
								then 
									echo "ERROR: Password is not changed for DHCP Proxy in eDirectory due to error $EDIR_UPDATE" >> $PROXY_LOGFILE
									echo "DHCP Proxy password eDir update is Failed."
									logger -t `basename $0[$$]` "ERROR: Password is not changed for DHCP Proxy in eDirectory due to error $EDIR_UPDATE"
								else
									echo "[Status] New password is updated for DHCP Proxy in eDirectory successfully" >> $PROXY_LOGFILE
									PASSWORD_CHANGED=1
								fi
								unset OLD_PROXY_DATA
								unset NEW_PROXY_DATA
							fi
						else
							echo "[Status] New password is already updated for DHCP Proxy in eDirectory" >> $PROXY_LOGFILE
						fi

						if test $PASSWORD_CHANGED == 1
						then
							# update the new proxy credentials into its credential store.
							export OES_DHCP_DATA="$NEW_PWD"
							echo "Updating the OCS with the new proxy credentials for DHCP service" >> $PROXY_LOGFILE
							cmd="/opt/novell/dhcp/bin/dhcp_update_proxy_cred.sh \"$curr_user_fdn\""
							RetrieveOrUpdateProxyCredentials $cmd
							RET_VAL=$?
							echo "Updating the OCS with the new proxy credentials for DHCP service returned: $RET_VAL" >> $PROXY_LOGFILE
							if test $RET_VAL == 0
							then 
								echo "[Status] New proxy credentials got stored for DHCP successfully" >> $PROXY_LOGFILE
								echo "DHCP Proxy Password update is successful."
							else
								echo "ERROR: Proxy credentials updation failed for DHCP" >> $PROXY_LOGFILE
								echo "DHCP Proxy password cred store update is Failed."
								logger -t `basename $0[$$]` "ERROR: Proxy credentials updation failed for DHCP"
							fi
							unset OES_DHCP_DATA
						fi

					else
                                                echo "[Status] Current proxy entry did not match with DHCP Proxy" >> $PROXY_LOGFILE
                                        fi
					unset SRVC_PRXY
				fi
			else
				echo "ERROR: Retrieving the proxy user credentials of DHCP has failed." >> $PROXY_LOGFILE
				logger -t `basename $0[$$]` "ERROR: Retrieving the proxy user credentials of DHCP has failed."
			fi
		else
			echo "[Status] Novell DHCP not installed on this machine" >> $PROXY_LOGFILE
		fi

	#NetStorage
	#`logger` command will log the message into syslogs (/var/log/messages). `basename` logs the name of the script. [$$] logs the pid of the process running this script. This is added to 	# provide the fix for the bug #859412
        
		chmod 666 $PROXY_LOGFILE
		if [ -f "/opt/novell/netstorage/bin/ns_retrieve_proxy_cred" ];
		then
			echo "Retrieving NetStorage proxy username" >> $PROXY_LOGFILE
			cmd="/opt/novell/netstorage/bin/ns_retrieve_proxy_cred username $PROXY_INFO_FILE"
			RetrieveOrUpdateProxyCredentials $cmd
			RET_VAL=$?
                        echo "Retrieving the NetStorage proxy username returned: $RET_VAL" >> $PROXY_LOGFILE
                        
			if [ $RET_VAL -eq 0 ]
                        then
				if [ -f $PROXY_INFO_FILE ];
				then
					read SRVC_PRXY < $PROXY_INFO_FILE
					rm $PROXY_INFO_FILE
				fi
				SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`	
				echo "[Debug] NetStorage proxy FDN - $SRVC_PRXY" >> $PROXY_LOGFILE
				echo "[Debug] current proxy FDN    - $curr_user_fdn" >> $PROXY_LOGFILE

				if [ "$SRVC_PRXY" != "" ]
				then
					if [ "`echo $SRVC_PRXY | tr '[:upper:]' '[:lower:]'`" = "`echo $curr_user_fdn | tr '[:upper:]' '[:lower:]'`" ]
					then 
						MATCHED=1
						echo "[Debug] Current Proxy entry matched with NetStorage Proxy" >> $PROXY_LOGFILE
						echo "[Status][`date`] Attempting to change password for NetStorage Proxy" >> $PROXY_LOGFILE	
						echo "*****Novell NetStorage************"

						if test $PASSWORD_CHANGED == 0
						then
							SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`
							echo "Retrieving NetStorage proxy password" >> $PROXY_LOGFILE
							cmd="/opt/novell/netstorage/bin/ns_retrieve_proxy_cred password $PROXY_INFO_FILE"
							RetrieveOrUpdateProxyCredentials $cmd
							RET_VAL=$?
							echo "Retrieving the NetStorage proxy password returned: $RET_VAL" >> $PROXY_LOGFILE
							
							if [ $RET_VAL -eq 0 ]
							then
								if [ -f $PROXY_INFO_FILE ];
								then
									read CURR_PWD < $PROXY_INFO_FILE
									#echo "[Debug] Current NetStorage Proxy Password: $CURR_PWD" >> $PROXY_LOGFILE
									rm $PROXY_INFO_FILE
								fi
								# update the new password in eDirectory.
								export OLD_PROXY_DATA="$CURR_PWD"
								export NEW_PROXY_DATA="$NEW_PWD"
								$CP_UTIL/change_pwd.sh "$SRVC_PRXY" $IP_ADDRESS 636 >> /dev/null 2>&1
								EDIR_UPDATE=$?
								if [[ ( $EDIR_UPDATE = 19 || $EDIR_UPDATE = 80 ) && $AUTO_MODE != "no" ]]
								then
									echo "Trying policy based password change for NetStorage" >> $PROXY_LOGFILE
									NEW_PWD=`$CP_UTIL/randpolicypwd $IP_ADDRESS 636 1 "$SRVC_PRXY" "$CURR_PWD" "$SRVC_PRXY"`
									RAND_PWD=$?
									if test $RAND_PWD == 0
									then
										export NEW_PROXY_DATA="$NEW_PWD"
										$CP_UTIL/change_pwd.sh "$SRVC_PRXY" $IP_ADDRESS 636  >> /dev/null 2>&1
										EDIR_UPDATE=$?
									fi
								fi
								if test $EDIR_UPDATE != 0
								then 
									echo "ERROR: Password is not changed for NetStorage Proxy in eDirectory due to error $EDIR_UPDATE" >> $PROXY_LOGFILE
									echo "NetStorage Proxy Password eDir update is Failed."
									logger -t `basename $0[$$]` "ERROR: Password is not changed for NetStorage Proxy in eDirectory due to error $EDIR_UPDATE"
								else
									echo "[Status] New password is updated for NetStorage Proxy in eDirectory successfully" >> $PROXY_LOGFILE
									PASSWORD_CHANGED=1
								fi
								unset OLD_PROXY_DATA
								unset NEW_PROXY_DATA
							fi
						else
							echo "New password is already updated in eDirectory" >> $PROXY_LOGFILE
						fi

						if test $PASSWORD_CHANGED == 1
						then
							# update the new proxy credentials into OCS store.
							export OES_NETSTORAGE_DATA="$NEW_PWD"
							
							echo "Updating the OCS with the new proxy credentials for NetStorage service" >> $PROXY_LOGFILE
							cmd="/opt/novell/netstorage/bin/ns_update_proxy_cred "$SRVC_PRXY""
							RetrieveOrUpdateProxyCredentials $cmd
							RET_VAL=$?
							echo "Updating the OCS with the new proxy credentials for NetStorage service returned: $RET_VAL" >> $PROXY_LOGFILE
							
							if test $RET_VAL == 0
							then 
								echo "[Status] New proxy credentials got stored for NetStorage successfully" >> $PROXY_LOGFILE
								echo "NetStorage Proxy password update is successful."
							else
								echo "ERROR: Proxy credentials updation failed for NetStorage" >> $PROXY_LOGFILE
								echo "NetStorage Proxy cred store update is Failed."
								logger -t `basename $0[$$]` "ERROR: Proxy credentials updation failed for NetStorage"
							fi
							unset OES_NETSTORAGE_DATA
						fi
					else
						echo "[Status] Current proxy entry did not match with NetStorage Proxy" >> $PROXY_LOGFILE

					fi
					unset SRVC_PRXY
				fi
			else
				echo "ERROR: Retrieving the proxy user credentials of NetStorage has failed." >> $PROXY_LOGFILE
				logger -t `basename $0[$$]` "ERROR: Retrieving the proxy user credentials of NetStorage has failed."
			fi
		else
			echo "[Status] NetStorage not installed on this machine" >> $PROXY_LOGFILE
		fi
		chmod 644 $PROXY_LOGFILE

	#NCS
	#`logger` command will log the message into syslogs (/var/log/messages). `basename` logs the name of the script. [$$] logs the pid of the process running this script. This is added to 	# provide the fix for the bug #859412
	
		if [ -f "/opt/novell/ncs/bin/ncs_retrieve_proxy_cred" ];
		then
			echo "Retrieving NCS proxy username" >> $PROXY_LOGFILE
			cmd="/opt/novell/ncs/bin/ncs_retrieve_proxy_cred username $PROXY_INFO_FILE"
			RetrieveOrUpdateProxyCredentials $cmd
			RET_VAL=$?
                        echo "Retrieving the NCS proxy username returned: $RET_VAL" >> $PROXY_LOGFILE

			if [ $RET_VAL -eq 0 ]
                        then
				if [ -f $PROXY_INFO_FILE ];
				then
					read SRVC_PRXY < $PROXY_INFO_FILE
					rm $PROXY_INFO_FILE
				fi
				SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`
				echo "[Debug] NCS Proxy FDN     -$SRVC_PRXY" >> $PROXY_LOGFILE
				echo "[Debug] current Proxy FDN -$curr_user_fdn" >> $PROXY_LOGFILE
			
				if [ "$SRVC_PRXY" != "" ]
				then
					if [ "`echo $SRVC_PRXY | tr '[:upper:]' '[:lower:]'`" = "`echo $curr_user_fdn | tr '[:upper:]' '[:lower:]'`" ]
					then 
						MATCHED=1
						echo "[Debug] Current proxy entry matched with NCS proxy" >> $PROXY_LOGFILE
						echo "[Status][`date`] Attempting to change password for NCS Proxy" >> $PROXY_LOGFILE
						echo "*****Novell Cluster Services************"

						if test $PASSWORD_CHANGED == 0
						then
							SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`
							echo "Retrieving NCS proxy password" >> $PROXY_LOGFILE
							cmd="/opt/novell/ncs/bin/ncs_retrieve_proxy_cred password $PROXY_INFO_FILE"
							RetrieveOrUpdateProxyCredentials $cmd
							RET_VAL=$?
							echo "Retrieving the NCS proxy password returned: $RET_VAL" >> $PROXY_LOGFILE
							
							if [ $RET_VAL -eq 0 ]
							then
								if [ -f $PROXY_INFO_FILE ];
								then
									read CURR_PWD < $PROXY_INFO_FILE
									#echo "[Debug] Current NCS Proxy Password: $CURR_PWD" >> $PROXY_LOGFILE
									rm $PROXY_INFO_FILE
								fi
								# update the new password in eDirectory.
								export OLD_PROXY_DATA="$CURR_PWD"
								export NEW_PROXY_DATA="$NEW_PWD"
								$CP_UTIL/change_pwd.sh "$SRVC_PRXY" $IP_ADDRESS 636 >> /dev/null 2>&1
								EDIR_UPDATE=$?
								if [[ ( $EDIR_UPDATE = 19 || $EDIR_UPDATE = 80 ) && $AUTO_MODE != "no" ]]
								then
									echo "Trying policy based password change for NCS" >> $PROXY_LOGFILE
									NEW_PWD=`$CP_UTIL/randpolicypwd $IP_ADDRESS 636 1 "$SRVC_PRXY" "$CURR_PWD" "$SRVC_PRXY"`
									RAND_PWD=$?
									if test $RAND_PWD == 0
									then
										export NEW_PROXY_DATA="$NEW_PWD"
										$CP_UTIL/change_pwd.sh "$SRVC_PRXY" $IP_ADDRESS 636  >> /dev/null 2>&1
										EDIR_UPDATE=$?
									fi
								fi
								if test $EDIR_UPDATE != 0
								then 
									echo "ERROR: Password is not changed for NCS Proxy in eDirectory due to error $EDIR_UPDATE" >> $PROXY_LOGFILE
									echo "NCS proxy password eDir update is Failed."
									logger -t `basename $0[$$]` "ERROR: Password is not changed for NCS Proxy in eDirectory due to error $EDIR_UPDATE"
								else
									echo "[Status] New password is updated for NCS Proxy in eDirectory successfully" >> $PROXY_LOGFILE
									PASSWORD_CHANGED=1
								fi
								unset OLD_PROXY_DATA
								unset NEW_PROXY_DATA
							fi
						else
							echo "[Status] New password is already updated for NCS Proxy in eDirectory" >> $PROXY_LOGFILE
						fi

						if test $PASSWORD_CHANGED == 1
						then
							# update the new proxy credentials into OCS store.
							export OES_NCS_DATA="$NEW_PWD"
							echo "Updating the OCS with the new proxy credentials for NCS service" >> $PROXY_LOGFILE
							cmd="/opt/novell/ncs/bin/ncs_update_proxy_cred \"$curr_user_fdn\""
							RetrieveOrUpdateProxyCredentials $cmd
							RET_VAL=$?
							echo "Updating the OCS with the new proxy credentials for NCS service returned: $RET_VAL" >> $PROXY_LOGFILE
							if test $RET_VAL == 0
							then 
								echo "[Status] New proxy credentials got stored for NCS successfully" >> $PROXY_LOGFILE
								echo "NCS Proxy password update is successful."
							else
								echo "ERROR: Proxy credentials updation failed for NCS" >> $PROXY_LOGFILE
								echo "NCS proxy cred store update is Failed."
								logger -t `basename $0[$$]` "ERROR: Proxy credentials updation failed for NCS"
							fi
							unset OES_NCS_DATA
						fi	
					else
                                                echo "[Status] Current proxy entry did not match with NCS Proxy" >> $PROXY_LOGFILE

                                        fi
					unset SRVC_PRXY
				fi
			else
				echo "ERROR: Retrieving the proxy user credentials of NCS has failed." >> $PROXY_LOGFILE
				logger -t `basename $0[$$]` "ERROR: Retrieving the proxy user credentials of NCS has failed."
			fi
		else
			echo "[Status] NCS not installed on this machine" >> $PROXY_LOGFILE
		fi

	#LUM
	#`logger` command will log the message into syslogs (/var/log/messages). `basename` logs the name of the script. [$$] logs the pid of the process running this script. This is added to 	# provide the fix for the bug #859412
	
		if [ -f "/usr/sbin/namcd" ];
		then	
			#SRVC_PRXY=`$CP_UTIL/lum_retrieve_proxy_cred username`
			echo "Retrieving LUM proxy username" >> $PROXY_LOGFILE
			cmd="/usr/bin/lum_retrieve_proxy_cred username $PROXY_INFO_FILE"
			RetrieveOrUpdateProxyCredentials $cmd
			RET_VAL=$?
                        echo "Retrieving LUM proxy username returned: $RET_VAL" >> $PROXY_LOGFILE

                        if [ $RET_VAL -eq 0 ]
                        then
				if [ -f $PROXY_INFO_FILE ];
				then
					read SRVC_PRXY < $PROXY_INFO_FILE
					rm $PROXY_INFO_FILE
				fi
				SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`
				echo "[Debug] LUM Proxy FDN     - $SRVC_PRXY" >> $PROXY_LOGFILE
				echo "[Debug] current Proxy FDN - $curr_user_fdn" >> $PROXY_LOGFILE
			
				if [ "$SRVC_PRXY" != "" ]
				then
					if [ "`echo $SRVC_PRXY | tr '[:upper:]' '[:lower:]'`" = "`echo $curr_user_fdn | tr '[:upper:]' '[:lower:]'`" ]
					then 
						MATCHED=1
						echo "[Debug] Current proxy entry matched with LUM Proxy" >> $PROXY_LOGFILE
						echo "[Status][`date`] Attempting to change password for LUM proxy" >> $PROXY_LOGFILE
						echo "******* Novell LUM service ********"

						if test $PASSWORD_CHANGED == 0
						then
							SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`
							echo "Retrieving LUM proxy password" >> $PROXY_LOGFILE
							cmd="/usr/bin/lum_retrieve_proxy_cred password $PROXY_INFO_FILE"
							RetrieveOrUpdateProxyCredentials $cmd
							RET_VAL=$?
							echo "Retrieving the LUM proxy password returned: $RET_VAL" >> $PROXY_LOGFILE

							if [ $RET_VAL -eq 0 ]
							then
								if [ -f $PROXY_INFO_FILE ];
								then
									read CURR_PWD < $PROXY_INFO_FILE
									#echo "[Debug] Current LUM Password: $CURR_PWD" >> $PROXY_LOGFILE
									rm $PROXY_INFO_FILE
								fi

								# update the new password in eDirectory.
								export OLD_PROXY_DATA="$CURR_PWD"
								export NEW_PROXY_DATA="$NEW_PWD"
								$CP_UTIL/change_pwd.sh "$SRVC_PRXY" $IP_ADDRESS 636 >> /dev/null 2>&1
								EDIR_UPDATE=$?
								if [[ ( $EDIR_UPDATE = 19 || $EDIR_UPDATE = 80 ) && $AUTO_MODE != "no" ]]
								then
									echo "Trying policy based password change for LUM" >> $PROXY_LOGFILE
									NEW_PWD=`$CP_UTIL/randpolicypwd $IP_ADDRESS 636 1 "$SRVC_PRXY" "$CURR_PWD" "$SRVC_PRXY"`
									RAND_PWD=$?
									if test $RAND_PWD == 0
									then
										export NEW_PROXY_DATA="$NEW_PWD"
										$CP_UTIL/change_pwd.sh "$SRVC_PRXY" $IP_ADDRESS 636  >> /dev/null 2>&1
										EDIR_UPDATE=$?
									fi
								fi
								if test $EDIR_UPDATE != 0
								then 
									echo "ERROR: Password is not changed for LUM proxy in eDirectory due to error $EDIR_UPDATE" >> $PROXY_LOGFILE
									echo "Novell LUM Proxy password eDir update is Failed."
									logger -t `basename $0[$$]` "ERROR: Password is not changed for LUM proxy in eDirectory due to error $EDIR_UPDATE"
								else
									echo "[Status] New password is updated for LUM Proxy in eDirectory successfully" >> $PROXY_LOGFILE
									PASSWORD_CHANGED=1
								fi
								unset OLD_PROXY_DATA
								unset NEW_PROXY_DATA
							fi
						else
							echo "[Status] New password is already updated for LUM Proxy in eDirectory" >> $PROXY_LOGFILE
						fi
						

						if test $PASSWORD_CHANGED == 1
						then
							# update the new proxy credentials into OCS store.
							export OES_LUM_DATA="$NEW_PWD"
							
							echo "Updating the OCS with the new proxy credentials of LUM service" >> $PROXY_LOGFILE
							cmd="/var/lib/novell-lum/lum_update_proxy_cred.sh \"$curr_user_fdn\""
							RetrieveOrUpdateProxyCredentials $cmd
							RET_VAL=$?
							echo "Updating the OCS with the new proxy credentials for LUM service returned: $RET_VAL" >> $PROXY_LOGFILE
							
							if test $RET_VAL == 0
							then 
								echo "[Status] New proxy credentials got stored in LUM OCS successfully" >> $PROXY_LOGFILE
								echo "Novell LUM Proxy password update is successful."
							else
								echo "ERROR: New Proxy credential updation failed for LUM" >> $PROXY_LOGFILE
								echo "Novell LUM Proxy cred store update is Failed."
								logger -t `basename $0[$$]` "ERROR: New Proxy credential updation failed for LUM"
							fi
							unset OES_LUM_DATA
						fi
					else
						echo "[Status] Curret proxy entry not matched with LUM proxy" >> $PROXY_LOGFILE

					fi
					unset SRVC_PRXY
				fi
			elif [ $RET_VAL -eq 2 ]
			then
				echo "LUM is not configured to use Common Proxy on this server." >> $PROXY_LOGFILE
				logger -t `basename $0[$$]` "LUM is not configured to use Common Proxy on this server."
			else		
				echo "ERROR: Retrieving the proxy user credentials of LUM has failed." >> $PROXY_LOGFILE
				logger -t `basename $0[$$]` "ERROR: Retrieving the proxy user credentials of LUM has failed."
			fi
		else
			echo "[Status] novell-LUM not installed on this machine" >> $PROXY_LOGFILE
		fi


if test $MATCHED == 0
then
	echo "ERROR: current proxy user FDN does not match with common proxy FDN or with any other service proxies' FDN" >> $PROXY_LOGFILE
	logger -t `basename $0[$$]` "ERROR: current proxy user FDN does not match with common proxy FDN or with any other service proxies' FDN"
fi
NEW_PWD=""
done < $PROXY_USER_FILE

if [ "$AUTO_MODE" = "no" ]
then
	rm -f /tmp/proxy_user.txt 
fi
unset LDAPTLS_REQCERT
echo "Proxy password change task is completed. Refer to $PROXY_LOGFILE for more details"
