#!/bin/sh
# This script is used to change the password for the provided common
# proxy user in eDirectory and oescredstore during upgrade.

user_id=`id -u`
if test $user_id -ne 0
then 
        echo "change_pwd_upgrade.sh : Only root user can run this script"
        exit 1
fi

#fips disable
/bin/rpm -q novell-xad-framework > /dev/null 2>&1
if test $? ==  0
then
	/usr/bin/grep -i "^n4u.server.fips_tls=" /etc/opt/novell/eDirectory/conf/nds.conf
	if test $? -eq 0
	then
		/usr/bin/sed -i -e 's/^n4u.server.fips_tls=[0-9]/n4u.server.fips_tls=0/g' /etc/opt/novell/eDirectory/conf/nds.conf
		if test $? -ne 0
		then
			echo "Unable to disable the fips mode. Check the /etc/opt/novell/eDirectory/conf/nds.conf file."
		fi
		systemctl restart ndsd.service
		
	fi
fi
		
CP_UTIL="/opt/novell/proxymgmt/bin"
PROXY_LOGFILE="/var/opt/novell/log/proxymgmt/pxymgmt.log"
TMP_ADD_PROXYUSER_LDIFFILE="/tmp/change_pwd.ldif"
LDAP_SEC_CERT="env LDAPTLS_CACERT=/etc/opt/novell/certs/SSCert.pem"
LDAP_MODIFY_BINARY="/usr/bin/ldapmodify"

getIp(){
	file=/var/opt/novell/eDirectory/data/ldap_listeners.txt
	ldaps_ip="127.0.0.1"

	if [ -f "$file" ]
	then
		ldaps_ip_port=`grep -Po -m 1 "(?<=n4u.ldap.interfaces.ldaps =).*" "$file"`
		ldaps_ip_port=$(echo $ldaps_ip_port | sed -e 's/[\r\n]//g')
		if [ ! -z ldaps_ip_port ]
		then
			IFS=':' read -r -a ip_array <<< "$ldaps_ip_port"
			if [ ${ip_array[0]} != "0.0.0.0" ]
			then
				ldaps_ip=${ip_array[0]}
				ldaps_port=${ip_array[1]}
			fi
		fi
	fi
	echo "$ldaps_ip"
	return 0
}

IP_ADDRESS=$(getIp)

Usage() 
{
	echo ""
	echo "Usage: change_pwd_upgrade.sh [options]"
	echo "		-h			Prints this summary"
	echo "		-u			Proxy user FDN"
	echo "		-p			Admin FDN"
	echo ""
	echo "		example:./change_pwd_upgrade.sh -u <Proxy user FDN> -p <Admin FDN> "
	echo ""
	exit 1;
}

# This function modifies the common proxy user password in eDirectory.

changePasswordInNDS()
{
	echo "Going to change the password in eDirectory"
        mkdir -p /tmp
        touch $TMP_ADD_PROXYUSER_LDIFFILE
        echo "dn: "$1 >> $TMP_ADD_PROXYUSER_LDIFFILE
        echo "changetype: modify" >> $TMP_ADD_PROXYUSER_LDIFFILE
        echo "replace: userpassword" >> $TMP_ADD_PROXYUSER_LDIFFILE
        echo "userPassword: "$NEW_PROXY_DATA >> $TMP_ADD_PROXYUSER_LDIFFILE
        echo "ldapmodify command going to be executed is $LDAP_SEC_CERT $LDAP_MODIFY_BINARY -f $TMP_ADD_PROXYUSER_LDIFFILE -D "$2" -w -H ldaps://$IP_ADDRESS:636 " >> $PROXY_LOGFILE
        $LDAP_SEC_CERT $LDAP_MODIFY_BINARY -f $TMP_ADD_PROXYUSER_LDIFFILE -D "$2" -w "$3" -H "ldaps://$IP_ADDRESS:636" >> $PROXY_LOGFILE 2>&1
        export PASSWORD_CHANGE=$?
        echo "ldapmodify return value is: $PASSWORD_CHANGE" >> $PROXY_LOGFILE
	rm $TMP_ADD_PROXYUSER_LDIFFILE
        return "$PASSWORD_CHANGE"  
}


if test $# -eq 0
then
	Usage
fi
while getopts u:p:h o
do		
	case "$o" in
		
		u)PROXY_FDN="$OPTARG";;
		p)ADMIN_FDN="$OPTARG";;
		h)Usage;;
		[?]) Usage;;
	esac
done

	if test "$PROXY_FDN" = "" 
	then
		echo "Enter Proxy user FDN (eg:cn=OESCommonProxy_<hostname>,o=novell)"
		read PROXY_FDN 
	fi
	 if test "$ADMIN_FDN" = ""
        then
                echo "Enter Admin FDN (eg:cn=admin_<hostname>,o=novell)"
                read PROXY_FDN
        fi
		
echo "`date`: [Status] Starting Change Password For Upgrade Task" >> $PROXY_LOGFILE

#Generate the random password here.
NEW_PWD=`$CP_UTIL/randpwd.sh`
ADMIN_PWD=$OES_DATA
export NEW_PROXY_DATA="$NEW_PWD"

#Delete the temporary ldif file if it exists before changing the password in eDirectory.
if [ -f $TMP_ADD_PROXYUSER_LDIFFILE ]
then
	rm $TMP_ADD_PROXYUSER_LDIFFILE
fi
		
changePasswordInNDS "$PROXY_FDN" "$ADMIN_FDN" "$ADMIN_PWD" 
EDIR_UPDATE=$?
echo "The changePaswordInNDS to change the password in eDirectory returned: $EDIR_UPDATE" >> $PROXY_LOGFILE
		
unset NEW_PROXY_DATA
if test $EDIR_UPDATE != 0
then 
	echo "ERROR: New Password for Common Proxy is not changed in eDirectory due to error $EDIR_UPDATE during upgrade." >> $PROXY_LOGFILE
	echo "Refer to $PROXY_LOGFILE for more details"
	logger -t `basename $0[$$]` "ERROR: New Password for Common Proxy is not changed in eDirectory due to error $EDIR_UPDATE during upgrade."
	exit 1
else	
	export OES_PROXY_DATA="$NEW_PWD"
	echo "Going to update the OCS with the new common proxy password for upgrade." >> $PROXY_LOGFILE
	$CP_UTIL/cp_update_proxy_cred.sh "$PROXY_FDN"
        STORE_IN_OCS=$?

	if test $STORE_IN_OCS == 0
	then
		echo "[Status] New Common proxy credentials got stored in OCS successfully for upgrade" >> $PROXY_LOGFILE
		echo "Common Proxy password is changed and stored in OCS successfully for upgrade"
	else
		echo "ERROR: Failed to update new Common proxy credentials in OCS for upgrade"
		logger -t `basename $0[$$]` "ERROR: Failed to update new Common proxy credentials in OCS for upgrade"
	        unset OES_PROXY_DATA
		exit 1
	fi
	unset OES_PROXY_DATA
fi
echo "Proxy password change task for upgrade is completed. Refer to $PROXY_LOGFILE for more details"
