#!/bin/sh
#
#Copyright (c) 2010, Novell, Inc.  All rights reserved.
#
#Script to create a common proxy password policy.
#It uses the standard FDN for password policy.
#"cn=Common_Proxy_Policy,cn=Password Policies,cn=Security"
# Bind password will be read from env variable OES_DATA

user_id=`id -u`
if test $user_id -ne 0
then 
	echo "create_common_proxypolicy.sh : Only root user can run this script"
	exit 1
fi

if test $# != 3 
then
	echo "Usage: create_common_proxypolicy.sh <bind_fdn> <ldapserver_ip> <ldap_port>";
	exit 1;
fi

TMP_ADD_PROXYPOLICY_LDIFFILE=/tmp/common_proxy_policy.ldif
LDAP_ADD_BINARY=/usr/bin/ldapadd
PROXY_LOGFILE=/var/opt/novell/log/proxymgmt/pxymgmt.log
LDAP_SEARCH_BINARY=/usr/bin/ldapsearch
PROXY_POLICY_DN="cn=Common_Proxy_Policy,cn=Password Policies,cn=Security"
LDAP_SEC_CERT="env LDAPTLS_CACERT=/etc/opt/novell/certs/SSCert.pem"

#If proxy password policy already exists, we need not create
echo "The ldap command to be executed from within create_common_proxypolicy script is $LDAP_SEC_CERT $LDAP_SEARCH_BINARY -D "$1" -w -H ldaps://$2:$3  -b "$PROXY_POLICY_DN" -s "base" -LLL -A " >> $PROXY_LOGFILE
$LDAP_SEC_CERT $LDAP_SEARCH_BINARY -D "$1" -w "$OES_DATA" -H ldaps://$2:$3  -b "$PROXY_POLICY_DN" -s "base" -LLL -A >> /dev/null 2>&1 
LDAP_SEARCH_RES=$?
echo "The return value of ldap command called from within create_common_proxypolicy script is: $LDAP_SEARCH_RES" >> $PROXY_LOGFILE
if test $LDAP_SEARCH_RES == 0
then
	echo "$PROXY_POLICY_DN Already exists. Not creating again" >> $PROXY_LOGFILE
	exit 0
fi

mkdir -p /tmp
touch $TMP_ADD_PROXYPOLICY_LDIFFILE

echo "dn: cn=Password Policies,cn=Security" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "objectClass: nspmPasswordPolicyContainer" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "cn: Password Policies" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "ACL: 1#subtree#[Public]#[Entry Rights]" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "ACL: 3#subtree#[Public]#[All Attributes Rights]" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "dn: $PROXY_POLICY_DN" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "objectClass: nspmPasswordPolicy" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "cn: Common_Proxy_Policy" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "Description: Default policy for common proxy users" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "nsimPwdRuleEnforcement: FALSE" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "nsimForgottenAction: <ForgottenPassword><Enabled>false</Enabled><Sequence><Au" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo " thentication><![CDATA[]]></Authentication><Action></Action></Sequence></For" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo " gottenPassword>" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "nsimForgottenLoginConfig: TRUE" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "nspmCaseSensitive: TRUE" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "nspmSpecialAsLastCharacter: TRUE" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "nspmSpecialAsFirstCharacter: TRUE" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "nspmSpecialCharactersAllowed: TRUE" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "nspmNumericAsLastCharacter: TRUE" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "nspmNumericAsFirstCharacter: TRUE" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "nspmNumericCharactersAllowed: TRUE" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "nspmConfigurationOptions: 852" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "nspmMaximumLength: 20" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "nspmExtendedCharactersAllowed: false" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "passwordUniqueRequired: FALSE" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "passwordAllowChange: TRUE" >> $TMP_ADD_PROXYPOLICY_LDIFFILE
echo "" >> $TMP_ADD_PROXYPOLICY_LDIFFILE

echo "The ldap command to be executed from within create_common_proxypolicy script is $LDAP_SEC_CERT $LDAP_ADD_BINARY -c -f $TMP_ADD_PROXYPOLICY_LDIFFILE -D "$1" -w -H ldaps://$2:$3" >> $PROXY_LOGFILE
$LDAP_SEC_CERT $LDAP_ADD_BINARY -c -f $TMP_ADD_PROXYPOLICY_LDIFFILE -D "$1" -w "$OES_DATA" -H ldaps://$2:$3 >> /dev/null 2>&1
LDAP_ADD_OUT=$?
echo "The return value of ldap command called from within create_common_proxypolicy script is: $LDAP_ADD_OUT" >> $PROXY_LOGFILE
rm $TMP_ADD_PROXYPOLICY_LDIFFILE

if test $LDAP_ADD_OUT == 68 || test $LDAP_ADD_OUT == 0
then 
	exit 0
fi

if test $LDAP_ADD_OUT != 0
then
	echo "Creation of common proxy password policy has failed with LDAP error: $LDAP_ADD_OUT" >> $PROXY_LOGFILE
	exit $LDAP_ADD_OUT
fi
