#!/bin/sh
#
#Copyright (c) 2010, Novell, Inc.  All rights reserved.
#
# Pre-requisite: The common proxy password policy should be created before calling this script.
# This script will read the admin password from OES_DATA and the proxy user password from OES_PROXY_DATA. 
# So please make sure that these variables are filled before calling this script.
# 1. This script adds a new common proxy user for OES. 
# 2. This script also assigns the default Common Proxy policy to common proxy object during creation itself if th user passes "yes" in the fifth argument.
# 3. Next, this script updates the given user FDN to a password policy and add him as reader of passwords to that policy

user_id=`id -u`
if test $user_id -ne 0
then 
	echo "create_common_proxyuser.sh : Only root user can run this script"
	exit 1
fi

if test $# == 5
then 
	PROXY_UTIL=/opt/novell/proxymgmt/bin
	TMP_ADD_PROXYUSER_LDIFFILE=/tmp/addafpproxy.ldif
	LDAP_ADD_BINARY=/usr/bin/ldapadd
	LDAP_MODIFY_BINARY=/usr/bin/ldapmodify
	LDAP_SEARCH_BINARY=/usr/bin/ldapsearch
	PROXY_LOG_FILE=/var/opt/novell/log/proxymgmt/pxymgmt.log
	TMP_ATTACH_USER_PWPOLICY_LDIFFILE=/tmp/attachuserpwpolicy.ldif
	LDAP_SEC_CERT="env LDAPTLS_CACERT=/etc/opt/novell/certs/SSCert.pem"

	#Delete the the proxy user if already existing. 
        ORG_PROXY_USER=$1
        PROXY_USER_TO_LDAP=`echo $ORG_PROXY_USER |sed 's/\./,/g'`

        ORG_ADMIN_USER=$2
        ADMIN_USER_TO_LDAP=`echo $ORG_ADMIN_USER |sed 's/\./,/g'`

	mkdir -p /tmp
	touch $TMP_ADD_PROXYUSER_LDIFFILE
	echo "dn: "$PROXY_USER_TO_LDAP >> $TMP_ADD_PROXYUSER_LDIFFILE
	echo "changetype: delete" >> $TMP_ADD_PROXYUSER_LDIFFILE
	
	echo "The ldap command to be executed from within create_common_proxyuser script is  $LDAP_SEC_CERT $LDAP_MODIFY_BINARY -c -f $TMP_ADD_PROXYUSER_LDIFFILE -D "$ADMIN_USER_TO_LDAP" -w -H ldaps://$3:$4 ">> $PROXY_LOG_FILE
	$LDAP_SEC_CERT $LDAP_MODIFY_BINARY -c -f $TMP_ADD_PROXYUSER_LDIFFILE -D "$ADMIN_USER_TO_LDAP" -w "$OES_DATA" -H ldaps://$3:$4 >> /dev/null 2>&1
       	USR_DELETED=$?
	echo "The return value of ldap command called from within create_common_proxyuser script is: $USR_DELETED" >> $PROXY_LOG_FILE 
	rm $TMP_ADD_PROXYUSER_LDIFFILE

	# If same proxy user already exists, then make sure that object got deleted properly.	
	if test $USR_DELETED == 0 
	then
		# We can wait for maximum of 120 seconds. This is to make sure the previous ldap operation is completed and refreshed.
		sleep 5
		COUNT=0	
		echo "The ldap command (If same proxy user already exists block) to be executed from within create_common_proxyuser script is $LDAP_SEC_CERT $LDAP_SEARCH_BINARY -b "$PROXY_USER_TO_LDAP" -s base -D "$ADMIN_USER_TO_LDAP" -w -H ldaps://$3:$4 " >> $PROXY_LOG_FILE
		$LDAP_SEC_CERT $LDAP_SEARCH_BINARY -b "$PROXY_USER_TO_LDAP" -s base -D "$ADMIN_USER_TO_LDAP" -w "$OES_DATA" -H ldaps://$3:$4  >> /dev/null 2>&1
		LDAP_SRCH_OUT=$?
		echo "The return value of ldap command called from (If same proxy user already exists block) within create_common_proxyuser script is: $LDAP_SRCH_OUT" >> $PROXY_LOG_FILE
		if test $LDAP_SRCH_OUT != 32 
		then
			while [[ ( $LDAP_SRCH_OUT != 32 ) && ( $COUNT -lt 60 ) ]]
			do
				let COUNT+=5
				sleep 5
				echo "The ldap command (ldapsearch output not 32 block) to be executed from within create_common_proxyuser script is  $LDAP_SEC_CERT $LDAP_SEARCH_BINARY -b "$PROXY_USER_TO_LDAP" -s base -D "$ADMIN_USER_TO_LDAP" -w -H ldaps://$3:$4 " >> $PROXY_LOG_FILE
				$LDAP_SEC_CERT $LDAP_SEARCH_BINARY -b "$PROXY_USER_TO_LDAP" -s base -D "$ADMIN_USER_TO_LDAP" -w "$OES_DATA" -H ldaps://$3:$4  >> /dev/null 2>&1
				LDAP_SRCH_OUT=$?
				echo "The return value of ldap command called from (ldapsearch output not 32 block) within create_common_proxyuser script is: $LDAP_SRCH_OUT" >> $PROXY_LOG_FILE
			done
			if test $COUNT == 60 
			then
				echo "[Error]Unable to Delete the existing common proxy user $PROXY_USER_TO_LDAP" >> $PROXY_LOG_FILE
				#Yast should abort the configuration.
				exit 2	
			fi
		fi
	fi	

	mkdir -p /tmp
	touch $TMP_ADD_PROXYUSER_LDIFFILE
	echo "dn: "$PROXY_USER_TO_LDAP >> $TMP_ADD_PROXYUSER_LDIFFILE
	echo "givenName: User" >> $TMP_ADD_PROXYUSER_LDIFFILE
	echo "sn: CommonProxy" >> $TMP_ADD_PROXYUSER_LDIFFILE
	echo "objectClass: inetOrgPerson" >> $TMP_ADD_PROXYUSER_LDIFFILE
	echo "userPassword: "$OES_PROXY_DATA >> $TMP_ADD_PROXYUSER_LDIFFILE

	ATTACH_PROXY_POLICY_TO_PROXY_USER=false
	
	# If user passes the fifth argument as "yes" then, at the time of creation of Proxy User, the script assigns the default Common Proxy Policy to it. 
	if test "$5" = "yes"
	then
		ATTACH_PROXY_POLICY_TO_PROXY_USER=true
		echo "Assigning the common proxy policy to proxy user" >> $PROXY_LOG_FILE
		echo "nspmPasswordPolicyDN: cn=Common_Proxy_policy,cn=Password Policies,cn=Security" >> $TMP_ADD_PROXYUSER_LDIFFILE

	fi

	echo "The ldap command (second block) to be executed from within create_common_proxyuser script is $LDAP_SEC_CERT $LDAP_ADD_BINARY -f $TMP_ADD_PROXYUSER_LDIFFILE -D "$ADMIN_USER_TO_LDAP" -w -H ldaps://$3:$4 " >> $PROXY_LOG_FILE
	$LDAP_SEC_CERT $LDAP_ADD_BINARY -f $TMP_ADD_PROXYUSER_LDIFFILE -D "$ADMIN_USER_TO_LDAP" -w "$OES_DATA" -H ldaps://$3:$4
	USER_CRAETED=$?
	echo "The return value of ldap command called from (second block) within create_common_proxyuser script is: $USER_CRAETED" >> $PROXY_LOG_FILE
	rm $TMP_ADD_PROXYUSER_LDIFFILE
	if test $USER_CRAETED != 0 
	then
		echo "Lets check if the container DN exists.If not create the non-existing container and create user"  >> $PROXY_LOG_FILE
		$PROXY_UTIL/create_ctx_and_user "$PROXY_USER_TO_LDAP" "$ADMIN_USER_TO_LDAP" $3 $4 1 >> /dev/null 2>&1
		USER_CRAETED=$?
		if test $USER_CRAETED != 0 
		then
			echo "Create common proxy user failed with error:$USER_CRAETED " >> $PROXY_LOG_FILE
		fi
	fi

	# The below block updates the given user FDN to a password policy and add him as reader of passwords to that policy. 
	if test $USER_CRAETED == 0 && test $ATTACH_PROXY_POLICY_TO_PROXY_USER == true
	then
		COUNT=0
		mkdir -p /tmp
		touch $TMP_ATTACH_USER_PWPOLICY_LDIFFILE

		echo "dn: cn=Common_Proxy_policy,cn=Password Policies,cn=Security" >> $TMP_ATTACH_USER_PWPOLICY_LDIFFILE
		echo "changetype: modify" >> $TMP_ATTACH_USER_PWPOLICY_LDIFFILE
		echo "add: nsimAssignments" >> $TMP_ATTACH_USER_PWPOLICY_LDIFFILE
		echo "nsimAssignments: "$PROXY_USER_TO_LDAP >> $TMP_ATTACH_USER_PWPOLICY_LDIFFILE
		echo "" >> $TMP_ATTACH_USER_PWPOLICY_LDIFFILE

		echo "The ldap command to be executed for attaching Common Proxy policy to Proxy User is $LDAP_SEC_CERT $LDAP_MODIFY_BINARY -c -f $TMP_ATTACH_USER_PWPOLICY_LDIFFILE -D "$ADMIN_USER_TO_LDAP" -w -H ldaps://$3:$4 ">>$PROXY_LOG_FILE
		$LDAP_SEC_CERT $LDAP_MODIFY_BINARY -c -f $TMP_ATTACH_USER_PWPOLICY_LDIFFILE -D "$ADMIN_USER_TO_LDAP" -w "$OES_DATA" -H ldaps://$3:$4 >> $PROXY_LOG_FILE 2>&1
		LDAP_MODIFY_OUT=$?
		echo "The return value of ldap command called from (second block) within attach_proxyuser_pwpolicy script is: $LDAP_MODIFY_OUT" >> $PROXY_LOG_FILE
		if test $LDAP_MODIFY_OUT == 19  
		then
			while [[ $LDAP_MODIFY_OUT == 19 && $COUNT -lt 60 ]]
			do
				let COUNT+=5
				sleep 5
				echo "The ldap command to be executed from the error block (error 19) within attach_proxyuser_pwpolicy script is $LDAP_SEC_CERT $LDAP_MODIFY_BINARY -c -f $TMP_ATTACH_USER_PWPOLICY_LDIFFILE -D "$ADMIN_USER_TO_LDAP" -w -H ldaps://$3:$4 " >> $PROXY_LOG_FILE
				$LDAP_SEC_CERT $LDAP_MODIFY_BINARY -c -f $TMP_ATTACH_USER_PWPOLICY_LDIFFILE -D "$ADMIN_USER_TO_LDAP" -w "$OES_DATA" -H ldaps://$3:$4 >> $PROXY_LOG_FILE 2>&1
				LDAP_MODIFY_OUT=$?
				echo "The return value of ldap command called from error block (error 19) within attach_proxyuser_pwpolicy script is: $LDAP_MODIFY_OUT" >> $PROXY_LOG_FILE
			done	
			if test $COUNT == 60
			then
				rm $TMP_ATTACH_USER_PWPOLICY_LDIFFILE
				echo "[Error] Proxy user policy attachment is failed with error $LDAP_MODIFY_OUT." >> $PROXY_LOG_FILE
				echo "Please run /opt/novell/proxymgmt/bin/attach_proxyuser_pwpolicy.sh later manually by setting the admin password to OES_DATA" >> $PROXY_LOG_FILE
				exit 2
			fi
		fi
		if test $LDAP_MODIFY_OUT != 20 && test $LDAP_MODIFY_OUT != 0
		then
			rm $TMP_ATTACH_USER_PWPOLICY_LDIFFILE
			exit 1 
		fi
		rm $TMP_ATTACH_USER_PWPOLICY_LDIFFILE
	fi
	
	exit $USER_CRAETED
else
	echo "Usage: create_common_proxyuser.sh <proxy_fdn> <bind_fdn> <ldapserver_ip> <ldap_port> <yes/no>";
	echo "For the last argument, if 'yes' is passed, the script assigns Common Proxy Policy to the proxy user. If 'no' the script will not assing the Common Proxy Policy to the proxy user.";
	echo "Please use env variables OES_DATA and OES_PROXY_DATA for admin and Proxy user passwords before calling this script"
	exit 1
fi
