#!/bin/sh
#
#Copyright (c) 2012, Novell, Inc.  All rights reserved.
#
# This script is migrating service proxy credentials from source 
# The command is run on target by providing IP of the source and 
# other LDAP parameters required for eDirectory access
# The script exclusively is implemented for proxy migration between different OES versions

user_id=`id -u`
if test $user_id -ne 0
then 
        echo "migrate_services_proxy.sh : Only root user can run this script"
        exit 1
fi
		
CP_UTIL="/opt/novell/proxymgmt/bin/cp_retrieve_proxy_cred"
CP_DIR="/var/opt/novell/log/proxymgmt"
PROXY_LOGFILE="/var/opt/novell/log/proxymgmt/pxymgmt.log"
CRED_FILE="/var/opt/novell/log/proxymgmt/proxycred"
CRED_TEMP_FILE="/var/opt/novell/log/proxymgmt/tempcred"
ENCBINARY="/opt/novell/proxymgmt/bin/oes-enc-dec"
RECONFBINS="/opt/novell/proxymgmt/bin"
LOGFOLDER="/var/opt/novell/log/proxymgmt"
IGNORECP=""
ENCRYPTCRED="yes"

FileList=(cifs_get_proxy_cred.sh dhcp_get_proxy_cred.sh dns_get_proxy_cred.sh lum_get_proxy_cred.sh ncs_get_proxy_cred.sh 
	netstorage_get_proxy_cred.sh services_get_proxy_cred.sh)

Usage() 
{
	echo ""
	echo "Usage: migrate_services_proxy.sh [options]"
	echo "          -h                      Prints this summary"
	echo "          -s                      Source system IP Address"
	echo "          -d                      LDAP Admin FDN"
	echo "          -w                      LDAP Admin Password"
	echo "          -i                      LDAP Server IP address"
	echo "          -p                      LDAP Port(Only Secure Port like 636)"
	#echo "		-f			Path to credentials file (Optional)"
	echo "          -e                      (Optional) yes or no. Credentials in file are encrypted or not. Default yes"
	echo "          -I                      (Optional) yes or no. Ignore services using common proxy. Default yes"
	echo ""
	
	exit 1;
}

#Create Proxy Management binary and log file directory paths on source
create_proxy_directories() 
{
	
	echo "Creating $RECONFBINS and $LOGFOLDER directories on source system" >> $PROXY_LOGFILE

	ssh root@$SOURCEIP mkdir -p $RECONFBINS
	CREATEBINFOLDER=$?
	if [ $CREATEBINFOLDER -ne 0 ] 
	then
		echo "Creation of $RECONF directory has failed: $CREATEBINFOLDER " >> $PROXY_LOGFILE
		return $CREATEBINFOLDER
	fi
	
	ssh root@$SOURCEIP mkdir -p $LOGFOLDER
	CREATELOGFOLDER=$?
	if [ $CREATELOGFOLDER -ne 0 ] 
	then
		echo "Creation of $LOGFOLDER directory has failed: $CREATELOGFOLDER " >> $PROXY_LOGFILE
		return $CREATELOGFOLDER
	fi

	echo "Completed creation of $RECONFBINS and $LOGFOLDER directories on source system" >> $PROXY_LOGFILE
	
	return 0
}

#Copy all proxy credentialretrieval scripts to source
copy_proxy_binaries()
{
	
	echo "Copying proxy credentials retrieval scripts to source system" >> $PROXY_LOGFILE
	for name in ${FileList[@]}
	do
		#Service proxy cred retrieval scripts	
		scp $RECONFBINS/$name root@$SOURCEIP:/$RECONFBINS
		COPYPROXYBIN=$?
		if [ $COPYPROXYBIN -ne 0 ]
		then
			echo "Could not copy $name script to source system: $COPYPROXYBIN" >> $PROXY_LOGFILE
			exit $COPYPROXYBIN
		fi
	done
	
	#Copy Encode Decode Binary based on source version
	SRCARCH=`ssh root@$SOURCEIP uname -p`
	GETSRCARCH=$?
	if [ $GETSRCARCH -ne 0 ]
	then
		echo "Could not determine architecture(32 or 64 bit) of source system: $GETSRCARCH" >> $PROXY_LOGFILE
		return $GETSRCARCH
	fi

        if test "$SRCARCH" = "x86_64"
	then
		scp $RECONFBINS/oes-enc-dec root@$SOURCEIP:/$RECONFBINS
		COPYPROXYBIN=$?
		if [ $COPYPROXYBIN -ne 0 ]
		then
			echo "Could not copy 64-bit encode-decode binary to source system: $COPYPROXYBIN" >> $PROXY_LOGFILE
			return $COPYPROXYBIN
		fi
	else
		scp $RECONFBINS/32bit/oes-enc-dec root@$SOURCEIP:/$RECONFBINS
		COPYPROXYBIN=$?
		if [ $COPYPROXYBIN -ne 0 ]
		then
			echo "Could not copy 32-bit encode-decode binary to source system: $COPYPROXYBIN" >> $PROXY_LOGFILE
			return $COPYPROXYBIN
		fi
	fi

	echo "Completed copying of proxy credentials retrieval scripts to source system" >> $PROXY_LOGFILE

	return 0	    
}

#Retrieve service proxy credentials on source system
execute_get_proxy_cred()
{

	echo "Retrieving service proxy credentials on source system" >> $PROXY_LOGFILE

	#Execute the script on source to retrieve proxy credentials. Password in encrypted format
	ssh root@$SOURCEIP $RECONFBINS/services_get_proxy_cred.sh -I $IGNORECP -e $ENCRYPTCRED
	GETPROXYCREDS=$?
	if [ $GETPROXYCREDS -ne 0 ]
	then
		echo "Failed to get service proxy credentials on source system: $GETPROXYCREDS" >> $PROXY_LOGFILE
		return $GETPROXYCREDS
	fi
	
	echo "Successfully retrieved service proxy credentials on source system" >> $PROXY_LOGFILE

	#Copy the proxycred from source
	scp root@$SOURCEIP:$CRED_FILE $CP_DIR/$SOURCEIP
	COPYCREDS=$?
	if [ $COPYCREDS -ne 0 ]
	then
		echo "Failed to copy $CRED_FILE from source system: $COPYCREDS" >> $PROXY_LOGFILE
		return $COPYCREDS
	fi

	echo "Successfully copied service proxy credentials from source system to $CP_DIR/$SOURCEIP " >> $PROXY_LOGFILE

	#Copy the log file also from source
	scp root@$SOURCEIP:$PROXY_LOGFILE $CP_DIR/$SOURCEIP
	COPYLOGS=$?
	if [ $COPYLOGS -ne 0 ]
	then
		echo "Failed to copy $PROXY_LOGFILE from source system: $COPYLOGS. Refer to log file manually on source, if required" >> $PROXY_LOGFILE
	fi

	#Remove the proxycred on source
	ssh root@$SOURCEIP rm $CRED_FILE
	REMCREDS=$?
	if [ $REMCREDS -ne 0 ]
	then
		echo "Failed to remove the $CREDFILE on source system: $REMCREDS. Remove the file manually" >> $PROXY_LOGFILE
	fi
    
	return 0
}

#Delete proxy retrieval binaries on source - for OES2 SP2 and SP3
delete_proxy_binaries()
{

	echo "Deleting proxy credentials retrieval binaries on $SOURCEIP" >> $PROXY_LOGFILE
	for name in ${FileList[@]}
	do
		#Just go and delete the proxy retrieval files from source
		ssh root@$SOURCEIP rm $RECONFBINS/$name
		REMFILES=$?
		if [ $REMFILES -ne 0 ]
		then
			echo "Failed to remove $name on source system: $REMFILES. Remove the file manually" >> $PROXY_LOGFILE
		fi
	done

	ssh root@$SOURCEIP rm $RECONFBINS/oes-enc-dec
	REMFILES=$?
	if [ $REMFILES -ne 0 ]
	then
		echo "Failed to remove the encode-decode binary on source system: $REMFILES. Remove the file manually" >> $PROXY_LOGFILE
	fi
}

#Delete the proxy mgmt folders on source - OES2 SP2
delete_proxy_directories()
{
	
	echo "Deleting $RECONFBINS and $LOGFOLDER on source system" >> $PROXY_LOGFILE

	ssh root@$SOURCEIP rm -r $RECONFBINS
	REMDIR=$?
	if [ $REMDIR -ne 0 ]
	then
		echo "Failed to delete the directory $RECONFBINS on source system: $REMDIR. Delete the directory manually" >> $PROXY_LOGFILE
	fi

	ssh root@$SOURCEIP rm -r /opt/novell/proxymgmt	#Need to delete this folder also
	REMDIR=$?
	if [ $REMDIR -ne 0 ]
	then
		echo "Failed to delete the directory $RECONFBINS on source system: $REMDIR. Delete the directory manually" >> $PROXY_LOGFILE
	fi

	ssh root@$SOURCEIP rm -rf $LOGFOLDER
	REMDIR=$?
	if [ $REMDIR -ne 0 ]
	then
		echo "Failed to delete the directory $LOGFOLDER on source system: $REMDIR. Delete the directory manually" >> $PROXY_LOGFILE
	fi

}


if test $# -eq 0
then
	Usage
fi

#Get the parameters
while getopts s:d:w:i:p:e:I:h o
do		
	case "$o" in
	             d)LDAP_ADM="$OPTARG";;
	             w)LDAP_PWD="$OPTARG";;
	             i)LDAP_IP="$OPTARG";;
	             p)LDAP_PORT="$OPTARG";;
#	             f)CREDSFILE="$OPTARG";;
		     e)ENCORNO="$OPTARG";;
		     I)IGNORECP="$OPTARG";;
		     s)SOURCEIP="$OPTARG";;
		     h)Usage;;
	           [?]) Usage;;
	esac
done

#LDAP connection parameters and source IP are must
if test "$LDAP_ADM" = "" || test "$LDAP_IP" = "" || test "$LDAP_PORT" = "" || test "$SOURCEIP" = ""
then
	Usage
fi

#Prompt for LDAP Admin password if not passed through command line
if test "$LDAP_PWD" = ""
then
	echo "Please enter LDAP admin password"
	mode=`stty -g`
        stty -echo
        read LDAP_PWD
        stty $mode
fi

: '
if test "$CREDSFILE" != ""
then
	CRED_FILE=$CREDSFILE
fi
'
#Whether to ignore services using common proxy. Defaut 'yes'
if test "$IGNORECP" = ""
then
	IGNORECP="yes"
fi
IGNORECP=`echo $IGNORECP | tr '[:upper:]' '[:lower:]'`

if test "$ENCORNO" != ""
then
	ENCORNO=`echo $ENCORNO | tr '[:upper:]' '[:lower:]'`
	ENCRYPTCRED="$ENCORNO"
fi

echo "===============================================================" >> $PROXY_LOGFILE
echo "`date`:Starting service proxy Migration" >> $PROXY_LOGFILE
echo "===============================================================" >> $PROXY_LOGFILE

#Create the folder with source IP under /var/opt/novell/log/proxymgmt
mkdir -p $CP_DIR/$SOURCEIP

#Get the OES version file from source
scp root@$SOURCEIP:/etc/novell-release $CP_DIR/$SOURCEIP
GETOESFLE=$?
if [ $GETOESFLE -ne 0 ]
then
	echo "Could not get the /etc/novell-release from source system" >> $PROXY_LOGFILE
	exit $GETOESFILE
fi

#Get the version of source OES
OESVER="`grep "VERSION" $CP_DIR/$SOURCEIP/novell-release`"
OESSP="`grep "PATCHLEVEL" $CP_DIR/$SOURCEIP/novell-release`"

echo "OESVERSION: $OESVER OESPATCH: $OESSP" >> $PROXY_LOGFILE

if [ "$OESVER" == "VERSION = 11.1" ] && [ "$OESSP" == "PATCHLEVEL = 1" ]	#OES11-SP1
then
	SOURCEOES="OES11SP1"
elif [ "$OESVER" == "VERSION = 11" ] && [ "$OESSP" == "PATCHLEVEL = 0" ]	#OES11 FP0
then
	SOURCEOES="OES11FP0"
elif [ "$OESVER" == "VERSION = 2.0.3" ] && [ "$OESSP" == "PATCHLEVEL = 3" ]	#OES2 SP3
then
	SOURCEOES="OES2SP3"
elif [ "$OESVER" == "VERSION = 2.0.2" ] && [ "$OESSP" == "PATCHLEVEL = 2" ]	#OES2 SP2
then
	SOURCEOES="OES2SP2"
elif [ "$OESVER" == "VERSION = 11.2" ] && [ "$OESSP" == "PATCHLEVEL = 2" ]	#OES11 SP2
then
	SOURCEOES="OES11SP2"
elif [ "$OESVER" == "VERSION = 2015" ] && [ "$OESSP" == "PATCHLEVEL = 0" ]	#OES2015
then
	SOURCEOES="OES2015"
else
	echo "Unsupport source OES: $OESVER $OESSP for proxy user migration" >> $PROXY_LOGFILE
	exit 1
fi

echo "OES Version on $SOURCEIP is $SOURCEOES" >> $PROXY_LOGFILE

#Based on Source OES version do one or more operations
#After the below execution, proxy credentials from source should be in /var/opt/novell/log/$SOURCEIP/proxycred
if test "$SOURCEOES" = "OES2SP2"
then
	#Create the /opt/novell/proxymgmt/bin and var/opt/novell/log/proxymgmt folders on source
	create_proxy_directories
	CREATEDIR=$?
	if [ $CREATEDIR -ne 0 ]
	then
		echo "Creation of folders on source system has failed: $CREATEDIR" >> $PROXY_LOGFILE
		exit $CREATEDIR
	fi

	#Copy the proxy credential retrieval code to source
	copy_proxy_binaries
	COPYFILES=$?
	if [ $COPYFILES -ne 0 ]
	then
		echo "Copying of credential retrieval binaries to source system has failed: $COPYFILES" >> $PROXY_LOGFILE
		delete_proxy_directories	#Delete the proxy directories on source before exit
		exit $COPYFILES
	fi

	execute_get_proxy_cred
	GETCREDS=$?
	if [ $GETCREDS -ne 0 ]
	then
		echo "Failed to get service proxy credentials from source system: $GETCREDS" >> $PROXY_LOGFILE
		delete_proxy_binaries	#Delete credential retrieval binaries on source
		delete_proxy_directories #Delete the proxy directories on source before exit
		exit $GETCREDS
	fi
elif test "$SOURCEOES" = "OES2SP3"
then
	copy_proxy_binaries
	COPYFILES=$?
	if [ $COPYFILES -ne 0 ]
	then
		echo "Copying of credential retrieval binaries to source system has failed: $COPYFILES" >> $PROXY_LOGFILE
		exit $COPYFILES
	fi
	execute_get_proxy_cred
	GETCREDS=$?
	if [ $GETCREDS -ne 0 ]
	then
		echo "Failed to get service proxy credentials from source system: $GETCREDS" >> $PROXY_LOGFILE
		delete_proxy_binaries	#Delete credential retrieval binaries on source
		exit $GETCREDS
	fi
elif test "$SOURCEOES" = "OES11FP0"
then
	execute_get_proxy_cred
	GETCREDS=$?
	if [ $GETCREDS -ne 0 ]
	then
		echo "Failed to get service proxy credentials from source system: $GETCREDS" >> $PROXY_LOGFILE
		
		exit $GETCREDS
	fi
elif test "$SOURCEOES" = "OES11SP1"
then
	execute_get_proxy_cred
	GETCREDS=$?
	if [ $GETCREDS -ne 0 ]
	then
		echo "Failed to get service proxy credentials from source system: $GETCREDS" >> $PROXY_LOGFILE
		exit $GETCREDS
	fi
elif test "$SOURCEOES" = "OES11SP2"
then
        execute_get_proxy_cred
        GETCREDS=$?
        if [ $GETCREDS -ne 0 ]
        then
                echo "Failed to get service proxy credentials from source system: $GETCREDS" >> $PROXY_LOGFILE
                exit $GETCREDS
        fi
elif test "$SOURCEOES" = "OES2015"
then
        execute_get_proxy_cred
        GETCREDS=$?
        if [ $GETCREDS -ne 0 ]
        then
                echo "Failed to get service proxy credentials from source system: $GETCREDS" >> $PROXY_LOGFILE
                exit $GETCREDS
        fi
fi

#Copy the source system cred file to /var/opt/novell/log/proxymgmt
cp $CP_DIR/$SOURCEIP/proxycred $CRED_FILE

#Now continue with reconfiguration of services on local system
$RECONFBINS/services_reconfig_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i $LDAP_IP -p $LDAP_PORT -e $ENCRYPTCRED -I $IGNORECP
RECONF=$?
if [ $RECONF -ne 0 ]
then
	echo "Services reconfiguration for proxy user has failed for one or more services: $RECONF" >> $PROXY_LOGFILE
fi

#Cleanup the source system, if it's OES2 SP2 and OES2 SP3
if test "$OSOURCEOES" = "OES2SP2"
then
	echo "Cleaning up source OES2SP2system" >> $PROXY_LOGFILE
	delete_proxy_binaries
	ssh@$SOURCEIP rm $PROXY_LOGFILE  #Delete the proxy log file on source
	delete_proxy_directories
	
elif test "$SOURCEOES" = "OES2SP3"
then
	echo "Cleaning up source OES2SP3 system" >> $PROXY_LOGFILE
	delete_proxy_binaries
fi


echo "===============================================================" >> $PROXY_LOGFILE
echo "`date`:Proxy migration of services is completed" >> $PROXY_LOGFILE
echo "===============================================================" >> $PROXY_LOGFILE

echo "Services migration for proxy user is completed. Refer to $PROXY_LOGFILE for more details"

exit 0
