#!/bin/sh  
#
#Copyright (c) 2010, Novell, Inc.  All rights reserved.
#
# This script is used to move any service to use common proxy from its service specific proxy.
#

user_id=`id -u`
if test $user_id -ne 0
then 
        echo "move_to_common_proxy.sh : Only root user can run this script"
        exit 1
fi

PROXY_UTIL="/opt/novell/proxymgmt/bin"
PROXY_LOGFILE="/var/opt/novell/log/proxymgmt/pxymgmt.log"
PROXY_INFO_FILE="/etc/opt/novell/proxymgmt/proxyuser.txt"
if test "$UPGRADE" = ""
then
	UPGRADE=0
else
	UPGRADE=1
fi
Usage()
{
	        echo ""
	        echo "Usage: move_to_common_proxy.sh [options]"
	        echo "          -h                      Prints this summary"
	        echo "          -d                      LDAP Admin FDN"
	        echo "          -w                      LDAP Admin Password"
	        echo "          -i                      LDAP Server IP address"
	        echo "          -p                      LDAP Port"
	        echo "          -s                      Service Name (Multiple service names should be separated by comma.'all' should be used to move all the services)"
		echo "					Valid Services:	novell-afp,novell-cifs,novell-dns,novell-dhcp,novell-netstorage,novell-lum,novell-ncs and 'all'"
		echo ""

		exit 1;
}

readProxyFDN()
{
	
	echo ""
        echo  "Enter proxy user context FDN for common proxy user(Optional). For eg:ou=users,o=novell. "
	echo -n "If context is not provided, common proxy will be created in local NCP server context:"
        read CTX_FDN
	CNTXT_LEN=$(echo ${#CTX_FDN})
	if test $CNTXT_LEN != 0
	then
        	CP_FDN="cn=$CP_NAME,$CTX_FDN"
	else
		#Get the NCP Server context from Root DSE
		#Read RootDSE of local LDAP Server
		ROOTDSE=`env LDAPTLS_CACERT=/etc/opt/novell/certs/SSCert.pem /usr/bin/ldapsearch -D "" -s base -H ldaps://$LDAP_IP:636 | grep dsaName`
		LDAP_SEA_RES=$?
		#Exit if we can't read from RootDSE
		if test "$ROOTDSE" = ""
		then
			echo "Failed to get the NCP Server name from From RootDSE. Run move_to_common_proxy.sh again: $LDAP_SEA_RES " >> $PROXY_LOGFILE
			echo "Failed to get the NCP Server name from From RootDSE.  Run move_to_common_proxy.sh again: $LDAP_SEA_RES " 
			exit $LDAP_SEA_RES
		fi

		echo "DSA Entry from from RootDSE: $ROOTDSE" >> $PROXY_LOGFILE

		#Extract the  NCP Server DN from RootDSE entry
		NCPDN=`echo $ROOTDSE | cut -d" " -f2`
		echo "NCP Server DN: $NCPDN" >> $PROXY_LOGFILE

		#Extract the NCP Server CN
		NCPCN=`echo $NCPDN | cut -d"," -f1`
		echo "NCP Server CN: $NCPCN" >> $PROXY_LOGFILE

		#Extract the NCP Server Context
		NCPDUP=$NCPDN
		NCPCNTXT=`echo ${NCPDUP#*,}`
		echo "NCP Server Context: $NCPCNTXT" >> $PROXY_LOGFILE

		CTX_FDN=$NCPCNTXT
		CP_FDN="cn=$CP_NAME,$CTX_FDN"
	fi
        echo "Going to create Common Proxy user $CP_FDN now."
        echo -n "Want to continue?[y/n]:"
        read WANT_CONTINUE
}

if test $# -eq 0
then
        Usage
fi

while getopts d:w:i:p:s:h o
do
        case "$o" in
	             d)LDAP_ADM="$OPTARG";;
	             w)LDAP_PWD="$OPTARG";;
	             i)LDAP_IP="$OPTARG";;
	             p)LDAP_PORT="$OPTARG";;
	             s)SERVICES="$OPTARG";;
	             h)Usage;;
	           [?]) Usage;;
	esac
done
														
if test "$LDAP_ADM" = "" || test "$LDAP_IP" = "" || test "$LDAP_PORT" = "" || test "$SERVICES" = ""
then
	Usage
fi

if test "$LDAP_PWD" = ""
then
	echo "Please enter Ldap Admin Password"
	mode=`stty -g`
        stty -echo
        read LDAP_PWD
        stty $mode
fi
# Check if the common proxy user already exists. If not create one.
CP_FDN=`$PROXY_UTIL/cp_retrieve_proxy_cred username`
CP_PWD=`$PROXY_UTIL/cp_retrieve_proxy_cred password `
export CP_EXISTS=$?

export WANT_CONTINUE="n"

echo "`date`:[status] Starting Move To Common Proxy Task" >> $PROXY_LOGFILE
if test $CP_EXISTS != 0
then
	CP_NAME="OESCommonProxy_$(hostname)"
	echo "Common Proxy user does not exist. Creating new common proxy user $CP_NAME now." 
	while [ $WANT_CONTINUE != "y" ]
	do
		readProxyFDN
	done
	
	echo ""
	echo "Enter Common Proxy User Password(Optional)"
	echo -n "If password is not entered, a random password will be set:"
	mode=`stty -g`
	stty -echo
	read CP_PWD
	stty $mode
	PWD_LEN=$(echo ${#CP_PWD})
	if test $PWD_LEN != 0
	then
		export OES_PROXY_DATA="$CP_PWD"
		AUTO_PWD=0;
	else
		AUTO_PWD=1;
		CP_PWD=`$PROXY_UTIL/randpwd.sh` #Generate a random password
		export OES_PROXY_DATA="$CP_PWD"
	fi

	# Create the common proxy user in eDirectory
	export OES_DATA="$LDAP_PWD"
	
	#Create common proxy
	#If password is autogenerated, first try with already generated password
	#If proxy creation fails with auto generated password, then try with a policy based password
	$PROXY_UTIL/create_common_proxyuser.sh "$CP_FDN" "$LDAP_ADM" $LDAP_IP $LDAP_PORT "yes"
	USER_CREATED=$?
	if test $USER_CREATED == 0
	then
		echo "Common Proxy user creation is successful"
		echo "[Status] Common Proxy user creation is successful" >> $PROXY_LOGFILE
	elif [[ ( $USER_CREATED = 19 || $USER_CREATED = 80 ) && $AUTO_PWD = 1 ]]	#Creation failed due to password policies
	then
		echo "Common Proxy user creation might have been failed due to password compliance" >>  $PROXY_LOGFILE
		echo "Trying with policy compliant based password" >> $PROXY_LOGFILE
		echo "Common Proxy user creation might have been failed due to password compliance"
		echo "Trying with policy compliant based password"

		#Generate NMAS Policy compliant password
		CP_PWD=`$PROXY_UTIL/randpolicypwd $LDAP_IP 636 1 "$LDAP_ADM" "$LDAP_PWD"  "$CTX_FDN"`
		RAND_PWD=$?
		if test $RAND_PWD == 0
		then
			export OES_PROXY_DATA="$CP_PWD"
			$PROXY_UTIL/create_common_proxyuser.sh "$CP_FDN" "$LDAP_ADM" $LDAP_IP $LDAP_PORT "yes" #Try again creating proxy
			USER_CREATED=$?
			if test $USER_CREATED != 0
			then
				echo "Common Proxy user creation failed with policy based password also. Error $USER_CREATED" 
				echo "Run move_to_common_proxy.sh again"
				echo "[Error] Common Proxy user creation failed with policy based password also. Error $USER_CREATED" >> $PROXY_LOGFILE
				echo "Run move_to_common_proxy.sh again" >> $PROXY_LOGFILE				
				exit $USER_CREATED
			else
				echo "Common Proxy user creation is successful with policy based password"
				echo "[Status] Common Proxy user creation is successful with policy based password" >> $PROXY_LOGFILE
			fi
		else
			echo "Error in generating policy based password: $RAND_PWD. Run move_to_common_proxy.sh again"
			echo "Error in generating policy based password: $RAND_PWD. Run move_to_common_proxy.sh again" >> $PROXY_LOGFILE
			exit $RAND_PWD
		fi
	else
		echo "Common Proxy user creation failed with error $USER_CREATED" 
		echo "[Error] Common Proxy user creation failed with error $USER_CREATED"  >> $PROXY_LOGFILE
		exit $USER_CREATED
	fi

	echo -n "Assign Common Proxy Password Policy to this Proxy User?[y/n]:"
	read PL_ASSIGN
	if test $PL_ASSIGN != "y"
	then
		echo "Not assigning the common proxy password policy might result in a policy assignment that causes issues for the common proxy user."
		echo -n "Want to continue with policy assignment?[y/n]:"
		read PL_ASSIGN
	fi 	
	if test $PL_ASSIGN == "y"
	then
		$PROXY_UTIL/create_common_proxypolicy.sh  "$LDAP_ADM" $LDAP_IP $LDAP_PORT >> /dev/null 2>&1
		POLICY_CREATE=$?
		if test $POLICY_CREATE != 0 
		then 
			echo "Creating the common proxy policy failed."
			echo "[Error]Creating the common proxy policy failed." >> $PROXY_LOGFILE
		else	
			$PROXY_UTIL/attach_proxyuser_pwpolicy.sh "$CP_FDN" "$LDAP_ADM" $LDAP_IP $LDAP_PORT >> /dev/null 2>&1
			ATTACH_POLICY=$?
			if test $ATTACH_POLICY != 0 
			then 
				echo "Policy association Failed. Please complete this task manually at later point."
				echo "[Error]Policy association Failed. Please complete this task manually at later point." >> $PROXY_LOGFILE
			else
				echo "Common Proxy Policy association is successful"
				echo "[Status] Common Proxy Policy association is successful" >> $PROXY_LOGFILE
			fi
		fi
	fi

	#
	# Store the credentials in OCS store.
	
	$PROXY_UTIL/cp_update_proxy_cred.sh "$CP_FDN" >> /dev/null 2>&1
	STORE_IN_OCS=$?
	
	if test $STORE_IN_OCS == 0
	then
		echo "[Status] Common proxy credentials got stored in common OCS store successfully" >> $PROXY_LOGFILE

	fi
	unset OES_PROXY_DATA

	# 
	# Finally add the change proxy password job to crontab.
	#
	$PROXY_UTIL/add_to_crontab.sh >> /dev/null 2>&1

fi

#Parse the service names into an array
oldIFS="$IFS"
IFS=","
I=0
SERVICESTRINGS="$SERVICES"
for SERVTOMOVE in $SERVICESTRINGS
do
#echo "$SERVICE1 $I"
SERVICENAMES[$I]="$SERVTOMOVE"
#echo "Service name from Array: ${SERVICENAMES[$I]}"
let "I += 1"
done
IFS="$oldIFS"
#From now onwards we just do case insensitive comparison.
shopt -s nocasematch

for SERVICE in ${SERVICENAMES[@]}
do 
	echo "$SERVICE"

	# Handle Moving services to common proxy user.
	case $SERVICE in

		"novell-afp")	# check if the service is already installed or not.
				if [ -f "/opt/novell/afptcpd/bin/afp_proxy_rights_assign.sh" ];
		                then
					echo "[Status] novell-afp is chosen to move to common proxy" >> $PROXY_LOGFILE
					#Check if the service is already using the common proxy user.
                                        if [ $UPGRADE -eq 0 ]
                                        then
					/opt/novell/afptcpd/bin/afp_retrieve_proxy_cred.sh username $PROXY_INFO_FILE >> /dev/null 2>&1
				        READ_PROXY_NAME=$?
					if [ $READ_PROXY_NAME -eq 0 ] && [ -f $PROXY_INFO_FILE ]
		                        then
		                                read SRVC_PRXY < $PROXY_INFO_FILE
		                                rm $PROXY_INFO_FILE
		                        fi
                                        fi
		                        SRVC_PRXY=`echo $SRVC_PRXY | tr . ,` 
					PROXY_LEN=$(echo ${#SRVC_PRXY})
					if test $PROXY_LEN != 0 || test $UPGRADE == 1 
					then  
						if test "$SRVC_PRXY" != "$CP_FDN"
						then
							export OES_AFP_DATA="$CP_PWD"
							export OES_ADMIN_DATA="$LDAP_PWD"
							/opt/novell/afptcpd/bin/afp_proxy_rights_assign.sh -u "$CP_FDN" -d "$LDAP_ADM" -i $LDAP_IP -p $LDAP_PORT -s 1  >> /dev/null 2>&1
							MOVE_TO_CP=$?
							if test $MOVE_TO_CP == 0
							then
								echo "[Status] Proxy rights assignment for AFP is successful" >> $PROXY_LOGFILE
								/opt/novell/afptcpd/bin/afp_update_proxy_cred.sh "$CP_FDN" >> /dev/null 2>&1
								STORE_IN_OCS=$?
								if test $STORE_IN_OCS == 0
								then 
									echo "[Status] New proxy credentials got stored for AFP successfully" >> $PROXY_LOGFILE
								else
									echo "[Error] Proxy credentials update failed for AFP" >> $PROXY_LOGFILE
								fi
							fi
					
							if test $MOVE_TO_CP == 0 && test $STORE_IN_OCS == 0
							then
								echo "[Status] AFP is successfully moved to common proxy" >> $PROXY_LOGFILE
								echo "AFP service is successfully moved to common proxy" 
								#Now update Yast sysconfig file for CIFS.
								sed -i "s/CONFIG_AFP_PROXY_USER=\".*\"/CONFIG_AFP_PROXY_USER=\"$CP_FDN\"/g" /etc/sysconfig/novell/afp_*
							else
								echo "[Error] Unable to move AFP to common proxy: $MOVE_TO_CP" >> $PROXY_LOGFILE
								echo "Unable to move AFP to common proxy. Check $PROXY_LOGFILE for more details " 
							fi
							unset OES_AFP_DATA
							unset OES_ADMIN_DATA
						else
							echo "[Status] AFP service is already using the common proxy user" >> $PROXY_LOGFILE
							echo "AFP service is already using the common proxy user"
							#Now update Yast sysconfig file for AFP.
							sed -i "s/CONFIG_AFP_PROXY_USER=\".*\"/CONFIG_AFP_PROXY_USER=\"$CP_FDN\"/g" /etc/sysconfig/novell/afp_*
						fi
					else
						echo "[status] AFP is not using any proxy user on the system. Not reconfguring AFP" >> $PROXY_LOGFILE
						echo "AFP is not using any proxy user on the system. Not reconfguring AFP"
					fi
					unset SRVC_PRXY
				else
					echo "[Error] AFP service is not yet installed on this machine" >> $PROXY_LOGFILE
					echo " AFP service is not yet installed on this machine" 
				fi
				AFP_IS_DONE=1
				;;


		"novell-cifs")	# check if the service is already installed or not.
				if [ -f "/opt/novell/cifs/bin/cifs_proxy_rights_assign.sh" ];
		                then
					echo "[Status] novell-cifs is chosen to move to common proxy" >> $PROXY_LOGFILE
					#Check if the service is already using the common proxy user.
                                        if [ $UPGRADE -eq 0 ]
                                        then
					/opt/novell/cifs/bin/cifs_retrieve_proxy_cred.sh username $PROXY_INFO_FILE >> /dev/null 2>&1
				        READ_PROXY_NAME=$?
					if [ $READ_PROXY_NAME -eq 0 ] && [ -f $PROXY_INFO_FILE ]
		                        then
		                                read SRVC_PRXY < $PROXY_INFO_FILE
		                                rm $PROXY_INFO_FILE
		                        fi
					fi
		                        SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`
					PROXY_LEN=$(echo ${#SRVC_PRXY})
					if test $PROXY_LEN != 0 || test $UPGRADE == 1
					then  
						if test "$SRVC_PRXY" != "$CP_FDN"
						then
							export OES_CIFS_DATA="$CP_PWD"
							export OES_ADMIN_DATA="$LDAP_PWD"
							/opt/novell/cifs/bin/cifs_proxy_rights_assign.sh -u "$CP_FDN" -d "$LDAP_ADM" -i  $LDAP_IP -p $LDAP_PORT -s 1 >> /dev/null 2>&1
							MOVE_TO_CP=$?
							if test $MOVE_TO_CP == 0
							then
								echo "[Status] Proxy rights assignment for CIFS is successful" >> $PROXY_LOGFILE
								/opt/novell/cifs/bin/cifs_update_proxy_cred.sh "$CP_FDN" >> /dev/null 2>&1
								STORE_IN_OCS=$?
								if test $STORE_IN_OCS == 0
								then 
									echo "[Status] New proxy credentials got stored for CIFS successfully" >> $PROXY_LOGFILE
								else
									echo "[Error] Proxy credentials update failed for CIFS" >> $PROXY_LOGFILE
								fi
							fi
					
							if test $MOVE_TO_CP == 0 && test $STORE_IN_OCS == 0
							then
								echo "[Status] CIFS is successfully moved to common proxy" >> $PROXY_LOGFILE
								echo "CIFS service is successfully moved to common proxy" 
								#Now update Yast sysconfig file for CIFS.
								sed -i "s/CONFIG_CIFS_PROXY_USER=\".*\"/CONFIG_CIFS_PROXY_USER=\"$CP_FDN\"/g" /etc/sysconfig/novell/NvlCifs_*
							else
								echo "[Error] Unable to move CIFS to common proxy: $MOVE_TO_CP" >> $PROXY_LOGFILE
								echo "Unable to move CIFS to common proxy. Check $PROXY_LOGFILE for more details " 
							fi
							unset OES_CIFS_DATA
							unset OES_ADMIN_DATA
						else
							echo "[Status] CIFS service is already using the common proxy user" >> $PROXY_LOGFILE
							echo "CIFS service is already using the common proxy user"
							#Now update Yast sysconfig file for CIFS.
							sed -i "s/CONFIG_CIFS_PROXY_USER=\".*\"/CONFIG_CIFS_PROXY_USER=\"$CP_FDN\"/g" /etc/sysconfig/novell/NvlCifs_*
						fi
					else
						echo "[status] CIFS is not using any proxy user on the system. Not reconfguring CIFS" >> $PROXY_LOGFILE
						echo "CIFS is not using any proxy user on the system. Not reconfguring CIFS"
					fi
					unset SRVC_PRXY
				else
					echo "[Error] CIFS service is not yet installed on this machine" >> $PROXY_LOGFILE
					echo " CIFS service is not yet installed on this machine" 
				fi
				CIFS_IS_DONE=1
				;;

		"novell-dns") 	# check if the service is already installed or not.
				if [ -f "/opt/novell/named/bin/dns_change_proxy" ];
		                then
					echo "[Status] novell-dns is chosen to move to common proxy" >> $PROXY_LOGFILE
				        if [ $UPGRADE -eq 0 ]
                                        then
	
					#Check if the service is already using the common proxy user.
					/opt/novell/named/bin/dns_retrieve_proxy_cred username $PROXY_INFO_FILE >> /dev/null 2>&1
		                        READ_PROXY_NAME=$?
					if [ $READ_PROXY_NAME -eq 0 ] && [ -f $PROXY_INFO_FILE ]
		                        then
		                                read SRVC_PRXY < $PROXY_INFO_FILE
		                                rm $PROXY_INFO_FILE
		                        fi
                                        fi
		                        SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`
					PROXY_LEN=$(echo ${#SRVC_PRXY})
					if test $PROXY_LEN != 0 || test $UPGRADE == 1
					then   
						if test "$SRVC_PRXY" != "$CP_FDN"
						then 
							export OES_DNS_DATA="$CP_PWD"
							export OES_ADMIN_DATA="$LDAP_PWD"
							/opt/novell/named/bin/dns_change_proxy "$LDAP_ADM" "$CP_FDN" $LDAP_IP $LDAP_PORT 1 >> /dev/null 2>&1
							MOVE_TO_CP=$?
							if test $MOVE_TO_CP == 0  
							then
								echo "[Status] DNS is successfully moved to Common proxy" >> $PROXY_LOGFILE
								echo "DNS is successfully moved to Common proxy" 
								#Now update Yast sysconfig file for DNS.
								sed -i "s/CONFIG_DNS_LDAP_USER_CONTEXT=\".*\"/CONFIG_DNS_LDAP_USER_CONTEXT=\"$CP_FDN\"/g" /etc/sysconfig/novell/NvlDns_*
							else
								echo "[Error] Unable to move DNS to common proxy: $MOVE_TO_CP" >> $PROXY_LOGFILE
								echo " Unable to move DNS to common proxy. Check $PROXY_LOGFILE for more details"
							fi
							unset OES_DNS_DATA
							unset OES_ADMIN_DATA
						else
							echo "[Status] DNS service is already using the common proxy user" >> $PROXY_LOGFILE
							echo "DNS service is already using the common proxy user"
							#Now update Yast sysconfig file for DNS.
							sed -i "s/CONFIG_DNS_LDAP_USER_CONTEXT=\".*\"/CONFIG_DNS_LDAP_USER_CONTEXT=\"$CP_FDN\"/g" /etc/sysconfig/novell/NvlDns_*
						fi
					else
						echo "[status] DNS is not using any proxy user on the system. Not reconfguring DNS" >> $PROXY_LOGFILE
						echo "DNS is not using any proxy user on the system. Not reconfguring DNS"
					fi
					unset SRVC_PRXY
				else
					echo "[Error] DNS service is not yet installed on this machine" >> $PROXY_LOGFILE
					echo " DNS service is not yet installed on this machine" 
				fi
				DNS_IS_DONE=1
				;;

		"novell-dhcp") 	# check if the service is already installed or not.
				if [ -f "/opt/novell/dhcp/bin/dhcp_proxy_rights_assign" ];
		                then
					echo "[Status] novell-dhcp is chosen to move to common proxy" >> $PROXY_LOGFILE
					#Check if the service is already using the common proxy user.
                                        if [ $UPGRADE -eq 0 ]
					then
					/opt/novell/dhcp/bin/dhcp_retrieve_proxy_cred username $PROXY_INFO_FILE >> /dev/null 2>&1
		                        READ_PROXY_NAME=$?
					if [ $READ_PROXY_NAME -eq 0 ] && [ -f $PROXY_INFO_FILE ]
		                        then
		                                read SRVC_PRXY < $PROXY_INFO_FILE
		                                rm $PROXY_INFO_FILE
		                        fi
					fi
			                SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`
					PROXY_LEN=$(echo ${#SRVC_PRXY})
					if test $PROXY_LEN != 0 || test $UPGRADE == 1
					then
						if test "$SRVC_PRXY" != "$CP_FDN"
						then
							export OES_DHCP_DATA="$CP_PWD"
							export OES_ADMIN_DATA="$LDAP_PWD"
							/opt/novell/dhcp/bin/dhcp_proxy_rights_assign "$CP_FDN" "$LDAP_ADM" $LDAP_IP $LDAP_PORT >> /dev/null 2>&1
							MOVE_TO_CP=$?
							if test $MOVE_TO_CP == 0
							then
								echo "[Status] DHCP is successfully moved to Common proxy" >> $PROXY_LOGFILE
								echo "DHCP is successfully moved to Common proxy" 
								#Now update Yast sysconfig file for DHCP.
								sed -i "s/CONFIG_DHCPSRV_LDAP_USER_CONTEXT=\".*\"/CONFIG_DHCPSRV_LDAP_USER_CONTEXT=\"$CP_FDN\"/g" /etc/sysconfig/novell/NvlDhcp_*
							else
								echo "[Error] Unable to move DHCP to common proxy: $MOVE_TO_CP" >> $PROXY_LOGFILE
								echo "Unable to move DHCP Service to common proxy. Check $PROXY_LOGFILE for more details" 
							fi
							unset OES_DHCP_DATA
							unset OES_ADMIN_DATA
						else
							echo "[Status] DHCP service is already using the common proxy user" >> $PROXY_LOGFILE
							echo "DHCP service is already using the common proxy user"
							#Now update Yast sysconfig file for DHCP.
							sed -i "s/CONFIG_DHCPSRV_LDAP_USER_CONTEXT=\".*\"/CONFIG_DHCPSRV_LDAP_USER_CONTEXT=\"$CP_FDN\"/g" /etc/sysconfig/novell/NvlDhcp_*
						fi
					else
						echo "[status] DHCP is not using any proxy user on the system. Not reconfguring DHCP" >> $PROXY_LOGFILE
						echo "DHCP is not using any proxy user on the system. Not reconfguring DHCP"
					fi
					unset SRVC_PRXY
				else
					echo "[Error] DHCP service is not yet installed on this machine" >> $PROXY_LOGFILE
					echo "DHCP service is not yet installed on this machine" 
				fi
				DHCP_IS_DONE=1
				;;
	
		"novell-netstorage") 	# check if the service is already installed or not.
				if [ -f "/opt/novell/netstorage/bin/ns_update_proxy_cred" ];
		                then
					echo "[Status] NetStorage is chosen to move to common proxy" >> $PROXY_LOGFILE
					#Check if the service is already using the common proxy user.
					if [ $UPGRADE -eq 0 ]	
					then
					/opt/novell/netstorage/bin/ns_retrieve_proxy_cred username $PROXY_INFO_FILE >> /dev/null 2>&1
		                        READ_PROXY_NAME=$?
					if [ $READ_PROXY_NAME -eq 0 ] && [ -f $PROXY_INFO_FILE ]
		                        then
		                                read SRVC_PRXY < $PROXY_INFO_FILE
		                                rm $PROXY_INFO_FILE
		                        fi
					fi
		                        SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`
					PROXY_LEN=$(echo ${#SRVC_PRXY})

					#Exception for NetStorage.
					#NetStoage won't have any OCS entry if it's installed with service specific proxy
					#So for NetStorage, continue to move to proxy even if it doesn't have any proxy in OCS
					if test $PROXY_LEN == 0 || test "$SRVC_PRXY" != "$CP_FDN"
					then
						# Give write permission to proxy log file for novlxsrvd user
						chmod 666 $PROXY_LOGFILE	
						export OES_NETSTORAGE_DATA="$CP_PWD"
						/opt/novell/netstorage/bin/ns_update_proxy_cred "$CP_FDN" >> /dev/null 2>&1
						MOVE_TO_CP=$?
						if test $MOVE_TO_CP == 0
						then
						   echo "[Status] New proxy credentials got stored for NetStorage successfully" >> $PROXY_LOGFILE
						   echo "NetStorage is successfully moved to common proxy"
						   echo "Please assign the necessary rights manually for this new netstorage proxy user" 
						   #Now update Yast sysconfig file for NetStorage.
						   sed -i "s/CONFIG_XTIER_PROXY_CONTEXT=\".*\"/CONFIG_XTIER_PROXY_CONTEXT=\"$CP_FDN\"/g" /etc/sysconfig/novell/netstore_*
						else
						   echo "[Error] Proxy credentials update failed for NetStorage" >> $PROXY_LOGFILE
						   echo "Unable to move NetStorage service to common proxy. Check $PROXY_LOGFILE for more details"
						fi
	
						#Change it back
						chmod 644 $PROXY_LOGFILE
						unset OES_NETSTORAGE_DATA
					else
						if test "$SRVC_PRXY" == "$CP_FDN"
						then
							echo "[Status] NetStorage service is already using the common proxy user" >> $PROXY_LOGFILE
							echo "NetStorage service is already using the common proxy user"
							#Now update Yast sysconfig file for NetStorage.
							sed -i "s/CONFIG_XTIER_PROXY_CONTEXT=\".*\"/CONFIG_XTIER_PROXY_CONTEXT=\"$CP_FDN\"/g" /etc/sysconfig/novell/netstore_*
						fi
					fi
					
					unset SRVC_PRXY
				else
					echo "[Error] NetStorage service is not yet installed on this machine" >> $PROXY_LOGFILE
					echo " NetStorage service is not yet installed on this machine" 
				fi
				NETSTORAGE_IS_DONE=1
				;;

		"novell-ncs") 	# check if the service is already installed or not.
				if [ -f "/opt/novell/ncs/bin/ncs_proxy_rights_assign" ];
		                then
					echo "[Status] NCS is chosen to move to common proxy" >> $PROXY_LOGFILE
					#Check if the service is already using the common proxy user.
					if [ $UPGRADE -eq 0 ]
					then
					/opt/novell/ncs/bin/ncs_retrieve_proxy_cred username $PROXY_INFO_FILE >> /dev/null 2>&1
		                        READ_PROXY_NAME=$?
					if [ $READ_PROXY_NAME -eq 0 ] && [ -f $PROXY_INFO_FILE ]
		                        then
	        	                        read SRVC_PRXY < $PROXY_INFO_FILE
	                	                rm $PROXY_INFO_FILE
	                        	fi
					fi
			                SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`
					PROXY_LEN=$(echo ${#SRVC_PRXY})
					if test $PROXY_LEN != 0 || test $UPGRADE == 1 
					then
						if test "$SRVC_PRXY" != "$CP_FDN"
						then
							export OES_NCS_DATA="$CP_PWD"
							export OES_ADMIN_DATA="$LDAP_PWD"
							/opt/novell/ncs/bin/ncs_proxy_rights_assign "$CP_FDN" "$LDAP_ADM" $LDAP_IP $LDAP_PORT 1 >> /dev/null 2>&1
							MOVE_TO_CP=$?
							if test $MOVE_TO_CP == 0
							then
								echo "[Status] NCS has successfully done the rights assignment for common proxy" >> $PROXY_LOGFILE
								/opt/novell/ncs/bin/ncs_update_proxy_cred "$CP_FDN" >> /dev/null 2>&1
								STORE_IN_OCS=$?
								if test $STORE_IN_OCS == 0
								then 
									echo "[Status] New proxy credentials got stored for NCS successfully" >> $PROXY_LOGFILE
								else
									echo "[Error] Proxy credentials update failed for NCS" >> $PROXY_LOGFILE
								fi
							else
								echo "[Error] NCS has Failed the rights assignment for common proxy: $MOVE_TO_CP" >> $PROXY_LOGFILE
							fi
					
							if test $MOVE_TO_CP == 0 && test $STORE_IN_OCS == 0
							then
								echo "[Status] NCS is successfully moved to common proxy" >> $PROXY_LOGFILE
								echo " NCS is successfully moved to common proxy" 
							   	#Now update Yast sysconfig file for NCS.
								sed -i "s/CONFIG_NCS_PROXY_USER=\".*\"/CONFIG_NCS_PROXY_USER=\"$CP_FDN\"/g" /etc/sysconfig/novell/ncs_*
								sed -i "s/CONFIG_NCS_USE_COMMON_PROXY=\".*\"/CONFIG_NCS_USE_COMMON_PROXY="yes"/g" /etc/sysconfig/novell/ncs_*
							else
								echo "[Error] Unable to move NCS Service to common Proxy" >> $PROXY_LOGFILE
								echo "Unable to move NCS Service to common Proxy.  Check $PROXY_LOGFILE for more details" 
							fi
							unset OES_NCS_DATA
							unset OES_ADMIN_DATA
						else
							echo "[Status] NCS service is already using the common proxy user" >> $PROXY_LOGFILE
							echo "NCS service is already using the common proxy user"
							#Now update Yast sysconfig file for NCS.
							sed -i "s/CONFIG_NCS_PROXY_USER=\".*\"/CONFIG_NCS_PROXY_USER=\"$CP_FDN\"/g" /etc/sysconfig/novell/ncs_*
							sed -i "s/CONFIG_NCS_USE_COMMON_PROXY=\".*\"/CONFIG_NCS_USE_COMMON_PROXY="yes"/g" /etc/sysconfig/novell/ncs_*
						fi
					else
						echo "[status] NCS is not using any proxy user on the system. Not reconfguring NCS" >> $PROXY_LOGFILE
						echo "NCS is not using any proxy user on the system. Not reconfguring NCS"
					fi
					unset SRVC_PRXY
				
				else
					echo "[Error] NCS service is not yet installed on this machine" >> $PROXY_LOGFILE
					echo "NCS service is not yet installed on this machine" 
				fi
				NCS_IS_DONE=1
				;;
	
		"novell-lum")   # check if service is already installed or not
				if [ -f "/var/lib/novell-lum/lum_update_proxy_cred.sh" ];
		                then
					echo "[Status] novell-lum is chosen to move to common proxy" >> $PROXY_LOGFILE
					#Check if the service is already using the common proxy user.
					if [ $UPGRADE == 0 ]
					then
					/usr/bin/lum_retrieve_proxy_cred username $PROXY_INFO_FILE >> /dev/null 2>&1
					READ_PROXY_NAME=$?
					if [ $READ_PROXY_NAME -eq 0 ] && [ -f $PROXY_INFO_FILE ]
		                        then
		                                read SRVC_PRXY < $PROXY_INFO_FILE
		                                rm $PROXY_INFO_FILE
		                        fi
					fi
		                        SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`
					PROXY_LEN=$(echo ${#SRVC_PRXY})
					if test $PROXY_LEN != 0 || test $UPGRADE == 1
					then
						if test  "$SRVC_PRXY" != "$CP_FDN"
						then
							export OES_LUM_DATA="$CP_PWD"
							CP_LUM_FDN=`echo $CP_FDN | tr . ,`
							sh /var/lib/novell-lum/lum_update_proxy_cred.sh "$CP_LUM_FDN" >> /dev/null 2>&1
							STORE_IN_OCS=$?
							if test $STORE_IN_OCS == 0
							then
								echo "[Status] Common proxy credentials got stored in LUM OCS store successfully" >> $PROXY_LOGFILE
								echo "novell-lum is successfully moved to Common proxy " 
							   	#Now update Yast sysconfig file for Novell LUM.
							   	sed -i "s/CONFIG_LUM_PROXY_USER=\".*\"/CONFIG_LUM_PROXY_USER=\"$CP_LUM_FDN\"/g" /etc/sysconfig/novell/lum_*
							else
								echo "[Error] Unable to store the common proxy credentials into LUM OCS" >> $PROXY_LOGFILE
								echo " Unable to move LUM Service to common proxy. Check $PROXY_LOGFILE for more details " 
							fi
							unset OES_LUM_DATA
						else
							echo "[Status] LUM service is already using the common proxy user" >> $PROXY_LOGFILE
							echo "LUM service is already using the common proxy user"
							#Now update Yast sysconfig file for Novell LUM.
							sed -i "s/CONFIG_LUM_PROXY_USER=\".*\"/CONFIG_LUM_PROXY_USER=\"$CP_LUM_FDN\"/g" /etc/sysconfig/novell/lum_*
						fi
					
					else
						echo "[status] LUM is not using any proxy user on the system. Not reconfguring LUM" >> $PROXY_LOGFILE
						echo "LUM is not using any proxy user on the system. Not reconfguring LUM"
					fi
					unset SRVC_PRXY
				else
					echo "[Error] LUM is not yet installed on this machine" >> $PROXY_LOGFILE
					echo "LUM is not yet installed on this machine" 
				fi
				LUM_IS_DONE=1
				;;
		all)		
				echo "[Status] Trying to move all the supported services to common proxy user" >> $PROXY_LOGFILE	
				echo "Trying to move all the supported services to common proxy user" 
				#Move all services to common proxy.
				if test "$AFP_IS_DONE" != 1 
				then
					$PROXY_UTIL/move_to_common_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i $LDAP_IP -p $LDAP_PORT -s novell-afp
				fi
				if test "$CIFS_IS_DONE" != 1 
				then
					$PROXY_UTIL/move_to_common_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i $LDAP_IP -p $LDAP_PORT -s novell-cifs
				fi
				if test "$DNS_IS_DONE" != 1 
				then
					$PROXY_UTIL/move_to_common_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i $LDAP_IP -p $LDAP_PORT -s novell-dns
				fi
				if test "$DHCP_IS_DONE" != 1 
				then
					$PROXY_UTIL/move_to_common_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i $LDAP_IP -p $LDAP_PORT -s novell-dhcp
				fi
				if test "$NETSTORAGE_IS_DONE" != 1 
				then
					$PROXY_UTIL/move_to_common_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i $LDAP_IP -p $LDAP_PORT -s novell-netstorage
				fi
				if test "$NCS_IS_DONE" != 1 
				then
					$PROXY_UTIL/move_to_common_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i $LDAP_IP -p $LDAP_PORT -s novell-ncs
				fi
				if test "$LUM_IS_DONE" != 1 
				then
					$PROXY_UTIL/move_to_common_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i $LDAP_IP -p $LDAP_PORT -s novell-lum
				fi
				break;
				;;

		*)	echo "$SERVICE is either not a valid service or its not under scope for common proxy"	
			echo "Valid service names are: novell-afp, novell-cifs, novell-dns, novell-dhcp,novell-lum,novell-netstorage,novell-ncs and 'all'";;				
	esac
done
#Unsetting the case insensitive option.
shopt -u nocasematch


