#!/bin/sh
#
#Copyright (c) 2012, Novell, Inc.  All rights reserved.
#
# This script is for 
# 1. During pre-check of transfer ID migration this script is used to retrieve the common proxy credentials from source.  
# 2. During repair step of Transfer ID migration this script is used to reconfigure all the services to use the retrieved common proxy user .
# The command is run on target by providing IP of the source and other LDAP parameters required for eDirectory access
# When this script is run manually, user has to export the admin password in the environment variable OES_ADMIN_PWD before running this script.
# The script exclusively is implemented for the enhancement bug#762241

user_id=`id -u`
if test $user_id -ne 0
then 
        echo "retrieve_proxycred_and_reconfigure_services.sh : Only root user can run this script"
        exit 1
fi
		
PROXY_LOGFILE="/var/opt/novell/log/proxymgmt/pxymgmt.log"
#This file is used to store the CP credentials retrieved from source during precheck step of Transfer ID migration. This path is introduced to provide the fix for the enhancement bug#762241
DECRYPTED_CRED_FILE="/var/opt/novell/log/proxymgmt/decrypted_credfile"
ENCRYPTED_CRED_FILE="/var/opt/novell/log/proxymgmt/encrypted_credfile"
CP_CRED_FILE="/var/opt/novell/log/proxymgmt/cp_credfile"
RECONFBINS="/opt/novell/proxymgmt/bin"
SVC_PROXY_TMPFILE="/var/opt/novell/log/proxymgmt/pxyuser.txt"
ENCBINARY="/opt/novell/proxymgmt/bin/oes-enc-dec"
PROXY_UTIL="/opt/novell/proxymgmt/bin"
PROXY_CONF_FILE="/etc/opt/novell/proxymgmt/proxy_users.conf"

Usage() 
{
	echo ""
	echo "Usage: retrieve_proxycred_and_reconfigure_services.sh [options]"
	echo "          -h                      Prints this summary"
	echo "          -s                      Source system IP Address"
	echo "          -d                      LDAP Admin FDN"
	echo "          -w                      LDAP Admin Password"
	echo "          -i                      LDAP Server IP address"
	echo "          -p                      LDAP Port(Only Secure Port like 636)"
	echo "          -c                      Optional. When passed, retrieves the Common Proxy credentials from source. This cannot be passed along with option 'm'"
	echo "          -m                      Optional. When passed reconfigures the services to use Common Proxy. This cannot be passed along with option 'c'"
	echo ""
        echo "          example1: To retrieve the Common Proxy credentials from source"
	echo "                    /opt/novell/proxymgmt/bin/retrieve_proxycred_and_reconfigure_services.sh  -s 192.168.1.1 -d "cn=admin,o=novell" -i 192.168.1.2 -p 636 -c"
        echo "          example2: To reconfigure the services to use Common Proxy on Target Server"
	echo " 			  /opt/novell/proxymgmt/bin/retrieve_proxycred_and_reconfigure_services.sh  -s 192.168.1.1 -d "cn=admin,o=novell" -i 192.168.1.2 -p 636 -m"

	exit 1;
}

#Retrieve service proxy credentials from source system
execute_get_proxy_cred()
{
	echo "Retrieving common proxy credentials from source system" >> $PROXY_LOGFILE

	if [ -f $CP_CRED_FILE ]
	then
		rm -rf $CP_CRED_FILE
	fi

	if [ -f $ENCRYPTED_CRED_FILE ]
        then
                rm -rf $ENCRYPTED_CRED_FILE
        fi

        if [ -f $DECRYPTED_CRED_FILE ]
        then
                rm -rf $DECRYPTED_CRED_FILE
        fi

	#Execute the script on source to retrieve proxy credentials. Password in encrypted format
	#Here, the credential retrieval command is executed on source system and the output is copied to target system.
	#Since we are retrieveing the CP credentials from source server, as a pre-requisite either we need to know the source system credentials or user has to copy the ssh keys on source and 	#target servers. Refer migration admin guide for the steps to copy the ssh keys.
	echo "Retrieving proxy username from source" >> $PROXY_LOGFILE
        ssh root@$SOURCEIP $RECONFBINS/cp_retrieve_proxy_cred username >> $CP_CRED_FILE
        GETPROXYCREDS=$?
        if [ $GETPROXYCREDS -ne 0 ]
        then
                echo "Failed to get proxy username from source system: $GETPROXYCREDS" >> $PROXY_LOGFILE
                return $GETPROXYCREDS
        fi

	#Here, the credential retrieval command is executed on source system and the output is copied to target system.
	echo "Retrieving proxy password in encrypted format from source" >> $PROXY_LOGFILE
	ssh root@$SOURCEIP $RECONFBINS/cp_retrieve_proxy_cred password > $DECRYPTED_CRED_FILE
	GETPROXYCREDS=$?
	if [ $GETPROXYCREDS -eq 0 ]
	then
		$ENCBINARY 1 $DECRYPTED_CRED_FILE $ENCRYPTED_CRED_FILE
        	ENC_PROXY_PWD=$?
        	if [ $ENC_PROXY_PWD -ne 0 ]
        	then
                	echo "Could not encrypt proxy user password: $ENC_PROXY_PWD" >> $PROXY_LOG_FILE
			rm -rf $DECRYPTED_CRED_FILE
                	exit $ENC_PROXY_PWD
        	fi
	fi

	# Delete the file DECRYPTED_CRED_FILE
	if [ -f $DECRYPTED_CRED_FILE ]
	then
		rm -rf $DECRYPTED_CRED_FILE
	fi

	if [ $GETPROXYCREDS -ne 0 ]
	then
		echo "Failed to get proxy password from source system: $GETPROXYCREDS" >> $PROXY_LOGFILE
		rm -rf $CP_CRED_FILE
		rm -rf $ENCRYPTED_CRED_FILE
		return $GETPROXYCREDS
	fi
	#Store the encrypted password in CP_CRED_FILE
	cat $ENCRYPTED_CRED_FILE >> $CP_CRED_FILE

	echo "Successfully retrieved common proxy credentials from source system to $CP_CRED_FILE " >> $PROXY_LOGFILE

	# Delete the file ENCRYPTED_CRED_FILE
	if [ -f $ENCRYPTED_CRED_FILE ]
        then
                rm -rf $ENCRYPTED_CRED_FILE
        fi
}

#Identify the services to be configured on Target Server and then configure these services on using the credentials retrieved from source server.  
reconfigure_common_proxy_services()
{

	#Retrieve current proxy credentials from OCS. If not present, common proxy is not in use. Nothing needs to be done
	OLDCP_DN=`$PROXY_UTIL/cp_retrieve_proxy_cred username`
	OCS_READUSR_RES=$?
	echo "OLDCP_DN is: $OLDCP_DN" >> $PROXY_LOGFILE
	if [ $OCS_READUSR_RES -ne 0 ]
	then
		echo "Common Proxy not configured on the system. Could not retrieve common proxy DN from OCS. Nothing needs to be done: $OCS_READUSR_RES" >> $PROXY_LOGFILE
		echo "Common Proxy not configured on the system. Could not retrieve common proxy DN from OCS. Nothing needs to be done: $OCS_READUSR_RES" 
		exit $OCS_READUSR_RES
	fi

	# Read CP username and password from CP_CRED_FILE
	if [ -f $CP_CRED_FILE ]
	then
		DONE=false
		i=0
		until $DONE
		do
		  read line || DONE=true
		  cred[$i]=$line
		  i=`expr $i + 1`
		done < $CP_CRED_FILE
	else
		echo "CP credential file $CP_CRED_FILE does not exist!" >> $PROXY_LOGFILE
		echo "CP credential file $CP_CRED_FILE does not exist!"
		exit 1
	fi
	
	# Check if username or password is empty
	if [ -z "${cred[0]}" ] || [ -z "${cred[1]}" ]; 
	then
              echo "CP username or password is invalid" >> $PROXY_LOGFILE
	      echo "CP username or password is invalid"
              exit 1
        fi

	# Delete the file DECRYPTED_CRED_FILE if exists
	if [ -f $DECRYPTED_CRED_FILE ]
	then
		rm -rf $DECRYPTED_CRED_FILE
	fi

	# Delete the file ENCRYPTED_CRED_FILE if exists
	if [ -f $ENCRYPTED_CRED_FILE ]
        then
                rm -rf $ENCRYPTED_CRED_FILE
        fi

	# Put the encrypted password in $ENCRYPTED_CRED_FILE
	echo -n "${cred[1]}" > $ENCRYPTED_CRED_FILE

	# Read the encrypted password from file ENCRYPTED_CRED_FILE.
	if [ -f $ENCRYPTED_CRED_FILE ]
	then
		$ENCBINARY 0 $ENCRYPTED_CRED_FILE $DECRYPTED_CRED_FILE
		read PROXYPWD < $DECRYPTED_CRED_FILE
		cred[1]=$PROXYPWD
	else
		echo "CP encrypted credentials file $ENCRYPTED_CRED_FILE does not exist!" >> $PROXY_LOGFILE
		echo "CP encrypted credentials file $ENCRYPTED_CRED_FILE does not exist!"
		exit 1
	fi 

	# Delete the file DECRYPTED_CRED_FILE
	if [ -f $DECRYPTED_CRED_FILE ]
	then
		rm -rf $DECRYPTED_CRED_FILE
	fi

	# Delete the file ENCRYPTED_CRED_FILE
	if [ -f $ENCRYPTED_CRED_FILE ]
        then
                rm -rf $ENCRYPTED_CRED_FILE
        fi

	export OES_PROXY_DATA=${cred[1]}

	NCPCPDN=${cred[0]}
	#Store the credentials in OCS
	/opt/novell/proxymgmt/bin/cp_update_proxy_cred.sh "$NCPCPDN"
	STORE_IN_OCS=$?
	if test $STORE_IN_OCS == 0
	then
		        echo "common proxy credentials got stored in OCS successfully" >> $PROXY_LOGFILE
	else
			echo "Error while storing proxy credentials in OCS. Run the tool again: $STORE_IN_OCS " >> $PROXY_LOGFILE
			echo "Error while storing proxy credentials in OCS. Run the tool again: $STORE_IN_OCS " 
			exit $STORE_IN_OCS
	fi

	#Remove old proxy user name from file /etc/opt/novell/proxymgmt/proxy_users.conf
	#This fix is provided for bug #900245
	echo "Deleting old common proxy user $OLDCP_DN from $PROXY_CONF_FILE" >> $PROXY_LOGFILE
	# Delete old common proxy user only if its lenght is non-zero and it is not empty
	if [ -n "$OLDCP_DN" ] && [ ! -z "$OLDCP_DN" ]
	then
	  sed -i "/${OLDCP_DN}/d" $PROXY_CONF_FILE
	fi


	echo "Retrieving list of services installed with common proxy" >> $PROXY_LOGFILE

	#Get list of services installed to use common proxy

	#AFP
	if [ -f "/opt/novell/afptcpd/bin/afp_retrieve_proxy_cred.sh" ];
	then	
		/opt/novell/afptcpd/bin/afp_retrieve_proxy_cred.sh username $SVC_PROXY_TMPFILE
		if [ -f $SVC_PROXY_TMPFILE ];
		then
			read SRVC_PROXY < $SVC_PROXY_TMPFILE
			echo "AFP : $SRVC_PROXY"
			if [ "$SRVC_PROXY" = "$OLDCP_DN" ]
			then
				echo "AFP is installed with Common Proxy. Will be reconfigured to use new common proxy " >> $PROXY_LOGFILE
				SRVNAME="novell-afp"
				CPSERVICES=`echo $CPSERVICES,$SRVNAME`
			fi
			rm $SVC_PROXY_TMPFILE
		fi
	fi

	#CIFS
	if [ -f "/opt/novell/cifs/bin/cifs_retrieve_proxy_cred.sh" ];
	then	
		/opt/novell/cifs/bin/cifs_retrieve_proxy_cred.sh username $SVC_PROXY_TMPFILE
		if [ -f $SVC_PROXY_TMPFILE ];
		then
			read SRVC_PROXY < $SVC_PROXY_TMPFILE
			if [ "$SRVC_PROXY" = "$OLDCP_DN" ]
			then
				echo "CIFS is installed with Common Proxy. Will be reconfigured to use new common proxy " >> $PROXY_LOGFILE
				SRVNAME="novell-cifs"
				CPSERVICES=`echo $CPSERVICES,$SRVNAME`
			fi
			rm $SVC_PROXY_TMPFILE
		fi
	fi


	#DNS Proxy User 
	if [ -f "/opt/novell/named/bin/dns_retrieve_proxy_cred" ];
	then	
		/opt/novell/named/bin/dns_retrieve_proxy_cred username $SVC_PROXY_TMPFILE			
		if [ -f $SVC_PROXY_TMPFILE ];
		then
			read SRVC_PROXY < $SVC_PROXY_TMPFILE
			rm $SVC_PROXY_TMPFILE
			if [ "$SRVC_PROXY" = "$OLDCP_DN" ];
			then
				echo "DNS is installed with Common Proxy. Will be reconfigured to use new common proxy" >> $PROXY_LOGFILE 
				SRVNAME="novell-dns"
				CPSERVICES=`echo $CPSERVICES,$SRVNAME`
			fi
		fi
	fi

	#DHCP Proxy User 
	if [ -f "/opt/novell/dhcp/bin/dhcp_retrieve_proxy_cred" ];
	then	
		/opt/novell/dhcp/bin/dhcp_retrieve_proxy_cred username $SVC_PROXY_TMPFILE			
		if [ -f $SVC_PROXY_TMPFILE ];
		then
			read SRVC_PROXY < $SVC_PROXY_TMPFILE
			rm $SVC_PROXY_TMPFILE
			if [ "$SRVC_PROXY" = "$OLDCP_DN" ];
			then
				echo "DHCP is installed with Common Proxy. Will be reconfigured to use new common proxy" >> $PROXY_LOGFILE
				SRVNAME="novell-dhcp"
				CPSERVICES=`echo $CPSERVICES,$SRVNAME`
			fi
		fi
	fi

	#NetStorage Proxy User 
	if [ -f "/opt/novell/netstorage/bin/ns_retrieve_proxy_cred" ];
	then	
		/opt/novell/netstorage/bin/ns_retrieve_proxy_cred username $SVC_PROXY_TMPFILE			
		if [ -f $SVC_PROXY_TMPFILE ];
		then
			read SRVC_PROXY < $SVC_PROXY_TMPFILE
			SRVC_PROXY=`echo $SRVC_PROXY | tr . ,`
			rm $SVC_PROXY_TMPFILE
			if [ "$SRVC_PROXY" = "$OLDCP_DN" ];
			then
				echo "NetStorage is installed with Common Proxy. Will be reconfigured to use new common proxy" >> $PROXY_LOGFILE
				SRVNAME="novell-netstorage"
				CPSERVICES=`echo $CPSERVICES,$SRVNAME`
			fi
		fi
	fi

	#NCS Proxy User 
	if [ -f "/opt/novell/ncs/bin/ncs_retrieve_proxy_cred" ];
	then	
		/opt/novell/ncs/bin/ncs_retrieve_proxy_cred username $SVC_PROXY_TMPFILE			
		if [ -f $SVC_PROXY_TMPFILE ];
		then
			read SRVC_PROXY < $SVC_PROXY_TMPFILE
			rm $SVC_PROXY_TMPFILE
			if [ "$SRVC_PROXY" = "$OLDCP_DN" ];
			then
				echo "Novell Cluster Services is installed with Common Proxy. Will be reconfigured to use new common proxy." >> $PROXY_LOGFILE
				SRVNAME="novell-ncs"
				CPSERVICES=`echo $CPSERVICES,$SRVNAME`
			fi
		fi
	fi

	#LUM Proxy User 
	if [ -f "/usr/bin/lum_retrieve_proxy_cred" ];
	then	
		/usr/bin/lum_retrieve_proxy_cred username $SVC_PROXY_TMPFILE		
		if [ -f $SVC_PROXY_TMPFILE ];
		then
			read SRVC_PROXY < $SVC_PROXY_TMPFILE
			rm $SVC_PROXY_TMPFILE
			if [ "$SRVC_PROXY" = "$OLDCP_DN" ];
			then
				echo "LUM is installed with Common Proxy. Will be reconfigured to use new common proxy" >> $PROXY_LOGFILE
				SRVNAME="novell-lum"
				CPSERVICES=`echo $CPSERVICES,$SRVNAME`
			fi
		fi
	fi

	if test "$CPSERVICES" = ""
	then
		echo "No service is using $OLDCP_DN. No service is reconfigured " >> $PROXY_LOGFILE
		echo "No service is using $OLDCP_DN. No service is reconfigured "
		exit 0
	fi

	# Substitute the comma separator by a forward slash.
	CPSERVICES=`echo "$CPSERVICES" | sed 's/^,//'`
	echo "Services getting reconfigured to use new common proxy: $CPSERVICES" >> $PROXY_LOGFILE
	echo "Services getting reconfigured to use new common proxy: $CPSERVICES" 

	# Call this script to reconfigure the identified services to use the common proxy.
	/opt/novell/proxymgmt/bin/move_to_common_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i $LDAP_IP -p $LDAP_PORT -s $CPSERVICES

	echo "Reconfiguring the system for common proxy is completed" >> $PROXY_LOGFILE
	echo "Reconfiguring the system for common proxy is completed"
	echo "Refer to $PROXY_LOGFILE for more details" 
}

if test $# -eq 0
then
	Usage
fi

#Get the parameters
COPYCRED=false
MIGRATE_PROXY=false
while getopts s:d:w:i:p:h:cm o
do		
	case "$o" in
	             d)LDAP_ADM="$OPTARG";;
	             w)LDAP_PWD="$OPTARG";;
	             i)LDAP_IP="$OPTARG";;
	             p)LDAP_PORT="$OPTARG";;
		     s)SOURCEIP="$OPTARG";;
		     c)COPYCRED=true;;
		     m)MIGRATE_PROXY=true;;
		     h)Usage;;
	           [?]) Usage;;
	esac
done

#LDAP connection parameters and source IP are must
if test "$LDAP_ADM" = "" || test "$LDAP_IP" = "" || test "$LDAP_PORT" = "" || test "$SOURCEIP" = ""
then
	Usage
fi

if test $COPYCRED == true && test $MIGRATE_PROXY == true
then
	echo "Options 'c' and 'm' cannot be passed together"
	Usage
fi

if test $COPYCRED == false && test $MIGRATE_PROXY == false
then
	echo "Either option 'c' or 'm' has to be passed"
	Usage
fi

#If Admin password is not passed through command line, it should be passed through environment variable OES_ADMIN_PWD
if test "$LDAP_PWD" = ""
then
	LDAP_PWD="$OES_ADMIN_PWD"
	if test "$LDAP_PWD" = ""
	then
		echo "LDAP Admin password is not provided"
		Usage
	fi
fi

#This script can be used to retrieve the CP credentials from source as well as to reconfigure services on target. When the option 'c' is passed, the script just retrieves the CP credentials from
#Source to Target. When the option 'm' is passed, the script reconfigures the services on the target to use the retrieved CP credentials from source.
if test $COPYCRED == true
then
	execute_get_proxy_cred
fi

if test $MIGRATE_PROXY == true
then
	reconfigure_common_proxy_services
fi
