#!/bin/sh 
#
#Copyright (c) 2012, Novell, Inc.  All rights reserved.
#
# This script is used to retrieve service proxy credentials on the system 
# Proxy credentials are saved in /var/opt/novell/proxymig/proxycred
# The script is implemented for proxy migration between different OES versions

user_id=`id -u`
if test $user_id -ne 0
then 
        echo "services_get_proxy_cred.sh : Only root user can run this script"
        exit 1
fi
		
CP_UTIL="/opt/novell/proxymgmt/bin/cp_retrieve_proxy_cred"
PROXY_LOGFILE="/var/opt/novell/log/proxymgmt/pxymgmt.log"
CRED_FILE="/var/opt/novell/log/proxymgmt/proxycred"
CRED_TEMP_FILE="/var/opt/novell/log/proxymgmt/tempcred"
GETCREDBINS="/opt/novell/proxymgmt/bin"
IGNORECP=""
ENCRYPTCRED="yes"

Usage() 
{
	echo ""
	echo "Usage: services_reconfig_proxy.sh [options]"
	echo "          -h			Prints this summary"
	#echo "		-f			Path to credentials file (Optional)"
	echo "          -e			(Optional) yes or no. Encrypt the credentials or not. Default yes"
	echo "          -I			(Optional) yes or no. Ignore services using common proxy. Default is yes"
	echo ""
	
	exit 1;
}

: '
if test $# -eq 0
then
	Usage
fi
'

#Get the parameters
while getopts e:I:h o
do		
	case "$o" in
	            
#	             f)CREDSFILE="$OPTARG";;
		     e)ENCORNO="$OPTARG";;
		     I)IGNORECP="$OPTARG";;
	             h)Usage;;
	           [?]) Usage;;
	esac
done

: '
if test "$CREDSFILE" != ""
then
	CRED_FILE=$CREDSFILE
fi
'

if test "$IGNORECP" = ""
then
	IGNORECP="yes"
fi

if test "$ENCORNO" != ""
then
	ENCORNO=`echo $ENCORNO | tr '[:upper:]' '[:lower:]'`
	ENCRYPTCRED="$ENCORNO"
fi

echo "===============================================================" >> $PROXY_LOGFILE
echo "`date`:Starting retrieval of service proxy credentials" >> $PROXY_LOGFILE
echo "===============================================================" >> $PROXY_LOGFILE

IGNORECP=`echo $IGNORECP | tr '[:upper:]' '[:lower:]'`

if [ -f "/opt/novell/proxymgmt/bin/cp_retrieve_proxy_cred" ];
then
	if [ "$IGNORECP" = "yes" ]
	then
		CP_FDN=`$CP_UTIL username`	#Get Common Proxy credentials
		READ_CP_FDN=$?
		if [ $READ_CP_FDN -ne 0 ]
		then
			echo "Failed to retrieve common proxy credentials: $READ_CP_FDN" >> $PROXY_LOGFILE
			exit $READ_CP_FDN
		fi
	
		#If common proxy doesn't exist on system, it's same as ignore CP
		if test "$CP_FDN" = ""
		then
			IGNORECP="yes"
		fi
	fi
else
	#Common proxy doesn't exist at all. It's same as take all services
	IGNORECP='yes'
fi

#Start retrieval of service credentials one by one

#CIFS
if [ -f "/opt/novell/cifs/bin/cifs_retrieve_proxy_cred.sh" ];	
then
	echo "Starting CIFS proxy retrieval" >> $PROXY_LOGFILE
	/opt/novell/cifs/bin/cifs_retrieve_proxy_cred.sh username $CRED_TEMP_FILE >> /dev/null 2>&1
	READ_PROXY_CRED=$?
	if [ $READ_PROXY_CRED -eq 0 ] && [ -f $CRED_TEMP_FILE ]
	then
		read SRVC_PRXY < $CRED_TEMP_FILE
		rm $CRED_TEMP_FILE
		
		if test $SRVC_PRXY != ""	#Don't proceed if we can't get proxy user
		then
			#Ignore the service if it's already configured to use common proxy on the system
			if test "$IGNORECP" = "no"
			then
				$GETCREDBINS/cifs_get_proxy_cred.sh -e $ENCRYPTCRED >> /dev/null 2>&1
				GET_CREDS=$?
				if [ $GET_CREDS -ne 0 ]
				then
					echo "Retrieval of CIFS proxy user credentials has failed: $GET_CREDS " >> $PROXY_LOGFILE
				fi
			else
				#Retrieve proxy creds if they are different from common proxy
				if test "$SRVC_PRXY" !=  "$CP_FDN"
				then
					$GETCREDBINS/cifs_get_proxy_cred.sh -e $ENCRYPTCRED >> /dev/null 2>&1
					GET_CREDS=$?
					if [ $GET_CREDS -ne 0 ]
					then
						echo "Retrieval of CIFS proxy user credentials has failed: $GET_CREDS " >> $PROXY_LOGFILE
					fi
				else
					echo "CIFS credentials are not retrieved as it's using common proxy: $CP_FDN" >> $PROXY_LOGFILE
					echo "Nothing to be done" >> $PROXY_LOGFILE
				fi
			fi
		else
			echo "CIFS Service doesn't have proxy configured" >> $PROXY_LOGFILE
		fi
	else
		echo "Failed to get current CIFS proxy user name: $READ_PROXY_CRED " >> $PROXY_LOGFILE
	fi
fi

#AFO
if [ -f "/opt/novell/afptcpd/bin/afp_retrieve_proxy_cred.sh" ];	
then
	echo "Starting AFP proxy retrieval" >> $PROXY_LOGFILE
	/opt/novell/afptcpd/bin/afp_retrieve_proxy_cred.sh username $CRED_TEMP_FILE >> /dev/null 2>&1
	READ_PROXY_CRED=$?
	if [ $READ_PROXY_CRED -eq 0 ] && [ -f $CRED_TEMP_FILE ]
	then
		read SRVC_PRXY < $CRED_TEMP_FILE
		rm $CRED_TEMP_FILE
		
		if test $SRVC_PRXY != ""	#Don't proceed if we can't get proxy user
		then
			#Ignore the service if it's already configured to use common proxy on the system
			if test "$IGNORECP" = "no"
			then
				$GETCREDBINS/afp_get_proxy_cred.sh -e $ENCRYPTCRED >> /dev/null 2>&1
				GET_CREDS=$?
				if [ $GET_CREDS -ne 0 ]
				then
					echo "Retrieval of AFP proxy user credentials has failed: $GET_CREDS " >> $PROXY_LOGFILE
				fi
			else
				#Retrieve proxy creds if they are different from common proxy
				if test "$SRVC_PRXY" !=  "$CP_FDN"
				then
					$GETCREDBINS/afp_get_proxy_cred.sh -e $ENCRYPTCRED >> /dev/null 2>&1
					GET_CREDS=$?
					if [ $GET_CREDS -ne 0 ]
					then
						echo "Retrieval of AFP proxy user credentials has failed: $GET_CREDS " >> $PROXY_LOGFILE
					fi
				else
					echo "AFP credentials are not retrieved as it's using common proxy: $CP_FDN" >> $PROXY_LOGFILE
					echo "Nothing to be done" >> $PROXY_LOGFILE
				fi
			fi
		else
			echo "AFP Service doesn't have proxy configured" >> $PROXY_LOGFILE
		fi
	else
		echo "Failed to get current AFP proxy user name: $READ_PROXY_CRED " >> $PROXY_LOGFILE
	fi
fi

#DNS
if [ -f "/opt/novell/named/bin/dns_retrieve_proxy_cred" ];	
then
	echo "Starting DNS proxy retrieval" >> $PROXY_LOGFILE
	/opt/novell/named/bin/dns_retrieve_proxy_cred username $CRED_TEMP_FILE >> /dev/null 2>&1
	READ_PROXY_CRED=$?
	if [ $READ_PROXY_CRED -eq 0 ] && [ -f $CRED_TEMP_FILE ]
	then
		read SRVC_PRXY < $CRED_TEMP_FILE
		rm $CRED_TEMP_FILE

		if test $SRVC_PRXY != ""	#Don't proceed if we can't get proxy user
		then		
			#Ignore the service if it's already configured to use common proxy on the system
			if test "$IGNORECP" = "no"
			then
				$GETCREDBINS/dns_get_proxy_cred.sh -e $ENCRYPTCRED >> /dev/null 2>&1
				GET_CREDS=$?
				if [ $GET_CREDS -ne 0 ]
				then
					echo "Retrieval of DNS proxy user credentials has failed: $GET_CREDS " >> $PROXY_LOGFILE
				fi
			else
				#Retrieve proxy creds if they are different from common proxy
				if test "$SRVC_PRXY" !=  "$CP_FDN"
				then
					$GETCREDBINS/dns_get_proxy_cred.sh -e $ENCRYPTCRED >> /dev/null 2>&1
					GET_CREDS=$?
					if [ $GET_CREDS -ne 0 ]
					then
						echo "Retrieval of DNS proxy user credentials has failed: $GET_CREDS " >> $PROXY_LOGFILE
					fi
				else
					echo "DNS credentials are not retrieved as it's using common proxy: $CP_FDN" >> $PROXY_LOGFILE
					echo "Nothing to be done" >> $PROXY_LOGFILE
				fi
			fi
		else
			echo "DNS Service doesn't have proxy configured" >> $PROXY_LOGFILE
		fi
	else
		echo "Failed to get current DNS proxy user name: $READ_PROXY_CRED " >> $PROXY_LOGFILE
	fi
fi


#DHCP
if [ -f "/opt/novell/dhcp/bin/dhcp_retrieve_proxy_cred" ];	
then
	echo "Starting DHCP proxy retrieval" >> $PROXY_LOGFILE
	/opt/novell/dhcp/bin/dhcp_retrieve_proxy_cred username $CRED_TEMP_FILE >> /dev/null 2>&1
	READ_PROXY_CRED=$?
	if [ $READ_PROXY_CRED -eq 0 ] && [ -f $CRED_TEMP_FILE ]
	then
		read SRVC_PRXY < $CRED_TEMP_FILE
		rm $CRED_TEMP_FILE
		
		if test $SRVC_PRXY != ""	#Don't proceed if we can't get proxy user
		then
			#Ignore the service if it's already configured to use common proxy on the system
			if test "$IGNORECP" = "no"
			then
				$GETCREDBINS/dhcp_get_proxy_cred.sh -e $ENCRYPTCRED >> /dev/null 2>&1
				GET_CREDS=$?
				if [ $GET_CREDS -ne 0 ]
				then
					echo "Retrieval of DHCP proxy user credentials has failed: $GET_CREDS " >> $PROXY_LOGFILE
				fi
			else
				#Retrieve proxy creds if they are different from common proxy
				if test "$SRVC_PRXY" !=  "$CP_FDN"
				then
					$GETCREDBINS/dhcp_get_proxy_cred.sh -e $ENCRYPTCRED >> /dev/null 2>&1
					GET_CREDS=$?
					if [ $GET_CREDS -ne 0 ]
					then
						echo "Retrieval of DHCP proxy user credentials has failed: $GET_CREDS " >> $PROXY_LOGFILE
					fi
				else
					echo "DHCP credentials are not retrieved as it's using common proxy: $CP_FDN" >> $PROXY_LOGFILE
					echo "Nothing to be done" >> $PROXY_LOGFILE
				fi
			fi
		else
			echo "DHCP Service doesn't have proxy configured" >> $PROXY_LOGFILE
		fi
	else
		echo "Failed to get current DHCP proxy user name: $READ_PROXY_CRED " >> $PROXY_LOGFILE
	fi
fi

#NetStorage
if [ -f "/opt/novell/netstorage/bin/ns_retrieve_proxy_cred" ];	
then
	echo "Starting NetStorage proxy retrieval" >> $PROXY_LOGFILE
	/opt/novell/netstorage/bin/ns_retrieve_proxy_cred username $CRED_TEMP_FILE >> /dev/null 2>&1
	READ_PROXY_CRED=$?
	if [ $READ_PROXY_CRED -eq 0 ] && [ -f $CRED_TEMP_FILE ]
	then
		read SRVC_PRXY < $CRED_TEMP_FILE
		rm $CRED_TEMP_FILE

		#If the username retrieved is in dot format, then replace the dot by comma. This is because while comparing this with CP_FDN (which is always in comma format) gives incorrect
		#results.
		SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`
		if test $SRVC_PRXY != ""	#Don't proceed if we can't get proxy user
		then
			#Ignore the service if it's already configured to use common proxy on the system
			if test "$IGNORECP" = "no"
			then
				$GETCREDBINS/netstorage_get_proxy_cred.sh -e $ENCRYPTCRED >> /dev/null 2>&1
				GET_CREDS=$?
				if [ $GET_CREDS -ne 0 ]
				then
					echo "Retrieval of NetStorage proxy user credentials has failed: $GET_CREDS " >> $PROXY_LOGFILE
				fi
			else
				#Retrieve proxy creds if they are different from common proxy
				if test "$SRVC_PRXY" !=  "$CP_FDN"
				then
					$GETCREDBINS/netstorage_get_proxy_cred.sh -e $ENCRYPTCRED >> /dev/null 2>&1
					GET_CREDS=$?
					if [ $GET_CREDS -ne 0 ]
					then
						echo "Retrieval of NetStorage proxy user credentials has failed: $GET_CREDS " >> $PROXY_LOGFILE
					fi
				else
					echo "NetStorage credentials are not retrieved as it's using common proxy: $CP_FDN" >> $PROXY_LOGFILE
					echo "Nothing to be done" >> $PROXY_LOGFILE
				fi
			fi
		else
			echo "NetStorage Service doesn't have proxy configured" >> $PROXY_LOGFILE
		fi
	else
		echo "Failed to get current NetStorage proxy user name: $READ_PROXY_CRED " >> $PROXY_LOGFILE
	fi
fi


#NCS
if [ -f "/opt/novell/ncs/bin/ncs_retrieve_proxy_cred" ];	
then
	echo "Starting NCS proxy retrieval" >> $PROXY_LOGFILE
	/opt/novell/ncs/bin/ncs_retrieve_proxy_cred username $CRED_TEMP_FILE >> /dev/null 2>&1
	READ_PROXY_CRED=$?
	if [ $READ_PROXY_CRED -eq 0 ] && [ -f $CRED_TEMP_FILE ]
	then
		read SRVC_PRXY < $CRED_TEMP_FILE
		rm $CRED_TEMP_FILE
		
		#If the username retrieved is in dot format, then replace the dot by comma. This is because while comparing this with CP_FDN (which is always in comma format) gives incorrect
		#results.
		SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`
		if test $SRVC_PRXY != ""	#Don't proceed if we can't get proxy user
		then
			#Ignore the service if it's already configured to use common proxy on the system
			if test "$IGNORECP" = "no"
			then
				$GETCREDBINS/ncs_get_proxy_cred.sh -e $ENCRYPTCRED >> /dev/null 2>&1
				GET_CREDS=$?
				if [ $GET_CREDS -ne 0 ]
				then
					echo "Retrieval of NCS proxy user credentials has failed: $GET_CREDS " >> $PROXY_LOGFILE
				fi
			else
				#Retrieve proxy creds if they are different from common proxy
				if test "$SRVC_PRXY" !=  "$CP_FDN"
				then
					$GETCREDBINS/ncs_get_proxy_cred.sh -e $ENCRYPTCRED >> /dev/null 2>&1
					GET_CREDS=$?
					if [ $GET_CREDS -ne 0 ]
					then
						echo "Retrieval of NCS proxy user credentials has failed: $GET_CREDS " >> $PROXY_LOGFILE
					fi
				else
					echo "NCS credentials are not retrieved as it's using common proxy: $CP_FDN" >> $PROXY_LOGFILE
					echo "Nothing to be done" >> $PROXY_LOGFILE
				fi
			fi
		else
			echo "NCS Service doesn't have proxy configured" >> $PROXY_LOGFILE
		fi
	else
		echo "Failed to get current NCS proxy user name: $READ_PROXY_CRED " >> $PROXY_LOGFILE
	fi
fi


#LUM
if [ -f "/usr/bin/lum_retrieve_proxy_cred" ];	
then
	echo "Starting LUM proxy retrieval" >> $PROXY_LOGFILE
	/usr/bin/lum_retrieve_proxy_cred username $CRED_TEMP_FILE >> /dev/null 2>&1
	READ_PROXY_CRED=$?
	if [ $READ_PROXY_CRED -eq 0 ] && [ -f $CRED_TEMP_FILE ]
	then
		read SRVC_PRXY < $CRED_TEMP_FILE
		rm $CRED_TEMP_FILE
		
		#If the username retrieved is in dot format, then replace the dot by comma. This is because while comparing this with CP_FDN (which is always in comma format) gives incorrect
		#results.
		SRVC_PRXY=`echo $SRVC_PRXY | tr . ,`
		if test $SRVC_PRXY != ""	#Don't proceed if we can't get proxy user
		then
			#Ignore the service if it's already configured to use common proxy on the system
			if test "$IGNORECP" = "no"
			then
				$GETCREDBINS/lum_get_proxy_cred.sh -e $ENCRYPTCRED >> /dev/null 2>&1
				GET_CREDS=$?
				if [ $GET_CREDS -ne 0 ]
				then
					echo "Retrieval of LUM proxy user credentials has failed: $GET_CREDS " >> $PROXY_LOGFILE
				fi
			else
				#Retrieve proxy creds if they are different from common proxy
				if test "$SRVC_PRXY" !=  "$CP_FDN"
				then
					$GETCREDBINS/lum_get_proxy_cred.sh -e $ENCRYPTCRED >> /dev/null 2>&1
					GET_CREDS=$?
					if [ $GET_CREDS -ne 0 ]
					then
						echo "Retrieval of LUM proxy user credentials has failed: $GET_CREDS " >> $PROXY_LOGFILE
					fi
				else
					echo "LUM credentials are not retrieved as it's using common proxy: $CP_FDN" >> $PROXY_LOGFILE
					echo "Nothing to be done" >> $PROXY_LOGFILE
				fi
			fi
		else
			echo "LUM Service doesn't have proxy configured" >> $PROXY_LOGFILE
		fi
	else
		echo "Failed to get current LUM proxy user name: $READ_PROXY_CRED " >> $PROXY_LOGFILE
	fi
fi

echo "===============================================================" >> $PROXY_LOGFILE
echo "`date`:Retrieval of service(s) proxy credentials is completed. Credentials are written to $CRED_FILE" >> $PROXY_LOGFILE
echo "===============================================================" >> $PROXY_LOGFILE

echo "Retrieval of proxy user credentials is completed. Credentials are written to $CRED_FILE. Refer to $PROXY_LOGFILE for more details"

exit 0
