#!/bin/sh 
#
#Copyright (c) 2012, Novell, Inc.  All rights reserved.
#
# This script is used to automatically reconfigure the services 
# as per the proxy credentials stored in /var/opt/novell/proxymig/proxycred
# The script is implemented for proxy migration between different OES versions

user_id=`id -u`
if test $user_id -ne 0
then 
        echo "services_reconfig_proxy.sh : Only root user can run this script"
        exit 1
fi
		
CP_UTIL="/opt/novell/proxymgmt/bin/cp_retrieve_proxy_cred"
PROXY_UTIL="/opt/novell/proxymgmt/bin"
PROXY_LOGFILE="/var/opt/novell/log/proxymgmt/pxymgmt.log"
CRED_FILE="/var/opt/novell/log/proxymgmt/proxycred"
CRED_TEMP_FILE="/var/opt/novell/log/proxymgmt/tempcred"
ENCBINARY="/opt/novell/proxymgmt/bin/oes-enc-dec"
RECONFBINS="/opt/novell/proxymgmt/bin"
IGNORECP=""
ENCRYPTCRED="yes"

Usage() 
{
	echo ""
	echo "Usage: services_reconfig_proxy.sh [options]"
	echo "          -h			Prints this summary"
	echo "          -d			LDAP Admin FDN"
	echo "          -w			LDAP Admin Password"
	echo "          -i			LDAP Server IP address"
	echo "          -p			LDAP Port(Only Secure Port like 636)"
	#echo "         -f			Path to credentials file (Optional)"
	echo "          -e			(Optional) yes or no. Credentials in file are encrypted or not. Default yes"
	echo "          -I			(Optional) yes or no. Ignore services using common proxy. Default yes"
	echo ""
	
	exit 1;
}

if test $# -eq 0
then
	Usage
fi

#Get the parameters
while getopts d:w:i:p:e:I:h o
do		
	case "$o" in
	             d)LDAP_ADM="$OPTARG";;
	             w)LDAP_PWD="$OPTARG";;
	             i)LDAP_IP="$OPTARG";;
	             p)LDAP_PORT="$OPTARG";;
#	             f)CREDSFILE="$OPTARG";;
		     e)ENCORNO="$OPTARG";;
		     I)IGNORECP="$OPTARG";;
	             h)Usage;;
	           [?]) Usage;;
	esac
done

#LDAP connection parameters are must
if test "$LDAP_ADM" = "" || test "$LDAP_IP" = "" || test "$LDAP_PORT" = "" 
then
	Usage
fi

#If Admin password can be passed through environment variable OES_ADMIN_PWD. Prompt for LDAP Admin password if not passed through command line or Environment Variable. Modified below block to 
#provide fix for the bug #762241
if test "$LDAP_PWD" = ""
then
	
	LDAP_PWD="$OES_ADMIN_PWD"
	if test "$LDAP_PWD" = ""
	then
		echo "Please enter LDAP admin password"
		mode=`stty -g`
		stty -echo
		read LDAP_PWD
		stty $mode
	fi
fi

: '
if test "$CREDSFILE" != ""
then
	CRED_FILE=$CREDSFILE
fi
'

if test "$IGNORECP" = ""
then
	IGNORECP="yes"
fi

if test "$ENCORNO" != ""
then
	ENCORNO=`echo $ENCORNO | tr '[:upper:]' '[:lower:]'`
	ENCRYPTCRED="$ENCORNO"
fi

echo "************************************************" >> $PROXY_LOGFILE
echo "`date`:[status] Starting Common Proxy Reconfiguration  Task" >> $PROXY_LOGFILE

#Retrieve current proxy credentials from OCS. If not present, common proxy is not in use. Nothing needs to be done
OLDCP_DN=`$PROXY_UTIL/cp_retrieve_proxy_cred username`
OCS_READUSR_RES=$?
if [ $OCS_READUSR_RES -ne 0 ]
then
        echo "Common Proxy not configured on the system. Could not retrieve common proxy DN from OCS. Nothing needs to be done: $OCS_READUSR_RES" >> $PROXY_LOGFILE
        echo "Common Proxy not configured on the system. Could not retrieve common proxy DN from OCS. Nothing needs to be done: $OCS_READUSR_RES" 
        exit $OCS_READUSR_RES
fi

CP_PWD=`$PROXY_UTIL/randpwd.sh` #Generate a random password
export OES_PROXY_DATA="$CP_PWD"
echo "Current Proxy DN: $OLDCP_DN" >> $PROXY_LOGFILE
OLDCPCN=`echo $OLDCP_DN | cut -d"," -f1`
echo "Current Proxy CN: $OLDCPCN" >> $PROXY_LOGFILE
DUPOLDCP=$OLDCP_DN
OLDCPCNTXT=`echo ${DUPOLDCP#*,}`
echo "Current Proxy Context: $OLDCPCNTXT" >> $PROXY_LOGFILE

#Now form the common proxy DN as per the NCP server name
#NCP Server name is retrieved from Root DSE
ROOTDSE=`env LDAPTLS_CACERT=/etc/opt/novell/certs/SSCert.pem /usr/bin/ldapsearch -D "" -s base -H ldaps://LDAP_IP:636 | grep dsaName`
LDAP_SEA_RES=$?
#Exit if we can't read from RootDSE
if test "$ROOTDSE" = ""
then
	echo "Failed to get the NCP Server name from From RootDSE. Run this script again manually: $LDAP_SEA_RES " >> $PROXY_LOGFILE
	echo "Failed to get the NCP Server name from From RootDSE. Run this script again manually: $LDAP_SEA_RES " 
	exit $LDAP_SEA_RES
fi

echo "DSA Entry from from RootDSE: $ROOTDSE" >> $PROXY_LOGFILE

#Extract the  NCP Server DN from RootDSE entry
NCPDN=`echo $ROOTDSE | cut -d" " -f2`
echo "NCP Server DN: $NCPDN" >> $PROXY_LOGFILE

#Extract the NCP Server CN
NCPCN=`echo $NCPDN | cut -d"," -f1`
echo "NCP Server CN: $NCPCN" >> $PROXY_LOGFILE

#Extract the NCP Server Context
NCPDUP=$NCPDN
NCPCNTXT=`echo ${NCPDUP#*,}`
echo "NCP Server Context: $NCPCNTXT" >> $PROXY_LOGFILE
 
#Get the Server Name by removing cn=
NCPHOSTNAME=`echo $NCPCN | cut -d"=" -f2`
echo "NCP Server Host Name: $NCPHOSTNAME" >> $PROXY_LOGFILE

#Form the Common Proxy CN for the host
NCPCPCN=`echo cn=OESCommonProxy_$NCPHOSTNAME`
echo "Common Proxy Name for the system should be: $NCPCPCN" >> $PROXY_LOGFILE


#If the current proxy is same the one we want, then exit
if [[ "$OLDCPCN" = "$NCPCPCN" ]]
then
	echo "Current Proxy is already configured with host name. Nothing needs to be done" >> $PROXY_LOGFILE
	echo "Current Proxy is already configured with host name. Nothing needs to be done" 
	exit 0;
else
	echo "Current Proxy user will be renamed as per the NCP Server host name" >> $PROXY_LOGFILE
fi

NCPCPDN=`echo $NCPCPCN,$OLDCPCNTXT`

#Rename the old proxy user as per the host name
echo "Common Proxy $OLDCP_DN is getting renamed to: $NCPCPDN" >> $PROXY_LOGFILE		
# -r option is added to below command to provide fix for bug#806982
# Enclosing the admin password in double quotes to support special characters. This is the fix for the bug #845803
export LDAPTLS_REQCERT=never
export OES_DATA="$LDAP_PWD"
echo "Resetting password in eDirectory"
echo "Resetting password in eDirectory" >> $PROXY_LOGFILE
/opt/novell/proxymgmt/bin/change_pwd_upgrade.sh -u "$NCPCPDN" -p "$LDAP_ADM"

STORE_IN_OCS=$?
if test $STORE_IN_OCS == 0
then
                echo "common proxy credentials got stored in eDirectory successfully" >> $PROXY_LOGFILE
else
		echo "Error while storing proxy credentials in eDirectory: $STORE_IN_OCS " >> $PROXY_LOGFILE
                exit $STORE_IN_OCS
fi

unset LDAPTLS_REQCERT
#change in cred store
sed -i "s/CONFIG_LDAP_PROXY_CONTEXT=\".*\"/CONFIG_LDAP_PROXY_CONTEXT=\"$NCPCPCN,$NCPCNTXT\"/g" /etc/sysconfig/novell/oes-ldap


echo "===============================================================" >> $PROXY_LOGFILE
echo "`date`:Starting service proxy reconfiguration" >> $PROXY_LOGFILE
echo "===============================================================" >> $PROXY_LOGFILE

IGNORECP=`echo $IGNORECP | tr '[:upper:]' '[:lower:]'`
if [ "$IGNORECP" = "yes" ]
then
	CP_FDN=`$CP_UTIL username`	#Get Common Proxy credentials
	READ_CP_FDN=$?
	if [ $READ_CP_FDN -ne 0 ]
	then
		echo "Failed to retrieve common proxy credentials: $READ_CP_FDN" >> $PROXY_LOGFILE
		exit $READ_CP_FDN
	fi
	
	#If common proxy doesn't exist on system, it's same as ignore CP
	if test "$CP_FDN" = ""
	then
		IGNORECP="yes"
	fi
fi

#Start reconfiguring services one by one

#CIFS
if [ -f "/opt/novell/cifs/bin/cifs_retrieve_proxy_cred.sh" ];	
then
	/opt/novell/cifs/bin/cifs_retrieve_proxy_cred.sh username $CRED_TEMP_FILE >> /dev/null 2>&1
	READ_PROXY_NAME=$?
	if [ $READ_PROXY_NAME -eq 0 ] && [ -f $CRED_TEMP_FILE ]
	then
		read SRVC_PRXY < $CRED_TEMP_FILE
		rm $CRED_TEMP_FILE
		
		if test $SRVC_PRXY != ""	#Don't proceed if we can't get proxy user
		then
			#Ignore the service if it's already configured to use common proxy on the system
			if test "$IGNORECP" = "no"
			then
				$RECONFBINS/cifs_reconfig_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i "$LDAP_IP" -p "$LDAP_PORT" -e $ENCRYPTCRED >> /dev/null 2>&1
				SERV_RECONFIG=$?
				if [ $SERV_RECONFIG -ne 0 ]
				then
					echo "CIFS reconfiguration for proxy user has failed: $SERV_RECONFIG " >> $PROXY_LOGFILE
				fi
			else
				#Compare the Service proxy with Common proxy and migrate if they are different
				if test "$SRVC_PRXY" !=  "$CP_FDN"
				then
					$RECONFBINS/cifs_reconfig_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i "$LDAP_IP" -p "$LDAP_PORT" -e $ENCRYPTCRED >> /dev/null 2>&1
					SERV_RECONFIG=$?
					if [ $SERV_RECONFIG -ne 0 ]
					then
						echo "CIFS reconfiguration for proxy user has failed: $SERV_RECONFIG " >> $PROXY_LOGFILE
					fi
				else
					echo "CIFS is not reconfigured as it's using common proxy: $CP_FDN" >> $PROXY_LOGFILE
					echo "Nothing to be done" >> $PROXY_LOGFILE
				fi
			fi
		else
			echo "CIFS is not configured with any proxy user. Not reconfiguring the service" >> $PROXY_LOGFILE
		fi
	else
		echo "Failed to get current CIFS proxy user name: $READ_PROXY_NAME " >> $PROXY_LOGFILE
	fi
fi

#AFP
if [ -f "/opt/novell/afptcpd/bin/afp_retrieve_proxy_cred.sh" ];	
then
	/opt/novell/afptcpd/bin/afp_retrieve_proxy_cred.sh username $CRED_TEMP_FILE >> /dev/null 2>&1
	READ_PROXY_NAME=$?
	if [ $READ_PROXY_NAME -eq 0 ] && [ -f $CRED_TEMP_FILE ]
	then
		read SRVC_PRXY < $CRED_TEMP_FILE
		rm $CRED_TEMP_FILE
		
		if test $SRVC_PRXY != ""	#Don't proceed if we can't get proxy user
		then
			#Ignore the service if it's already configured to use common proxy on the system
			if test "$IGNORECP" = "no"
			then
				$RECONFBINS/afp_reconfig_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i "$LDAP_IP" -p "$LDAP_PORT" -e $ENCRYPTCRED >> /dev/null 2>&1
				SERV_RECONFIG=$?
				if [ $SERV_RECONFIG -ne 0 ]
				then
					echo "AFP reconfiguration for proxy user has failed: $SERV_RECONFIG " >> $PROXY_LOGFILE
				fi
			else
				#Compare the Service proxy with Common proxy and migrate if they are different
				if test "$SRVC_PRXY" !=  "$CP_FDN"
				then
					$RECONFBINS/afp_reconfig_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i "$LDAP_IP" -p "$LDAP_PORT" -e $ENCRYPTCRED >> /dev/null 2>&1
					SERV_RECONFIG=$?
					if [ $SERV_RECONFIG -ne 0 ]
					then
						echo "CIFS reconfiguration for proxy user has failed: $SERV_RECONFIG " >> $PROXY_LOGFILE
					fi
				else
					echo "CIFS is not reconfigured as it's using common proxy: $CP_FDN" >> $PROXY_LOGFILE
					echo "Nothing to be done" >> $PROXY_LOGFILE
				fi
			fi
		else
			echo "CIFS is not configured with any proxy user. Not reconfiguring the service" >> $PROXY_LOGFILE
		fi
	else
		echo "Failed to get current AFP proxy user name: $READ_PROXY_NAME " >> $PROXY_LOGFILE
	fi
fi


#DNS
if [ -f "/opt/novell/named/bin/dns_retrieve_proxy_cred" ];	
then
	/opt/novell/named/bin/dns_retrieve_proxy_cred username $CRED_TEMP_FILE >> /dev/null 2>&1
	READ_PROXY_NAME=$?
	if [ $READ_PROXY_NAME -eq 0 ] && [ -f $CRED_TEMP_FILE ]
	then
		read SRVC_PRXY < $CRED_TEMP_FILE
		rm $CRED_TEMP_FILE
		
		if test $SRVC_PRXY != ""	#Don't proceed if we can't get proxy user
		then
			#Ignore the service if it's already configured to use common proxy on the system
			if test "$IGNORECP" = "no"
			then
				$RECONFBINS/dns_reconfig_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i "$LDAP_IP" -p "$LDAP_PORT" -e $ENCRYPTCRED >> /dev/null 2>&1
				SERV_RECONFIG=$?
				if [ $SERV_RECONFIG -ne 0 ]
				then
					echo "DNS reconfiguration for proxy user has failed: $SERV_RECONFIG " >> $PROXY_LOGFILE
				fi
			else
				#Compare the Service proxy with Common proxy and migrate if they are different
				if test "$SRVC_PRXY" !=  "$CP_FDN"
				then
					$RECONFBINS/dns_reconfig_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i "$LDAP_IP" -p "$LDAP_PORT" -e $ENCRYPTCRED >> /dev/null 2>&1
					SERV_RECONFIG=$?
					if [ $SERV_RECONFIG -ne 0 ]
					then
						echo "DNS reconfiguration for proxy user has failed: $SERV_RECONFIG " >> $PROXY_LOGFILE
					fi
				else
					echo "DNS is not reconfigured as it's using common proxy: $CP_FDN" >> $PROXY_LOGFILE
					echo "Nothing to be done" >> $PROXY_LOGFILE
				fi
			fi
		else
			echo "DNS is not configured with any proxy user. Not reconfiguring the service" >> $PROXY_LOGFILE
		fi
	else
		echo "Failed to get current DNS proxy user name: $READ_PROXY_NAME " >> $PROXY_LOGFILE
	fi
fi


#DHCP
if [ -f "/opt/novell/dhcp/bin/dhcp_retrieve_proxy_cred" ];	
then
	/opt/novell/dhcp/bin/dhcp_retrieve_proxy_cred username $CRED_TEMP_FILE >> /dev/null 2>&1
	READ_PROXY_NAME=$?
	if [ $READ_PROXY_NAME -eq 0 ] && [ -f $CRED_TEMP_FILE ]
	then
		read SRVC_PRXY < $CRED_TEMP_FILE
		rm $CRED_TEMP_FILE
		
		if test $SRVC_PRXY != ""	#Don't proceed if we can't get proxy user
		then
			#Ignore the service if it's already configured to use common proxy on the system
			if test "$IGNORECP" = "no"
			then
				$RECONFBINS/dhcp_reconfig_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i "$LDAP_IP" -p "$LDAP_PORT"-e $ENCRYPTCRED  >> /dev/null 2>&1
				SERV_RECONFIG=$?
				if [ $SERV_RECONFIG -ne 0 ]
				then
					echo "DHCP reconfiguration for proxy user has failed: $SERV_RECONFIG " >> $PROXY_LOGFILE
				fi
			else
				#Compare the Service proxy with Common proxy and migrate if they are different
				if test "$SRVC_PRXY" !=  "$CP_FDN"
				then
					$RECONFBINS/dhcp_reconfig_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i "$LDAP_IP" -p "$LDAP_PORT" -e $ENCRYPTCRED >> /dev/null 2>&1
					SERV_RECONFIG=$?
					if [ $SERV_RECONFIG -ne 0 ]
					then
						echo "DHCP reconfiguration for proxy user has failed: $SERV_RECONFIG " >> $PROXY_LOGFILE
					fi
				else
					echo "DHCP is not reconfigured as it's using common proxy: $CP_FDN" >> $PROXY_LOGFILE
					echo "Nothing to be done" >> $PROXY_LOGFILE
				fi
			fi
		else
			echo "DHCP is not configured with any proxy user. Not reconfiguring the service" >> $PROXY_LOGFILE
		fi
	else
		echo "Failed to get current DHCP proxy user name: $READ_PROXY_NAME " >> $PROXY_LOGFILE
	fi
fi


#NetStorage
if [ -f "/opt/novell/netstorage/bin/ns_retrieve_proxy_cred" ];	
then
	/opt/novell/netstorage/bin/ns_retrieve_proxy_cred username $CRED_TEMP_FILE >> /dev/null 2>&1
	READ_PROXY_NAME=$?
	if [ $READ_PROXY_NAME -eq 0 ] && [ -f $CRED_TEMP_FILE ]
	then
		read SRVC_PRXY < $CRED_TEMP_FILE
		rm $CRED_TEMP_FILE
		
		if test $SRVC_PRXY != ""	#Don't proceed if we can't get proxy user
		then
			#Ignore the service if it's already configured to use common proxy on the system
			if test "$IGNORECP" = "no"
			then
				$RECONFBINS/netstorage_reconfig_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i "$LDAP_IP" -p "$LDAP_PORT" -e $ENCRYPTCRED >> /dev/null 2>&1
				SERV_RECONFIG=$?
				if [ $SERV_RECONFIG -ne 0 ]
				then
					echo "NetStorage reconfiguration for proxy user has failed: $SERV_RECONFIG " >> $PROXY_LOGFILE
				fi
			else
				#Compare the Service proxy with Common proxy and migrate if they are different
				if test "$SRVC_PRXY" !=  "$CP_FDN"
				then
					$RECONFBINS/netstorage_reconfig_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i "$LDAP_IP" -p "$LDAP_PORT" -e $ENCRYPTCRED  >> /dev/null 2>&1
					SERV_RECONFIG=$?
					if [ $SERV_RECONFIG -ne 0 ]
					then
						echo "NetStorage reconfiguration for proxy user has failed: $SERV_RECONFIG " >> $PROXY_LOGFILE
					fi
				else
					echo "NetStorage is not reconfigured as it's using common proxy: $CP_FDN" >> $PROXY_LOGFILE
					echo "Nothing to be done" >> $PROXY_LOGFILE
				fi
			fi
		else
			echo "NetStorage is not configured with any proxy user. Not reconfiguring the service" >> $PROXY_LOGFILE
		fi
	else
		echo "Failed to get current NetStorage proxy user name: $READ_PROXY_NAME " >> $PROXY_LOGFILE
	fi
fi

#NCS
if [ -f "/opt/novell/ncs/bin/ncs_retrieve_proxy_cred" ];	
then
	/opt/novell/ncs/bin/ncs_retrieve_proxy_cred username $CRED_TEMP_FILE >> /dev/null 2>&1
	READ_PROXY_NAME=$?
	if [ $READ_PROXY_NAME -eq 0 ] && [ -f $CRED_TEMP_FILE ]
	then
		read SRVC_PRXY < $CRED_TEMP_FILE
		rm $CRED_TEMP_FILE
		
		if test $SRVC_PRXY != ""	#Don't proceed if we can't get proxy user
		then
			#Ignore the service if it's already configured to use common proxy on the system
			if test "$IGNORECP" = "no"
			then
				$RECONFBINS/ncs_reconfig_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i "$LDAP_IP" -p "$LDAP_PORT" -e $ENCRYPTCRED >> /dev/null 2>&1
				SERV_RECONFIG=$?
				if [ $SERV_RECONFIG -ne 0 ]
				then
					echo "NCS reconfiguration for proxy user has failed: $SERV_RECONFIG " >> $PROXY_LOGFILE
				fi
			else
				#Compare the Service proxy with Common proxy and migrate if they are different
				if test "$SRVC_PRXY" !=  "$CP_FDN"
				then
					$RECONFBINS/ncs_reconfig_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i "$LDAP_IP" -p "$LDAP_PORT" -e $ENCRYPTCRED >> /dev/null 2>&1
					SERV_RECONFIG=$?
					if [ $SERV_RECONFIG -ne 0 ]
					then
						echo "NCS reconfiguration for proxy user has failed: $SERV_RECONFIG " >> $PROXY_LOGFILE
					fi
				else
					echo "NCS is not reconfigured as it's using common proxy: $CP_FDN" >> $PROXY_LOGFILE
					echo "Nothing to be done" >> $PROXY_LOGFILE
				fi
			fi
		else
			echo "NCS is not configured with any proxy user. Not reconfiguring the service" >> $PROXY_LOGFILE
		fi
	else
		echo "Failed to get current NCS proxy user name: $READ_PROXY_NAME " >> $PROXY_LOGFILE
	fi
fi

#LUM
if [ -f "/usr/bin/lum_retrieve_proxy_cred" ];	
then
	/usr/bin/lum_retrieve_proxy_cred username $CRED_TEMP_FILE >> /dev/null 2>&1
	READ_PROXY_NAME=$?
	if [ $READ_PROXY_NAME -eq 0 ] && [ -f $CRED_TEMP_FILE ]
	then
		read SRVC_PRXY < $CRED_TEMP_FILE
		rm $CRED_TEMP_FILE
		
		if test $SRVC_PRXY != ""	#Don't proceed if we can't get proxy user
		then
			#Ignore the service if it's already configured to use common proxy on the system
			if test "$IGNORECP" = "no"
			then
				$RECONFBINS/lum_reconfig_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i "$LDAP_IP" -p "$LDAP_PORT" -e $ENCRYPTCRED >> /dev/null 2>&1
				SERV_RECONFIG=$?
				if [ $SERV_RECONFIG -ne 0 ]
				then
					echo "LUM reconfiguration for proxy user has failed: $SERV_RECONFIG " >> $PROXY_LOGFILE
				fi
			else
				#Compare the Service proxy with Common proxy and migrate if they are different
				if test "$SRVC_PRXY" !=  "$CP_FDN"
				then
					$RECONFBINS/lum_reconfig_proxy.sh -d "$LDAP_ADM" -w "$LDAP_PWD" -i "$LDAP_IP" -p "$LDAP_PORT" -e $ENCRYPTCRED >> /dev/null 2>&1
					SERV_RECONFIG=$?
					if [ $SERV_RECONFIG -ne 0 ]
					then
						echo "LUM reconfiguration for proxy user has failed: $SERV_RECONFIG " >> $PROXY_LOGFILE
					fi
				else
					echo "LUM is not reconfigured as it's using common proxy: $CP_FDN" >> $PROXY_LOGFILE
					echo "Nothing to be done" >> $PROXY_LOGFILE
				fi
			fi
		else
			echo "LUM is not configured with any proxy user. Not reconfiguring the service" >> $PROXY_LOGFILE
		fi
	else
		echo "Failed to get current LUM proxy user name: $READ_PROXY_NAME " >> $PROXY_LOGFILE
	fi
fi

echo "===============================================================" >> $PROXY_LOGFILE
echo "`date`:Proxy reconfiguration of services is completed" >> $PROXY_LOGFILE
echo "===============================================================" >> $PROXY_LOGFILE

echo "Services reconfiguration for proxy user is completed. Refer to $PROXY_LOGFILE for more details"

exit 0
